@@ -16,6 +16,7 @@
 #include <qregexp.h>
 #include <qpopupmenu.h>
 
+#include <kgenericfactory.h>
 #include <ksimpleconfig.h>
 #include <kaction.h>
 #include <kiconloader.h>
@@ -40,35 +41,42 @@
 // XXX instead of 'char *' in calls that don't modify the string
 #define tocstr(x) ((char *)((x).latin1()))
 
-extern "C"
-{
-	KCModule *create_kamera(QWidget *parent, const char *name)
-	{
-		KGlobal::locale()->insertCatalogue("kcmkamera");
-		return new KKameraConfig(parent, name);
-	}
-}
+typedef KGenericFactory<KKameraConfig, QWidget> KKameraConfigFactory;
+K_EXPORT_COMPONENT_FACTORY( kcm_kamera, KKameraConfigFactory( "kcmkamera" ) );
+
+// --------------- Camera control center module widget ---
 
 KKameraConfig *KKameraConfig::m_instance = NULL;
 
-KKameraConfig::KKameraConfig(QWidget *parent, const char *name)
-:KCModule(parent, name)
+KKameraConfig::KKameraConfig(QWidget *parent, const char *name, const QStringList &)
+	: KCModule(KKameraConfigFactory::instance(), parent, name)
 {
 	m_devicePopup = new QPopupMenu(this);
 	m_actions = new KActionCollection(this);
 	m_config = new KSimpleConfig(KProtocolInfo::config("camera"));
+	
+	m_context = gp_context_new();
+	if (m_context) {
+
+		// Register the callback functions
+		gp_context_set_cancel_func(m_context, cbGPCancel, this);
+		gp_context_set_idle_func(m_context, cbGPIdle, this);
+
+		displayGPSuccessDialogue();
+
+		// autodetect new cameras
+		autoDetect();
+
+		// load existing configuration
+		load();
+
+	} else {
+
+		displayGPFailureDialogue();
+	}
 
 	// store instance for frontend_prompt
 	m_instance = this;
-
-	// build and display normal dialogue
-	displayGPSuccessDialogue();
-
-	// autodetect new cameras
-	autoDetect();
-
-	// load existing configuration
-	load();
 }
 
 KKameraConfig::~KKameraConfig()
@@ -86,11 +94,15 @@ void KKameraConfig::displayGPFailureDialogue(void)
 
 void KKameraConfig::displayGPSuccessDialogue(void)
 {
+	// set the kcontrol module buttons
+	setButtons(Help | Apply | Cancel | Ok);
+
 	// create a layout with two vertical boxes
-	QVBoxLayout *topLayout = new QVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());
+	QVBoxLayout *topLayout = new QVBoxLayout(this, 0, 0);
 	topLayout->setAutoAdd(true);
 	
 	m_toolbar = new KToolBar(this, "ToolBar");
+	m_toolbar->setMovingEnabled(false);
 	
 	// create list of devices
 	m_deviceSel = new KIconView(this);
@@ -111,13 +123,17 @@ void KKameraConfig::displayGPSuccessDialogue(void)
 	act = new KAction(i18n("Remove"), "edittrash", 0, this, SLOT(slot_removeCamera()), m_actions, "camera_remove");
 	act->setWhatsThis(i18n("Click this button to remove the selected camera from the list."));
 	act->plug(m_toolbar);
-	act = new KAction(i18n("Configure"), "configure", 0, this, SLOT(slot_configureCamera()), m_actions, "camera_configure");
+	act = new KAction(i18n("Configure..."), "configure", 0, this, SLOT(slot_configureCamera()), m_actions, "camera_configure");
 	act->setWhatsThis(i18n("Click this button to change the configuration of the selected camera.<br><br>The availability of this feature and the contents of the Configuration dialog depend on the camera model."));
 	act->plug(m_toolbar);
-
 	act = new KAction(i18n("Information"), "hwinfo", 0, this, SLOT(slot_cameraSummary()), m_actions, "camera_summary");
 	act->setWhatsThis(i18n("Click this button to view a summary of the current status of the selected camera.<br><br>The availability of this feature and the contents of the Configuration dialog depend on the camera model."));
 	act->plug(m_toolbar);
+	m_toolbar->insertLineSeparator();
+	act = new KAction(i18n("Cancel"), "stop", 0, this, SLOT(slot_cancelOperation()), m_actions, "camera_cancel");
+	act->setWhatsThis(i18n("Click this button to cancel the current camera operation."));
+	act->setEnabled(false);
+	act->plug(m_toolbar);
 }
 
 void KKameraConfig::populateDeviceListView(void)
@@ -145,7 +161,8 @@ void KKameraConfig::save(void)
 
 void KKameraConfig::autoDetect(void)
 {
-	GPContext *glob_context = NULL;
+	m_cancelPending = false;
+
 	QStringList groupList = m_config->groupList();
 
         int i, count;
@@ -155,10 +172,10 @@ void KKameraConfig::autoDetect(void)
         const char *model, *value;
 
         gp_abilities_list_new (&al);
-        gp_abilities_list_load (al, glob_context);
+        gp_abilities_list_load (al, m_context);
         gp_port_info_list_new (&il);
         gp_port_info_list_load (il);
-        gp_abilities_list_detect (al, il, &list, glob_context);
+        gp_abilities_list_detect (al, il, &list, m_context);
         gp_abilities_list_free (al);
         gp_port_info_list_free (il);
 
@@ -195,6 +212,33 @@ void KKameraConfig::load(void)
 	populateDeviceListView();
 }
 
+void KKameraConfig::beforeCameraOperation(void)
+{
+	m_cancelPending = false;
+
+	m_actions->action("camera_test")->setEnabled(false);
+	m_actions->action("camera_remove")->setEnabled(false);
+	m_actions->action("camera_configure")->setEnabled(false);
+	m_actions->action("camera_summary")->setEnabled(false);
+
+	m_actions->action("camera_cancel")->setEnabled(true);
+}
+
+void KKameraConfig::afterCameraOperation(void)
+{
+	m_actions->action("camera_cancel")->setEnabled(false);
+
+	// if we're regaining control after a Cancel...
+	if (m_cancelPending) {
+		qApp->restoreOverrideCursor();
+		m_cancelPending = false;
+	}
+	
+	// if any item was selected before the operation was run
+	// it makes sense for the relevant toolbar buttons to be enabled
+	slot_deviceSelected(m_deviceSel->currentItem());
+}
+
 QString KKameraConfig::suggestName(const QString &name)
 {
 	QString new_name = name;
@@ -223,6 +267,7 @@ void KKameraConfig::slot_addCamera()
 		m_device->setName(suggestName(m_device->model()));
 		m_devices.insert(m_device->name(), m_device);
 		populateDeviceListView();
+		emit changed(true);
 	} else {
 		delete m_device;
 	}
@@ -237,17 +282,22 @@ void KKameraConfig::slot_removeCamera()
 		delete m_device;
 		m_config->deleteGroup(name, true);
 		populateDeviceListView();
+		emit changed(true);
 	}
 }
 
 void KKameraConfig::slot_testCamera()
 {
+	beforeCameraOperation();
+
 	QString name = m_deviceSel->currentItem()->text();
 	if (m_devices.contains(name)) {
 		KCamera *m_device = m_devices[name];
 		if (m_device->test())
 			KMessageBox::information(this, i18n("Camera test was successful."));
 	}
+	
+	afterCameraOperation();
 }
 
 void KKameraConfig::slot_configureCamera()
@@ -272,6 +322,15 @@ void KKameraConfig::slot_cameraSummary()
 	}
 }
 
+void KKameraConfig::slot_cancelOperation()
+{
+	m_cancelPending = true;
+	// Prevent the user from keeping clicking Cancel
+	m_actions->action("camera_cancel")->setEnabled(false);
+	// and indicate that the click on Cancel did have some effect
+	qApp->setOverrideCursor(Qt::WaitCursor);
+}
+
 void KKameraConfig::slot_deviceMenu(QIconViewItem *item, const QPoint &point)
 {
 	if (item) {
@@ -293,6 +352,28 @@ void KKameraConfig::slot_deviceSelected(QIconViewItem *item)
 	m_actions->action("camera_summary")->setEnabled(item);
 }
 
+void KKameraConfig::cbGPIdle(GPContext *context, void *data)
+{
+	KKameraConfig *self( reinterpret_cast<KKameraConfig*>(data) );
+
+	qApp->processEvents();
+}
+
+GPContextFeedback KKameraConfig::cbGPCancel(GPContext *context, void *data)
+{
+	KKameraConfig *self( reinterpret_cast<KKameraConfig*>(data) );
+
+	// Since in practice no camera driver supports idle callbacks yet,
+	// we'll use the cancel callback as opportunity to process events
+	qApp->processEvents();
+
+	// If a cancel request is pending, ask gphoto to cancel
+	if (self->m_cancelPending)
+		return GP_CONTEXT_FEEDBACK_CANCEL;
+	else
+		return GP_CONTEXT_FEEDBACK_OK;
+}
+
 QString KKameraConfig::quickHelp() const
 {
 	return i18n("<h1>Kamera Configuration</h1>\n"
@@ -314,3 +395,4 @@ void KKameraConfig::slot_error(const QString &message, const QString &details)
 {
 	KMessageBox::detailedError(this, message, details);
 }
+
