@@ -44,7 +44,7 @@ int kdemain(int argc, char **argv)
 	KInstance instance("kio_kamera");
 
 	if(argc != 4) {
-		kdDebug() << "Usage: kio_kamera protocol "
+		kdDebug(7123) << "Usage: kio_kamera protocol "
 			     "domain-socket1 domain-socket2" << endl;
 		exit(-1);
 	}
@@ -63,8 +63,7 @@ m_camera(NULL)
 	// attempt to initialize libgphoto2 and chosen camera (requires locking)
 	// (will init m_camera, since the m_camera's configuration is empty)
 	m_camera = 0;
-
-	
+	m_file = NULL;
 	m_config = new KSimpleConfig(KProtocolInfo::config("camera"));
 	autoDetect();
 	m_context = gp_context_new();
@@ -72,9 +71,11 @@ m_camera(NULL)
 
 KameraProtocol::~KameraProtocol()
 {
+    delete m_config;
 	if(m_camera) {
 		closeCamera();
  		gp_camera_free(m_camera);
+		m_camera = NULL;
 	}
 }
 
@@ -98,14 +99,14 @@ void KameraProtocol::autoDetect(void)
         gp_port_info_list_free (il);
 
         count = gp_list_count (&list);
-	
+
 	for (i = 0 ; i<count ; i++) {
 		gp_list_get_name  (&list, i, &model);
 		gp_list_get_value (&list, i, &value);
 
 		if (groupList.contains(model))
 			continue;
-		kdDebug() << "Adding " << model << " at " << value << endl;
+		kdDebug(7123) << "Adding " << model << " at " << value << endl;
 		m_config->setGroup(model);
 		m_config->writeEntry("Model",model);
 		m_config->writeEntry("Path",value);
@@ -124,8 +125,12 @@ bool KameraProtocol::openCamera(void) {
 void KameraProtocol::closeCamera(void)
 {
 	int gpr;
+
+	if (!m_camera)
+		return;
+
 	if ((gpr=gp_camera_exit(m_camera,m_context))!=GP_OK) {
-		kdDebug() << "closeCamera failed with " << gp_result_as_string(gpr) << endl;
+		kdDebug(7123) << "closeCamera failed with " << gp_result_as_string(gpr) << endl;
 	}
 	// HACK: gp_camera_exit() in gp 2.0 does not close the port if there
 	//       is no camera_exit function.
@@ -137,7 +142,7 @@ void KameraProtocol::closeCamera(void)
 // The actual returning of the data is done in the frontend callback functions.
 void KameraProtocol::get(const KURL &url)
 {
-	kdDebug() << "KameraProtocol::get(" << url.path() << ")" << endl;
+	kdDebug(7123) << "KameraProtocol::get(" << url.path() << ")" << endl;
 
 	CameraFileType fileType;
 	int gpr;
@@ -149,6 +154,31 @@ void KameraProtocol::get(const KURL &url)
 	if(!openCamera())
 		return;
 
+	// fprintf(stderr,"get(%s)\n",url.path().latin1());
+
+#define GPHOTO_TEXT_FILE(xx)						\
+	if (!url.path().compare("/" #xx ".txt")) {			\
+		CameraText xx;						\
+		gpr = gp_camera_get_##xx(m_camera,  &xx, m_context);	\
+		if (gpr != GP_OK) {					\
+			error(KIO::ERR_DOES_NOT_EXIST, url.path());	\
+			return;						\
+		}							\
+		QByteArray chunkDataBuffer;				\
+		chunkDataBuffer.setRawData(xx.text, strlen(xx.text));	\
+		data(chunkDataBuffer);					\
+		processedSize(strlen(xx.text));				\
+		chunkDataBuffer.resetRawData(xx.text, strlen(xx.text));	\
+		finished();						\
+		closeCamera();						\
+		return;							\
+	}
+
+	GPHOTO_TEXT_FILE(about);
+	GPHOTO_TEXT_FILE(manual);
+	GPHOTO_TEXT_FILE(summary);
+
+#undef GPHOTO_TEXT_FILE
 	// emit info message
 	infoMessage( i18n("Retrieving data from camera <b>%1</b>").arg(m_cfgModel) );
 
@@ -168,19 +198,21 @@ void KameraProtocol::get(const KURL &url)
 
 	// at last, a proper API to determine whether a thumbnail was requested.
 	if(cameraSupportsPreview() && metaData("thumbnail") == "1") {
-		kdDebug() << "get() retrieving the thumbnail" << endl;
+		kdDebug(7123) << "get() retrieving the thumbnail" << endl;
 		fileType = GP_FILE_TYPE_PREVIEW;
-		if (info.preview.fields & GP_FILE_INFO_SIZE) {
+		if (info.preview.fields & GP_FILE_INFO_SIZE)
 			totalSize(info.preview.size);
-		}
+		if (info.preview.fields & GP_FILE_INFO_TYPE)
+			mimeType(info.preview.type);
 	} else {
-		kdDebug() << "get() retrieving the full-scale photo" << endl;
+		kdDebug(7123) << "get() retrieving the full-scale photo" << endl;
 		fileType = GP_FILE_TYPE_NORMAL;
-		if (info.file.fields & GP_FILE_INFO_SIZE) {
+		if (info.file.fields & GP_FILE_INFO_SIZE)
 			totalSize(info.file.size);
-		}
+		if (info.preview.fields & GP_FILE_INFO_TYPE)
+			mimeType(info.file.type);
 	}
-	
+
 	// fetch the data
 	m_fileSize = 0;
 	gpr = gp_camera_file_get(m_camera, tocstr(url.directory(false)), tocstr(url.filename()), fileType, m_file, m_context);
@@ -190,38 +222,54 @@ void KameraProtocol::get(const KURL &url)
 		case GP_ERROR_FILE_NOT_FOUND:
 		case GP_ERROR_DIRECTORY_NOT_FOUND:
 			gp_file_free(m_file);
+			m_file = NULL;
 			error(KIO::ERR_DOES_NOT_EXIST, url.filename());
 			closeCamera();
 			return ;
 		default:
 			gp_file_free(m_file);
+			m_file = NULL;
 			error(KIO::ERR_UNKNOWN, gp_result_as_string(gpr));
 			closeCamera();
 			return;
 	}
-	const char *xdata;
-	unsigned long int xsize;
-	gp_file_get_data_and_size(m_file,&xdata,&xsize);
-	QByteArray	barr(xsize);
-	barr.setRawData(xdata,xsize);
-	data(barr);
-	barr.resetRawData(xdata,xsize);
-
 	// emit the mimetype
 	// NOTE: we must first get the file, so that CameraFile->name would be set
 	const char *fileMimeType;
 	gp_file_get_mime_type(m_file, &fileMimeType);
 	mimeType(fileMimeType);
 
+	// We need to pass left over data here. Some camera drivers do not
+	// implement progress callbacks!
+	const char *fileData;
+	long unsigned int fileSize;
+	// This merely returns us a pointer to gphoto's internal data
+	// buffer -- there's no expensive memcpy
+	gp_file_get_data_and_size(m_file, &fileData, &fileSize);
+	// make sure we're not sending zero-sized chunks (=EOF)
+	// also make sure we send only if the progress did not send the data
+	// already.
+	if ((fileSize > 0)  && (fileSize - m_fileSize)>0) {
+		// XXX using assign() here causes segfault, prolly because
+		// gp_file_free is called before chunkData goes out of scope
+		QByteArray chunkDataBuffer;
+		chunkDataBuffer.setRawData(fileData + m_fileSize, fileSize - m_fileSize);
+		data(chunkDataBuffer);
+		processedSize(fileSize);
+		chunkDataBuffer.resetRawData(fileData + m_fileSize, fileSize - m_fileSize);
+		m_fileSize = fileSize;
+	}
+
 	finished();
 	gp_file_free(m_file);
+	m_file = NULL;
 	closeCamera();
 }
 
 // The KIO slave "stat" function.
 void KameraProtocol::stat(const KURL &url)
 {
-	kdDebug() << "KameraProtocol("<<this<<")::stat(" << url.path() << ")" << endl;
+	kdDebug(7123) << "KameraProtocol("<<this<<")::stat(" << url.path() << ")" << endl;
 
 	if(url.path() == "/") {
 		statRoot();
@@ -238,11 +286,11 @@ void KameraProtocol::statRoot(void)
 
 	atom.m_uds = UDS_NAME;
 	atom.m_str = "/";
-	entry.append(atom);  
+	entry.append(atom);
 
 	atom.m_uds = UDS_FILE_TYPE;
 	atom.m_long = S_IFDIR;
-	entry.append(atom);    	
+	entry.append(atom);
 
 	atom.m_uds = UDS_ACCESS;
 	atom.m_long = S_IRUSR | S_IRGRP | S_IROTH |
@@ -263,19 +311,40 @@ void KameraProtocol::statRegular(const KURL &url)
 	if (openCamera() == false)
 		return;
 
+	// fprintf(stderr,"statRegular(%s)\n",url.path().latin1());
+
 	// Is "url" a directory?
 	CameraList *dirList;
 	gp_list_new(&dirList);
-	kdDebug() << "statRegular() Requesting directories list for " << url.directory() << endl;
+	kdDebug(7123) << "statRegular() Requesting directories list for " << url.directory() << endl;
 	gpr = gp_camera_folder_list_folders(m_camera, tocstr(url.directory()), dirList, m_context);
-	closeCamera();
 	if (gpr != GP_OK) {
 		if ((gpr == GP_ERROR_FILE_NOT_FOUND) || (gpr == GP_ERROR_DIRECTORY_NOT_FOUND))
 			error(KIO::ERR_DOES_NOT_EXIST, url.path());
 		gp_list_free(dirList);
+		closeCamera();
 		return;
 	}
 
+#define GPHOTO_TEXT_FILE(xx)						\
+	if (!url.path().compare("/"#xx".txt")) {			\
+		CameraText xx;						\
+		gpr = gp_camera_get_about(m_camera,  &xx, m_context);	\
+		if (gpr != GP_OK) {					\
+			error(KIO::ERR_DOES_NOT_EXIST, url.filename());	\
+			return;						\
+		}							\
+		translateTextToUDS(entry,#xx".txt",xx.text);		\
+		statEntry(entry);					\
+		finished();						\
+		closeCamera();						\
+		return;							\
+	}
+	GPHOTO_TEXT_FILE(about);
+	GPHOTO_TEXT_FILE(manual);
+	GPHOTO_TEXT_FILE(summary);
+#undef GPHOTO_TEXT_FILE
+
 	const char *name;
 	for(int i = 0; i < gp_list_count(dirList); i++) {
 		gp_list_get_name(dirList, i, &name);
@@ -285,29 +354,31 @@ void KameraProtocol::statRegular(const KURL &url)
 			translateDirectoryToUDS(entry, url.fileName());
 			statEntry(entry);
 			finished();
+			closeCamera();
 			return;
 		}
 	}
 	gp_list_free(dirList);
-	
+
 	// Is "url" a file?
 	CameraFileInfo info;
 	gpr = gp_camera_file_get_info(m_camera, tocstr(url.directory(false)), tocstr(url.fileName()), &info, m_context);
-	closeCamera();
 	if (gpr != GP_OK) {
 		if ((gpr == GP_ERROR_FILE_NOT_FOUND) || (gpr == GP_ERROR_DIRECTORY_NOT_FOUND))
 			error(KIO::ERR_DOES_NOT_EXIST, url.path());
+		closeCamera();
 		return;
 	}
-	translateFileToUDS(entry, info);
+	translateFileToUDS(entry, info, url.fileName());
 	statEntry(entry);
 	finished();
+	closeCamera();
 }
 
 // The KIO slave "del" function.
 void KameraProtocol::del(const KURL &url, bool isFile)
 {
-	kdDebug() << "KameraProtocol::del(" << url.path() << ")" << endl;
+	kdDebug(7123) << "KameraProtocol::del(" << url.path() << ")" << endl;
 
 	if(!openCamera())
 		return;
@@ -319,7 +390,7 @@ void KameraProtocol::del(const KURL &url, bool isFile)
 		CameraList *list;
 		gp_list_new(&list);
 		int ret;
- 
+
 		ret = gp_camera_file_delete(m_camera, tocstr(url.directory(false)), tocstr(url.filename()), m_context);
 
 		if(ret != GP_OK) {
@@ -334,12 +405,12 @@ void KameraProtocol::del(const KURL &url, bool isFile)
 // The KIO slave "listDir" function.
 void KameraProtocol::listDir(const KURL &url)
 {
-	kdDebug() << "KameraProtocol::listDir(" << url.path() << ")" << endl;
+	kdDebug(7123) << "KameraProtocol::listDir(" << url.path() << ")" << endl;
 
 	if (url.host().isEmpty()) {
 		// List the available cameras
-		QStringList groupList = m_config->groupList(); 
-		kdDebug() << "Found cameras: " << groupList.join(", ") << endl;
+		QStringList groupList = m_config->groupList();
+		kdDebug(7123) << "Found cameras: " << groupList.join(", ") << endl;
 		QStringList::Iterator it;
 		UDSEntry entry;
 		UDSAtom atom;
@@ -358,11 +429,11 @@ void KameraProtocol::listDir(const KURL &url)
 				atom.m_long = S_IRUSR | S_IRGRP | S_IROTH |
 					S_IWUSR | S_IWGRP | S_IWOTH;
 				entry.append(atom);
-				
+
 				atom.m_uds = UDS_URL;
 				atom.m_str = QString::fromLatin1("camera://") + *it + QString::fromLatin1("/");
 				entry.append(atom);
-				
+
 				listEntry(entry, false);
 			}
 		}
@@ -370,31 +441,44 @@ void KameraProtocol::listDir(const KURL &url)
 		finished();
 		return;
 	}
-	
+
 	if (!openCamera())
 		return;
 
 	CameraList *dirList;
 	CameraList *fileList;
+	CameraList *specialList;
 	gp_list_new(&dirList);
 	gp_list_new(&fileList);
+	gp_list_new(&specialList);
 	int gpr;
 
+	if (!url.path().compare("/")) {
+		CameraText text;
+		if (GP_OK == gp_camera_get_manual(m_camera, &text, m_context))
+			gp_list_append(specialList,"manual.txt",NULL);
+		if (GP_OK == gp_camera_get_about(m_camera, &text, m_context))
+			gp_list_append(specialList,"about.txt",NULL);
+		if (GP_OK == gp_camera_get_summary(m_camera, &text, m_context))
+			gp_list_append(specialList,"summary.txt",NULL);
+	}
+
 	gpr = readCameraFolder(url.path(), dirList, fileList);
 	if(gpr != GP_OK) {
-		kdDebug() << "read Camera Folder failed:" << gp_result_as_string(gpr) <<endl;
+		kdDebug(7123) << "read Camera Folder failed:" << gp_result_as_string(gpr) <<endl;
 		closeCamera();
 		gp_list_free(dirList);
 		gp_list_free(fileList);
+		gp_list_free(specialList);
 		error(KIO::ERR_COULD_NOT_READ, gp_result_as_string(gpr));
 		return;
 	}
 
-	totalSize(gp_list_count(dirList) + gp_list_count(fileList));
+	totalSize(gp_list_count(specialList) + gp_list_count(dirList) + gp_list_count(fileList));
 
 	UDSEntry entry;
 	const char *name;
-	
+
 	for(int i = 0; i < gp_list_count(dirList); ++i) {
 		gp_list_get_name(dirList, i, &name);
 		translateDirectoryToUDS(entry, QString::fromLocal8Bit(name));
@@ -407,13 +491,30 @@ void KameraProtocol::listDir(const KURL &url)
 		gp_list_get_name(fileList, i, &name);
 		// we want to know more info about files (size, type...)
 		gp_camera_file_get_info(m_camera, tocstr(url.path()), name, &info, m_context);
-		translateFileToUDS(entry, info);
+		translateFileToUDS(entry, info, QString::fromLocal8Bit(name));
 		listEntry(entry, false);
 	}
+	if (!url.path().compare("/")) {
+		CameraText text;
+		if (GP_OK == gp_camera_get_manual(m_camera, &text, m_context)) {
+			translateTextToUDS(entry, "manual.txt", text.text);
+			listEntry(entry, false);
+		}
+		if (GP_OK == gp_camera_get_about(m_camera, &text, m_context)) {
+			translateTextToUDS(entry, "about.txt", text.text);
+			listEntry(entry, false);
+		}
+		if (GP_OK == gp_camera_get_summary(m_camera, &text, m_context)) {
+			translateTextToUDS(entry, "summary.txt", text.text);
+			listEntry(entry, false);
+		}
+	}
+
 	closeCamera();
 
 	gp_list_free(fileList);
 	gp_list_free(dirList);
+	gp_list_free(specialList);
 
 	listEntry(entry, true); // 'entry' is not used in this case - we only signal list completion
 	finished();
@@ -421,7 +522,7 @@ void KameraProtocol::listDir(const KURL &url)
 
 void KameraProtocol::setHost(const QString& host, int port, const QString& user, const QString& pass )
 {
-	kdDebug() << "KameraProtocol::setHost(" << host << ", " << port << ", " << user << ", " << pass << ")" << endl;
+	kdDebug(7123) << "KameraProtocol::setHost(" << host << ", " << port << ", " << user << ", " << pass << ")" << endl;
 	int gpr, idx;
 
 	if (!host.isEmpty()) {
@@ -430,18 +531,16 @@ void KameraProtocol::setHost(const QString& host, int port, const QString& user,
 		QString m_cfgModel = m_config->readEntry("Model");
 		QString m_cfgPath = m_config->readEntry("Path");
 
-		kdDebug() << "model is " << m_cfgModel << ", port is " << m_cfgPath << endl;
+		kdDebug(7123) << "model is " << m_cfgModel << ", port is " << m_cfgPath << endl;
 
 		if (m_camera) {
-			kdDebug() << "Configuration change detected" << endl;
-			if (GP_OK!=gp_camera_exit(m_camera,m_context)) {
-				kdDebug() << "camera exit failed for old cam?\n";
-			}
+			kdDebug(7123) << "Configuration change detected" << endl;
+			closeCamera();
 			gp_camera_unref(m_camera);
 			m_camera = NULL;
 			infoMessage( i18n("Reinitializing camera") );
 		} else {
-			kdDebug() << "Initializing camera" << endl;
+			kdDebug(7123) << "Initializing camera" << endl;
 			infoMessage( i18n("Initializing camera") );
 		}
 		// fetch abilities
@@ -451,7 +550,7 @@ void KameraProtocol::setHost(const QString& host, int port, const QString& user,
 		idx = gp_abilities_list_lookup_model(abilities_list, tocstr(m_cfgModel));
 		if (idx < 0) {
 			gp_abilities_list_free(abilities_list);
-			kdDebug() << "Unable to get abilities for model: " << m_cfgModel << endl;
+			kdDebug(7123) << "Unable to get abilities for model: " << m_cfgModel << endl;
 			error(KIO::ERR_UNKNOWN, gp_result_as_string(gpr));
 			return;
 		}
@@ -466,7 +565,7 @@ void KameraProtocol::setHost(const QString& host, int port, const QString& user,
 		idx = gp_port_info_list_lookup_path(port_info_list, tocstr(m_cfgPath));
 		if (idx < 0) {
 			gp_port_info_list_free(port_info_list);
-			kdDebug() << "Unable to get port info for path: " << m_cfgPath << endl;
+			kdDebug(7123) << "Unable to get port info for path: " << m_cfgPath << endl;
 			error(KIO::ERR_UNKNOWN, gp_result_as_string(gpr));
 			return;
 		}
@@ -479,7 +578,7 @@ void KameraProtocol::setHost(const QString& host, int port, const QString& user,
 			error(KIO::ERR_UNKNOWN, gp_result_as_string(gpr));
 			return;
 		}
-	
+
 		// register gphoto2 callback functions
 		gp_context_set_status_func(m_context, frontendCameraStatus, this);
 		gp_context_set_progress_funcs(m_context, frontendProgressStart, frontendProgressUpdate, NULL, this);
@@ -488,7 +587,8 @@ void KameraProtocol::setHost(const QString& host, int port, const QString& user,
 		// set model and port
 		gp_camera_set_abilities(m_camera, m_abilities);
 		gp_camera_set_port_info(m_camera, port_info);
-		kdDebug() << "Opening camera model " << m_cfgModel << " at " << m_cfgPath << endl;
+		gp_camera_set_port_speed(m_camera, 0); // TODO: the value needs to be configurable
+		kdDebug(7123) << "Opening camera model " << m_cfgModel << " at " << m_cfgPath << endl;
 #if 0
 		// initialize the camera (might take time on a non-existant or disconnected camera)
 		gpr = gp_camera_init(m_camera, m_context);
@@ -496,7 +596,7 @@ void KameraProtocol::setHost(const QString& host, int port, const QString& user,
 			gp_camera_unref(m_camera);
 			m_camera = NULL;
 			m_cfgModel = ""; // force a configuration reload (since init didn't complete)
-			kdDebug() << "Unable to init camera: " << gp_result_as_string(gpr) << endl;
+			kdDebug(7123) << "Unable to init camera: " << gp_result_as_string(gpr) << endl;
 			error(KIO::ERR_UNKNOWN, gp_result_as_string(gpr));
 			return;
 		}
@@ -510,8 +610,33 @@ void KameraProtocol::reparseConfiguration(void)
 	// we have no global config, do we?
 }
 
+// translate a simple text to a UDS entry
+void KameraProtocol::translateTextToUDS(UDSEntry &udsEntry, const QString &fn,
+	const char *text
+) {
+	UDSAtom atom;
+
+	udsEntry.clear();
+
+	atom.m_uds = UDS_FILE_TYPE; // UDS type
+	atom.m_long = S_IFREG; // file
+	udsEntry.append(atom);
+
+	atom.m_uds = UDS_NAME;
+	atom.m_str = fn;
+	udsEntry.append(atom);
+
+	atom.m_uds = UDS_SIZE;
+	atom.m_long = strlen(text);
+	udsEntry.append(atom);
+
+	atom.m_uds = UDS_ACCESS;
+	atom.m_long = S_IRUSR | S_IRGRP | S_IROTH;
+	udsEntry.append(atom);
+}
+
 // translate a CameraFileInfo to a UDSEntry which we can return as a directory listing entry
-void KameraProtocol::translateFileToUDS(UDSEntry &udsEntry, const CameraFileInfo &info)
+void KameraProtocol::translateFileToUDS(UDSEntry &udsEntry, const CameraFileInfo &info, QString name)
 {
 	UDSAtom atom;
 
@@ -520,25 +645,36 @@ void KameraProtocol::translateFileToUDS(UDSEntry &udsEntry, const CameraFileInfo
 	atom.m_uds = UDS_FILE_TYPE; // UDS type
 	atom.m_long = S_IFREG; // file
 	udsEntry.append(atom);
-	
-	if (info.file.fields & GP_FILE_INFO_NAME) {
-		atom.m_uds = UDS_NAME;
+
+	atom.m_uds = UDS_NAME;
+	if (info.file.fields & GP_FILE_INFO_NAME)
 		atom.m_str = QString::fromLocal8Bit(info.file.name);
-		udsEntry.append(atom);
-	}
+	else
+		atom.m_str = name;
+	udsEntry.append(atom);
 
 	if (info.file.fields & GP_FILE_INFO_SIZE) {
 		atom.m_uds = UDS_SIZE;
 		atom.m_long = info.file.size;
 		udsEntry.append(atom);
 	}
-	
+
+	if (info.file.fields & GP_FILE_INFO_MTIME) {
+		atom.m_uds = UDS_MODIFICATION_TIME;
+		atom.m_long = info.file.mtime;
+		udsEntry.append(atom);
+	} else {
+		atom.m_uds = UDS_MODIFICATION_TIME;
+		atom.m_long = time(NULL); /* NOW */
+		udsEntry.append(atom);
+	}
+
 	if (info.file.fields & GP_FILE_INFO_TYPE) {
 		atom.m_uds = UDS_MIME_TYPE;
 		atom.m_str = QString::fromLatin1(info.file.type);
 		udsEntry.append(atom);
 	}
-	
+
 	if (info.file.fields & GP_FILE_INFO_PERMISSIONS) {
 		atom.m_uds = UDS_ACCESS;
 		atom.m_long = 0;
@@ -594,7 +730,7 @@ bool KameraProtocol::cameraSupportsPreview(void)
 
 int KameraProtocol::readCameraFolder(const QString &folder, CameraList *dirList, CameraList *fileList)
 {
-	kdDebug() << "KameraProtocol::readCameraFolder(" << folder << ")" << endl;
+	kdDebug(7123) << "KameraProtocol::readCameraFolder(" << folder << ")" << endl;
 
 	int gpr;
 	if((gpr = gp_camera_folder_list_folders(m_camera, tocstr(folder), dirList, m_context)) != GP_OK)
@@ -604,15 +740,37 @@ int KameraProtocol::readCameraFolder(const QString &folder, CameraList *dirList,
 	return GP_OK;
 }
 
-static void frontendProgressUpdate(
+void frontendProgressUpdate(
 	GPContext *context, unsigned int id, float current, void *data
 ) {
 	KameraProtocol *object = (KameraProtocol*)data;
 
-	object->processedSize((int)current); // hack: call slot directly 
+	// This code will get the last chunk of data retrieved from the
+	// camera and pass it to KIO, to allow progressive display
+	// of the downloaded photo.
+
+	const char *fileData;
+	long unsigned int fileSize;
+
+	// This merely returns us a pointer to gphoto's internal data
+	// buffer -- there's no expensive memcpy
+	if (!object->getFile())
+		return;
+	gp_file_get_data_and_size(object->getFile(), &fileData, &fileSize);
+	// make sure we're not sending zero-sized chunks (=EOF)
+	if (fileSize > 0) {
+		// XXX using assign() here causes segfault, prolly because
+		// gp_file_free is called before chunkData goes out of scope
+		QByteArray chunkDataBuffer;
+		chunkDataBuffer.setRawData(fileData + object->getFileSize(), fileSize - object->getFileSize());
+		object->data(chunkDataBuffer);
+		object->processedSize(fileSize);
+		chunkDataBuffer.resetRawData(fileData + object->getFileSize(), fileSize - object->getFileSize());
+		object->setFileSize(fileSize);
+	}
 }
 
-static unsigned int frontendProgressStart(
+unsigned int frontendProgressStart(
 	GPContext *context, float totalsize, const char *format, va_list args,
 	void *data
 ) {
@@ -624,11 +782,11 @@ static unsigned int frontendProgressStart(
 
 	char *status=new char[size+1];
 	vsnprintf(status, size, format, args);
-	
+
 	object->infoMessage(QString::fromLocal8Bit(status));
 	delete status;
 
-	object->totalSize((int)totalsize); // hack: call slot directly 
+	object->totalSize((int)totalsize); // hack: call slot directly
 
 	return GP_OK;
 }
@@ -643,7 +801,7 @@ static void frontendCameraStatus(GPContext *context, const char *format, va_list
 
 	char *status=new char[size+1];
 	vsnprintf(status, size, format, args);
-	
+
 	object->infoMessage(QString::fromLocal8Bit(status));
 	delete status;
 }
