@@ -12,15 +12,15 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <qcheckbox.h> 
-#include <qclipboard.h> 
+#include <qcheckbox.h>
+#include <qclipboard.h>
 #include <qfileinfo.h>
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qmessagebox.h>
 #include <qpaintdevice.h>
 #include <qpainter.h>
-#include <qprogressdialog.h> 
+#include <qprogressdialog.h>
 #include <qregexp.h>
 #include <qurl.h>
 #include <qvbox.h>
@@ -39,12 +39,12 @@
 #include <kprocess.h>
 
 
-
 #include "dviwin.h"
 #include "fontpool.h"
 #include "fontprogress.h"
 #include "infodialog.h"
 #include "optiondialog.h"
+#include "zoomlimits.h"
 
 
 //------ some definitions from xdvi ----------
@@ -70,7 +70,7 @@ QPainter foreGroundPaint; // QPainter used for text
 
 //------ now comes the dviWindow class implementation ----------
 
-dviWindow::dviWindow(double zoom, int mkpk, QWidget *parent, const char *name ) 
+dviWindow::dviWindow(double zoom, int mkpk, QWidget *parent, const char *name )
   : QWidget( parent, name )
 {
 #ifdef DEBUG_DVIWIN
@@ -81,7 +81,7 @@ dviWindow::dviWindow(double zoom, int mkpk, QWidget *parent, const char *name )
 
   setFocusPolicy(QWidget::StrongFocus);
   setFocus();
-  
+
   // initialize the dvi machinery
   dviFile                = 0;
 
@@ -100,7 +100,7 @@ dviWindow::dviWindow(double zoom, int mkpk, QWidget *parent, const char *name )
     kdError(4300) << "Could not allocate memory for the info dialog." << endl;
   } else {
     qApp->connect(font_pool, SIGNAL(MFOutput(QString)), info, SLOT(outputReceiver(QString)));
-    qApp->connect(font_pool, SIGNAL(fonts_info(class fontPool *)), info, SLOT(setFontInfo(class fontPool *)));
+    qApp->connect(font_pool, SIGNAL(fonts_info(fontPool *)), info, SLOT(setFontInfo(fontPool *)));
     qApp->connect(font_pool, SIGNAL(new_kpsewhich_run(QString)), info, SLOT(clear(QString)));
   }
 
@@ -111,11 +111,12 @@ dviWindow::dviWindow(double zoom, int mkpk, QWidget *parent, const char *name )
   paper_width           = 21.0; // set A4 paper as default
   paper_height          = 27.9;
   unshrunk_page_w       = int( 21.0 * basedpi/2.54 + 0.5 );
-  unshrunk_page_h       = int( 27.9 * basedpi/2.54 + 0.5 ); 
+  unshrunk_page_h       = int( 27.9 * basedpi/2.54 + 0.5 );
   PostScriptOutPutString = NULL;
   HTML_href              = NULL;
   mane                   = currwin;
   _postscript            = 0;
+  _showHyperLinks        = true;
   pixmap                 = 0;
   findDialog             = 0;
   findNextAction         = 0;
@@ -143,22 +144,22 @@ dviWindow::dviWindow(double zoom, int mkpk, QWidget *parent, const char *name )
 
   // In principle, this method should never be called with illegal
   // values for zoom. In principle.
-  if (zoom < KViewPart::minZoom/1000.0)
-    zoom = KViewPart::minZoom/1000.0;
-  if (zoom > KViewPart::maxZoom/1000.0)
-    zoom = KViewPart::maxZoom/1000.0;
+  if (zoom < ZoomLimits::MinZoom/1000.0)
+    zoom = ZoomLimits::MinZoom/1000.0;
+  if (zoom > ZoomLimits::MaxZoom/1000.0)
+    zoom = ZoomLimits::MaxZoom/1000.0;
   mane.shrinkfactor      = currwin.shrinkfactor = (double)basedpi/(xres*zoom);
   _zoom                  = zoom;
 
   PS_interface           = new ghostscript_interface(0.0, 0, 0);
-  // pass status bar messages through 
+  // pass status bar messages through
   connect(PS_interface, SIGNAL( setStatusBarText( const QString& ) ), this, SIGNAL( setStatusBarText( const QString& ) ) );
-  is_current_page_drawn  = 0;  
+  is_current_page_drawn  = 0;
 
   // Variables used in animation.
   animationCounter = 0;
   timerIdent       = 0;
-  
+
   resize(0,0);
 }
 
@@ -170,9 +171,9 @@ dviWindow::~dviWindow()
 
   if (info)
     delete info;
-
+  if (pixmap)
+    delete pixmap;
   delete PS_interface;
-
   if (dviFile)
     delete dviFile;
 
@@ -184,7 +185,7 @@ dviWindow::~dviWindow()
 
 void dviWindow::showInfo(void)
 {
-  if (info == 0) 
+  if (info == 0)
     return;
 
   info->setDVIData(dviFile);
@@ -199,11 +200,11 @@ void dviWindow::showInfo(void)
 void dviWindow::selectAll(void)
 {
   QString selectedText("");
-  for(int i = 0; i < num_of_used_textlinks; i++) {
+  for(unsigned int i = 0; i < textLinkList.size(); i++) {
     selectedText += textLinkList[i].linkText;
     selectedText += "\n";
   }
-  DVIselection.set(0, num_of_used_textlinks-1, selectedText);
+  DVIselection.set(0, textLinkList.size()-1, selectedText);
   update();
 }
 
@@ -246,7 +247,7 @@ void dviWindow::setMetafontMode( unsigned int mode )
     KMessageBox::sorry( this,
 			i18n("The change in Metafont mode will be effective "
 			     "only after you start kdvi again!") );
-  
+
   MetafontMode     = font_pool->setMetafontMode(mode);
   basedpi          = MFResolutions[MetafontMode];
   _pixels_per_inch = MFResolutions[MetafontMode];  //@@@
@@ -265,7 +266,7 @@ void dviWindow::setPaper(double w, double h)
   paper_width      = w;
   paper_height     = h;
   unshrunk_page_w  = int( w * basedpi/2.54 + 0.5 );
-  unshrunk_page_h  = int( h * basedpi/2.54 + 0.5 ); 
+  unshrunk_page_h  = int( h * basedpi/2.54 + 0.5 );
   page_w           = (int)(unshrunk_page_w / mane.shrinkfactor  + 0.5) + 2;
   page_h           = (int)(unshrunk_page_h / mane.shrinkfactor  + 0.5) + 2;
   font_pool->reset_fonts();
@@ -314,9 +315,9 @@ void dviWindow::drawPage()
     foreGroundPaint.end();
     QApplication::restoreOverrideCursor();
     if (errorMsg.isEmpty() != true) {
-      KMessageBox::detailedError(this, 
+      KMessageBox::detailedError(this,
 				 i18n("<qt><strong>File corruption!</strong> KDVI had trouble interpreting your DVI file. Most "
-				      "likely this means that the DVI file is broken.</qt>"), 
+				      "likely this means that the DVI file is broken.</qt>"),
 				 errorMsg, i18n("DVI File error"));
       return;
     }
@@ -333,19 +334,19 @@ void dviWindow::drawPage()
       KConfig *config = kapp->config();
       KConfigGroupSaver saver( config, "Notification Messages" );
       bool showMsg = config->readBoolEntry( "KDVI-info_on_source_specials", true);
-      
+
       if (showMsg) {
 	KDialogBase *dialog= new KDialogBase(i18n("KDVI: Information"), KDialogBase::Yes, KDialogBase::Yes, KDialogBase::Yes,
 					     this, "information", true, true, i18n("&OK"));
-	
+
 	QVBox *topcontents = new QVBox (dialog);
 	topcontents->setSpacing(KDialog::spacingHint()*2);
 	topcontents->setMargin(KDialog::marginHint()*2);
-	
+
 	QWidget *contents = new QWidget(topcontents);
 	QHBoxLayout * lay = new QHBoxLayout(contents);
 	lay->setSpacing(KDialog::spacingHint()*2);
-	
+
 	lay->addStretch(1);
 	QLabel *label1 = new QLabel( contents);
 	label1->setPixmap(QMessageBox::standardIcon(QMessageBox::Information));
@@ -367,7 +368,7 @@ void dviWindow::drawPage()
 	dialog->incInitialSize( extraSize );
 	dialog->exec();
 	delete dialog;
-	
+
 	showMsg = !checkbox->isChecked();
 	if (!showMsg) {
 	  KConfigGroupSaver saver( config, "Notification Messages" );
@@ -387,17 +388,21 @@ bool dviWindow::correctDVI(QString filename)
   QFile f(filename);
   if (!f.open(IO_ReadOnly))
     return FALSE;
+
+  unsigned char test[4];
+  if ( f.readBlock( (char *)test,2)<2 || test[0] != 247 || test[1] != 2 )
+    return FALSE;
+
   int n = f.size();
   if ( n < 134 )	// Too short for a dvi file
     return FALSE;
   f.at( n-4 );
 
-  char test[4];
   unsigned char trailer[4] = { 0xdf,0xdf,0xdf,0xdf };
 
-  if ( f.readBlock( test, 4 )<4 || strncmp( test, (char *) trailer, 4 ) )
+  if ( f.readBlock( (char *)test, 4 )<4 || strncmp( (char *)test, (char *) trailer, 4 ) )
     return FALSE;
-  // We suppose now that the dvi file is complete	and OK
+  // We suppose now that the dvi file is complete and OK
   return TRUE;
 }
 
@@ -452,8 +457,8 @@ bool dviWindow::setFile(QString fname, QString ref, bool sourceMarker)
   if (!fi.exists() || fi.isDir()) {
     KMessageBox::error( this,
 			i18n("<qt><strong>File error!</strong> The specified file '%1' does not exist. "
-			     "KDVI already tried to add the ending '.dvi'</qt>").arg(filename), 
-			i18n("File error!"));
+			     "KDVI already tried to add the ending '.dvi'</qt>").arg(filename),
+			i18n("File Error!"));
     return false;
   }
 
@@ -464,7 +469,7 @@ bool dviWindow::setFile(QString fname, QString ref, bool sourceMarker)
   QString mimetype( KMimeMagic::self()->findFileType( fname )->mimeType() );
   if (mimetype != "application/x-dvi") {
     KMessageBox::sorry( this,
-			i18n( "<qt>Could not open file <nobr><strong>%1</strong></nobr> which has " 
+			i18n( "<qt>Could not open file <nobr><strong>%1</strong></nobr> which has "
 			      "type <strong>%2</strong>. KDVI can only load DVI (.dvi) files.</qt>" )
 			.arg( fname )
 			.arg( mimetype ) );
@@ -476,15 +481,15 @@ bool dviWindow::setFile(QString fname, QString ref, bool sourceMarker)
   if ((dviFile_new->dvi_Data == NULL)||(dviFile_new->errorMsg.isEmpty() != true)) {
     QApplication::restoreOverrideCursor();
     if (dviFile_new->errorMsg.isEmpty() != true)
-      KMessageBox::detailedError(this, 
+      KMessageBox::detailedError(this,
 				 i18n("<qt>File corruption! KDVI had trouble interpreting your DVI file. Most "
-				      "likely this means that the DVI file is broken.</qt>"), 
-				 dviFile_new->errorMsg, i18n("DVI File error"));
+				      "likely this means that the DVI file is broken.</qt>"),
+				 dviFile_new->errorMsg, i18n("DVI File Error"));
     delete dviFile_new;
     return false;
   }
-    
-  
+
+
   if (dviFile)
     delete dviFile;
   dviFile = dviFile_new;
@@ -498,23 +503,24 @@ bool dviWindow::setFile(QString fname, QString ref, bool sourceMarker)
   // specials in PostScriptDirectory, and the headers in the
   // PostScriptHeaderString.
   PS_interface->clear();
-  
+
   // We will also generate a list of hyperlink-anchors in the
   // document. So declare the existing list empty.
   numAnchors = 0;
+  sourceHyperLinkAnchors.clear();
 
   if (dviFile->page_offset == 0)
     return false;
 
   for(current_page=0; current_page < dviFile->total_pages; current_page++) {
     PostScriptOutPutString = new QString();
-    
+
     if (current_page < dviFile->total_pages) {
       command_pointer = dviFile->dvi_Data + dviFile->page_offset[current_page];
       end_pointer     = dviFile->dvi_Data + dviFile->page_offset[current_page+1];
     } else
       command_pointer = end_pointer = 0;
-    
+
     memset((char *) &currinf.data, 0, sizeof(currinf.data));
     currinf.fonttable = tn_table;
     currinf._virtual  = NULL;
@@ -554,94 +560,49 @@ void dviWindow::all_fonts_loaded(void)
     return;
   }
 
+
   // case 2: The reference is of form "src:1111Filename", where "1111"
   // points to line number 1111 in the file "Filename". KDVI then
   // looks for source specials of the form "src:xxxxFilename", and
   // tries to find the special with the biggest xxxx
   if (reference.find("src:",0,false) == 0) {
-    Q_INT32 page = 0;
-    Q_INT32 y    = -1000;
-    bool    sourceSpecialsFlag = false;
     QString ref = reference.mid(4);
-    
-    // Extract the file name and the numeral part from the string
-    unsigned int i;
+    // Extract the file name and the numeral part from the reference string
+    Q_UINT32 i;
     for(i=0;i<ref.length();i++)
       if (!ref.at(i).isNumber())
 	break;
     Q_UINT32 refLineNumber = ref.left(i).toUInt();
-    QString  fileName   = QFileInfo(ref.mid(i)).absFilePath();
-
-    bool _postscript_sav = _postscript;
-    int current_page_sav = current_page;
-    _postscript = FALSE; // Switch off postscript to speed up things...
-    QProgressDialog progress( i18n("Searching for position corresponding to line %1 in %2.").arg(ref.left(i)).arg(fileName), 
-			      i18n("Abort"), dviFile->total_pages, this, "search_reference_progress", TRUE );
-    progress.setMinimumDuration(300);
-    QPixmap pixie(1,1);
-
-    for(current_page=0; current_page < dviFile->total_pages; current_page++) {
-      progress.setProgress( current_page );
-      // Funny. The manual to QT tells us that we need to call
-      // qApp->processEvents() regularly to keep the application from
-      // freezing. However, the application crashes immediately if we
-      // uncomment the following line and works just fine as it is. Wild
-      // guess: Could that be related to the fact that we are linking
-      // against qt-mt?
-      
-      // qApp->processEvents();
-      
-      if ( progress.wasCancelled() )
-	break;
-      
-      foreGroundPaint.begin( &pixie );
-      draw_page(); // We gracefully ingore any errors (bad dvi-file, etc.) which may occur during draw_page()
-      foreGroundPaint.end();
-      if (num_of_used_source_hyperlinks > 0)
-	sourceSpecialsFlag = true;
-      for(int i=0; i<num_of_used_source_hyperlinks; i++) {
-	QString sourceLink = sourceHyperLinkList[i].linkText;
-	// Extract the file name and the numeral part from the string
-	unsigned int j;
-	for(j=0;j<sourceLink.length();j++)
-	  if (!sourceLink.at(j).isNumber())
-	    break;
-	Q_UINT32 sourceLineNumber = sourceLink.left(j).toUInt();
-	QString  sourceFileName   = QFileInfo(sourceLink.mid(j).stripWhiteSpace()).absFilePath();
-	if (fileName.stripWhiteSpace() == sourceFileName.stripWhiteSpace()) {
-	  if (refLineNumber >= sourceLineNumber) {
-	    page = current_page;
-	    y    = sourceHyperLinkList[i].box.top();
-	  } else
-	    break;
-	}
-      }
-    }
-    progress.setProgress( dviFile->total_pages ); // Switch off the progress dialog, etc.
-    _postscript = _postscript_sav; // Restore the PostScript setting 
+    QString  refFileName   = QFileInfo(ref.mid(i)).absFilePath();
     
-    // Restore the current page.
-    current_page = current_page_sav;
-    foreGroundPaint.begin( &pixie );
-    draw_page();  // We gracefully ingore any errors (bad dvi-file, etc.) which may occur during draw_page()
-    foreGroundPaint.end();
-    
-    reference = QString::null;
-    if (sourceSpecialsFlag == false) {
+    if (sourceHyperLinkAnchors.isEmpty()) {
       KMessageBox::sorry(this, i18n("<qt>You have asked KDVI to locate the place in the DVI file which corresponds to "
 				    "line %1 in the TeX-file <strong>%2</strong>. It seems, however, that the DVI file "
 				    "does not contain the necessary source file information. "
 				    "We refer to the manual of KDVI for a detailed explanation on how to include this "
-				    "information. Press the F1 key to open the manual.</qt>").arg(ref.left(i)).arg(fileName),
-			 i18n( "Could not find reference" ));
+				    "information. Press the F1 key to open the manual.</qt>").arg(ref.left(i)).arg(refFileName),
+			 i18n( "Could not Find Reference" ));
       return;
     }
+    
+    Q_INT32 page = 0;
+    Q_INT32 y    = -1000;
+    QValueVector<DVI_SourceFileAnchor>::iterator it;
+    for( it = sourceHyperLinkAnchors.begin(); it != sourceHyperLinkAnchors.end(); ++it )
+      if (refFileName.stripWhiteSpace() == it->fileName.stripWhiteSpace()) {
+	if (refLineNumber >= it->line) {
+	  page = it->page;
+	  y    = (Q_INT32)(it->vertical_coordinate/mane.shrinkfactor+0.5);
+	} 
+      }
+    
+    reference = QString::null;
     if (y >= 0)
       emit(request_goto_page(page, y));
     if (y < 0)
       KMessageBox::sorry(this, i18n("<qt>KDVI was not able to locate the place in the DVI file which corresponds to "
-				    "line %1 in the TeX-file <strong>%2</strong>.</qt>").arg(ref.left(i)).arg(fileName),
-			 i18n( "Could not find reference" ));
+				    "line %1 in the TeX-file <strong>%2</strong>.</qt>").arg(ref.left(i)).arg(refFileName),
+			 i18n( "Could not Find Reference" ));
     return;
   }
   reference = QString::null;
@@ -662,7 +623,7 @@ void dviWindow::gotoPage(unsigned int new_page)
   if ((new_page-1==current_page) &&  !is_current_page_drawn)
     return;
   current_page           = new_page-1;
-  is_current_page_drawn  = 0;  
+  is_current_page_drawn  = 0;
   animationCounter       = 0;
   drawPage();
 }
@@ -678,7 +639,7 @@ void dviWindow::gotoPage(int new_page, int vflashOffset)
   timerIdent       = startTimer(50); // Start the animation. The animation proceeds in 1/10s intervals
 }
 
-void dviWindow::timerEvent( QTimerEvent *e ) 
+void dviWindow::timerEvent( QTimerEvent *e )
 {
   animationCounter++;
   if (animationCounter >= 10) {
@@ -702,10 +663,10 @@ double dviWindow::setZoom(double zoom)
 {
   // In principle, this method should never be called with illegal
   // values. In principle.
-  if (zoom < KViewPart::minZoom/1000.0)
-    zoom = KViewPart::minZoom/1000.0;
-  if (zoom > KViewPart::maxZoom/1000.0)
-    zoom = KViewPart::maxZoom/1000.0;
+  if (zoom < ZoomLimits::MinZoom/1000.0)
+    zoom = ZoomLimits::MinZoom/1000.0;
+  if (zoom > ZoomLimits::MaxZoom/1000.0)
+    zoom = ZoomLimits::MaxZoom/1000.0;
 
   mane.shrinkfactor = currwin.shrinkfactor = basedpi/(xres*zoom);
   _zoom             = zoom;
@@ -733,7 +694,7 @@ void dviWindow::paintEvent(QPaintEvent *e)
 
     // Mark selected text.
     if (DVIselection.selectedTextStart != -1)
-      for(int i = DVIselection.selectedTextStart; (i <= DVIselection.selectedTextEnd)&&(i < num_of_used_textlinks); i++) {
+      for(unsigned int i = DVIselection.selectedTextStart; (i <= DVIselection.selectedTextEnd)&&(i < textLinkList.size()); i++) {
 	p.setPen( NoPen );
 	p.setBrush( white );
 	p.setRasterOp( Qt::XorROP );
@@ -748,13 +709,15 @@ void dviWindow::mouseMoveEvent ( QMouseEvent * e )
   if ( e->state() == 0 ) {
     for(int i=0; i<num_of_used_hyperlinks; i++) {
       if (hyperLinkList[i].box.contains(e->pos())) {
+	emit setStatusBarText( hyperLinkList[i].linkText );
 	setCursor(pointingHandCursor);
 	return;
       }
     }
+    emit setStatusBarText( QString::null );
     setCursor(arrowCursor);
   }
-  
+
   // Right mouse button pressed -> Text copy function
   if ((e->state() & RightButton) != 0) {
     if (selectedRectangle.isEmpty()) {
@@ -767,13 +730,13 @@ void dviWindow::mouseMoveEvent ( QMouseEvent * e )
       int by = e->pos().y() > firstSelectedPoint.y() ? e->pos().y() : firstSelectedPoint.y();
       selectedRectangle.setCoords(lx,ty,rx,by);
     }
-    
+
     // Now that we know the rectangle, we have to find out which words
     // intersect it!
     Q_INT32 selectedTextStart = -1;
     Q_INT32 selectedTextEnd   = -1;
 
-    for(int i=0; i<num_of_used_textlinks; i++) 
+    for(unsigned int i=0; i<textLinkList.size(); i++)
       if ( selectedRectangle.intersects(textLinkList[i].box) ) {
 	if (selectedTextStart == -1)
 	  selectedTextStart = i;
@@ -782,7 +745,7 @@ void dviWindow::mouseMoveEvent ( QMouseEvent * e )
 
     QString selectedText("");
     if (selectedTextStart != -1)
-      for(int i = selectedTextStart; (i <= selectedTextEnd)&&(i < num_of_used_textlinks); i++) {
+      for(unsigned int i = selectedTextStart; (i <= selectedTextEnd)&&(i < textLinkList.size()); i++) {
 	selectedText += textLinkList[i].linkText;
 	selectedText += "\n";
       }
@@ -803,7 +766,7 @@ void dviWindow::mouseMoveEvent ( QMouseEvent * e )
 	int i2 = kMin(kMax(a,c),kMin(b,d));
 	int i3 = kMax(kMax(a,c),kMin(b,d));
 	int i4 = kMax(b,d);
-	
+
 	QRect box;
 	int i=i1;
 	while(i<i2) {
@@ -812,7 +775,7 @@ void dviWindow::mouseMoveEvent ( QMouseEvent * e )
 	  i++;
 	}
 
-	for(int i=i3; i<i4; i++) 
+	for(int i=i3; i<i4; i++)
 	  if (i != -1)
 	    box = box.unite(textLinkList[i].box);
 	DVIselection.set(selectedTextStart, selectedTextEnd, selectedText);
@@ -862,10 +825,11 @@ void dviWindow::mousePressEvent ( QMouseEvent * e )
 	  // the kfmclient seems to be MUCH safer.
 	  QUrl DVI_Url(dviFile->filename);
 	  QUrl Link_Url(DVI_Url, hyperLinkList[i].linkText, TRUE );
-	
-	  KShellProcess proc;
-	  proc << "kfmclient openURL " << Link_Url.toString();
-	  proc.start(KProcess::Block);
+
+          QStringList args;
+          args << "openURL";
+          args << Link_Url.toString();
+          kapp->kdeinitExec("kfmclient", args);
 	}
 	break;
       }
@@ -873,7 +837,7 @@ void dviWindow::mousePressEvent ( QMouseEvent * e )
 
   // Check if the mouse is pressed on a source-hyperlink
   if ((e->button() == MidButton) && (num_of_used_source_hyperlinks > 0))
-    for(int i=0; i<num_of_used_source_hyperlinks; i++) 
+    for(int i=0; i<num_of_used_source_hyperlinks; i++)
       if (sourceHyperLinkList[i].box.contains(e->pos())) {
 #ifdef DEBUG_SPECIAL
 	kdDebug(4300) << "Source hyperlink to " << sourceHyperLinkList[i].linkText << endl;
@@ -885,7 +849,7 @@ void dviWindow::mousePressEvent ( QMouseEvent * e )
 	for(i=0; i<max; i++)
 	  if (cp[i].isDigit() == false)
 	    break;
-	
+
 	// The macro-package srcltx gives a special like "src:99 test.tex"
 	// while MikTeX gives "src:99test.tex". KDVI tries
 	// to understand both.
@@ -900,7 +864,7 @@ void dviWindow::mousePressEvent ( QMouseEvent * e )
 	  if ( !fi3.exists() ) {
 	    KMessageBox::sorry(this, i18n("The DVI-file refers to the TeX-file "
 					  "<strong>%1</strong> which could not be found.").arg(KShellProcess::quote(TeXfile)),
-			       i18n( "Could not find file" ));
+			       i18n( "Could not Find File" ));
 	    return;
 	  }
 	}
@@ -911,19 +875,19 @@ void dviWindow::mousePressEvent ( QMouseEvent * e )
 								"Please choose your favourite editor in the "
 								"<strong>DVI options dialog</strong> "
 								"which you will find in the <strong>Settings</strong>-menu."),
-						     i18n("Need to specify editor"),
-		                                     i18n("Use KDE's editor Kate for now"));
+						     i18n("Need to Specify Editor"),
+		                                     i18n("Use KDE's Editor Kate for Now"));
 	  if (r == KMessageBox::Continue)
 	    command = "kate %f";
 	  else
 	    return;
 	}
-	command = command.replace( QRegExp("%l"), cp.left(i) ).replace( QRegExp("%f"), KShellProcess::quote(TeXfile) ); 
-	
+	command = command.replace( QRegExp("%l"), cp.left(i) ).replace( QRegExp("%f"), KShellProcess::quote(TeXfile) );
+
 #ifdef DEBUG_SPECIAL
 	kdDebug(4300) << "Calling program: " << command << endl;
 #endif
-	
+
 	// There may still be another program running. Since we don't
 	// want to mix the output of several programs, we will
 	// henceforth dimiss the output of the older programm. "If it
@@ -933,7 +897,7 @@ void dviWindow::mousePressEvent ( QMouseEvent * e )
 	  qApp->disconnect(proc, SIGNAL(receivedStdout(KProcess *, char *, int)), 0, 0);
 	  proc = 0;
 	}
-	
+
 	// Set up a shell process with the editor command.
 	proc = new KShellProcess();
 	if (proc == 0) {
@@ -944,7 +908,7 @@ void dviWindow::mousePressEvent ( QMouseEvent * e )
 	qApp->connect(proc, SIGNAL(receivedStdout(KProcess *, char *, int)), this, SLOT(dvips_output_receiver(KProcess *, char *, int)));
 	qApp->connect(proc, SIGNAL(processExited(KProcess *)), this, SLOT(editorCommand_terminated(KProcess *)));
 	// Merge the editor-specific editor message here.
-	export_errorString = i18n("<qt>The external program<br/><br/><tt><strong>%1</strong></tt><br/><br/>which was used to call the editor "
+	export_errorString = i18n("<qt>The external program<br><br><tt><strong>%1</strong></tt><br/><br/>which was used to call the editor "
 				  "for inverse search, reported an error. You might wish to look at the <strong>document info "
 				  "dialog</strong> which you will find in the File-Menu for a precise error report. The "
 				  "manual for KDVI contains a detailed explanation how to set up your editor for use with KDVI, "
@@ -957,7 +921,7 @@ void dviWindow::mousePressEvent ( QMouseEvent * e )
 	flashOffset      = e->y(); // Heuristic correction. Looks better.
 	timerIdent       = startTimer(50); // Start the animation. The animation proceeds in 1/10s intervals
 
-	
+
 	proc->clearArguments();
 	*proc << command;
 	proc->closeStdin();
