@@ -100,7 +100,7 @@ class font *fontPool::appendx(char *fontname, long checksum, Q_INT32 scale, int
     if (strcmp(fontname, fontp->fontname) == 0 && (int (fsize+0.5)) == (int)(fontp->fsize + 0.5)) {
       // if font is already in the list
       fontp->mark_as_used();
-      free(fontname);
+      delete [] fontname;
       return fontp;
     }
     fontp=fontList.next();
@@ -216,7 +216,7 @@ char fontPool::check_if_fonts_are_loaded(unsigned char pass)
   proc->clearArguments();
   *proc << "kpsewhich";
   *proc << QString("--dpi %1").arg(MFResolutions[MetafontMode]);
-  *proc << QString("--mode %1").arg(MFModes[MetafontMode]);
+  *proc << QString("--mode %1").arg(KShellProcess::quote(MFModes[MetafontMode]));
   // Enable automatic pk-font generation only in the second pass, and
   // only if the user expressidly asked for it.
   if ((makepk == 0) || (pass == 0))
@@ -229,10 +229,10 @@ char fontPool::check_if_fonts_are_loaded(unsigned char pass)
   while ( fontp != 0 ) {
     if ((fontp->flags & font::FONT_KPSE_NAME) == 0) {
       numFontsInJob++;
-      *proc << QString("%1.%2pk").arg(fontp->fontname).arg((int)(fontp->fsize + 0.5));
+      *proc << KShellProcess::quote(QString("%2.%1pk").arg((int)(fontp->fsize + 0.5)).arg(fontp->fontname));
       // In the first pass, we look also for virtual fonts.
       if (pass == 0)
-	*proc << QString("%1.vf").arg(fontp->fontname);
+	*proc << KShellProcess::quote(QString("%1.vf").arg(fontp->fontname));
       // In the second (last) pass, mark the font "looked up". As this
       // is the last chance that the filename could be found, we
       // ensure that if the filename is still not found now, we won't
@@ -282,7 +282,7 @@ void fontPool::kpsewhich_terminated(KProcess *)
     }
   }
 
-   delete proc;
+  delete proc;
   proc = 0;
 
   QStringList fileNameList = QStringList::split('\n', kpsewhichOutput);
@@ -357,8 +357,8 @@ void fontPool::kpsewhich_terminated(KProcess *)
 	KMessageBox::sorry( 0, nokps+body+metaf, title );
       else
 	if (makepk == 0) {
-	  if(KMessageBox::warningYesNo( 0, body+i18n("\nAutomatic font generation is switched off."), title, 
-				   i18n("Generate fonts now"), i18n("Continue without") ) == KMessageBox::Yes) {
+	  if(KMessageBox::warningYesNo( 0, body+i18n("\nAutomatic font generation is switched off."), title,
+				   i18n("Generate Fonts Now"), i18n("Continue Without") ) == KMessageBox::Yes) {
 	    KInstance *instance = new KInstance("kdvi");
 	    KConfig *config = instance->config();
 	    config->setGroup("kdvi");
@@ -370,8 +370,8 @@ void fontPool::kpsewhich_terminated(KProcess *)
 	} else
 	  KMessageBox::sorry( 0, body+metaf, title );
     }
-    
-    emit(fonts_have_been_loaded());
+    emit setStatusBarText(QString::null);
+    emit fonts_have_been_loaded();
   }
   return;
 }
