@@ -17,10 +17,11 @@
 #include "kviewpart.h"
 #include "optiondialog.h"
 #include "kdvi_multipage.h"
+#include "zoomlimits.h"
 
 extern "C"
 {
-  void *init_libkdvi()
+  void *init_kdvipart()
   {
     KGlobal::locale()->insertCatalogue("kviewshell");
     return new KDVIMultiPageFactory;
@@ -87,15 +88,15 @@ KDVIMultiPage::KDVIMultiPage(QWidget *parentWidget, const char *widgetName, QObj
   copyTextAction     = KStdAction::copy(window, SLOT(copyText()), actionCollection(), "copy_text");
   window->DVIselection.setAction(copyTextAction);
   selectAllAction    = KStdAction::selectAll(this, SLOT(doSelectAll()), actionCollection(), "edit_select_all");
-  new KAction(i18n("Enable All Warnings and Messages"), 0, this, SLOT(doEnableWarnings()), actionCollection(), "enable_msgs");
-  exportPSAction     = new KAction(i18n("PostScript"), 0, this, SLOT(doExportPS()), actionCollection(), "export_postscript");
-  exportPDFAction    = new KAction(i18n("PDF"), 0, this, SLOT(doExportPDF()), actionCollection(), "export_pdf");
-  exportTextAction   = new KAction(i18n("Text"), 0, this, SLOT(doExportText()), actionCollection(), "export_text");
+  new KAction(i18n("Enable All Warnings && Messages"), 0, this, SLOT(doEnableWarnings()), actionCollection(), "enable_msgs");
+  exportPSAction     = new KAction(i18n("PostScript..."), 0, this, SLOT(doExportPS()), actionCollection(), "export_postscript");
+  exportPDFAction    = new KAction(i18n("PDF..."), 0, this, SLOT(doExportPDF()), actionCollection(), "export_pdf");
+  exportTextAction   = new KAction(i18n("Text..."), 0, this, SLOT(doExportText()), actionCollection(), "export_text");
 
-  new KAction(i18n("&DVI Options"), 0, this, SLOT(doSettings()), actionCollection(), "settings_dvi");
-  new KAction(i18n("&Tip of the Day..."), 0, this, SLOT(showTip()), actionCollection(), "help_tipofday");
-  new KAction(i18n("About the KDVI plugin..."), 0, this, SLOT(about()), actionCollection(), "about_kdvi");
-  new KAction(i18n("Help on the KDVI plugin..."), 0, this, SLOT(helpme()), actionCollection(), "help_dvi");
+  new KAction(i18n("&DVI Options..."), 0, this, SLOT(doSettings()), actionCollection(), "settings_dvi");
+  new KAction(i18n("&Tip of the Day"), 0, this, SLOT(showTip()), actionCollection(), "help_tipofday");
+  new KAction(i18n("About the KDVI plugin"), 0, this, SLOT(about()), actionCollection(), "about_kdvi");
+  new KAction(i18n("Help on the KDVI plugin"), 0, this, SLOT(helpme()), actionCollection(), "help_dvi");
   new KAction(i18n("Report Bug in the KDVI plugin..."), 0, this, SLOT(bugform()), actionCollection(), "bug_dvi");
 
   setXMLFile("kdvi_part.rc");
@@ -131,10 +132,10 @@ bool KDVIMultiPage::openFile()
   bool r = window->setFile(m_file,url().ref());
   if (!r)
     emit setStatusBarText(QString::null);
-  window->changePageSize(); //  This also calles drawPage(); @@@
-
+  window->changePageSize(); //  This also calles drawPage();
   emit numberOfPages(window->totalPages());
   enableActions(r);
+
   return r;
 }
 
@@ -147,7 +148,6 @@ void KDVIMultiPage::jumpToReference(QString reference)
   }
 }
 
-
 void KDVIMultiPage::contents_of_dviwin_changed(void)
 {
   emit previewChanged(true);
@@ -186,17 +186,16 @@ void KDVIMultiPage::goto_page(int page, int y)
   else
     window->gotoPage(page+1);
   scrollView()->ensureVisible(scrollView()->width()/2, y );
-
   emit pageInfo(window->totalPages(), page );
 }
 
 
 double KDVIMultiPage::setZoom(double zoom)
 {
-  if (zoom < KViewPart::minZoom/1000.0)
-    zoom = KViewPart::minZoom/1000.0;
-  if (zoom > KViewPart::maxZoom/1000.0)
-    zoom = KViewPart::maxZoom/1000.0;
+  if (zoom < ZoomLimits::MinZoom/1000.0)
+    zoom = ZoomLimits::MinZoom/1000.0;
+  if (zoom > ZoomLimits::MaxZoom/1000.0)
+    zoom = ZoomLimits::MaxZoom/1000.0;
 
   double z = window->setZoom(zoom);
   scrollView()->resizeContents(window->width(), window->height());
@@ -344,11 +343,11 @@ void KDVIMultiPage::preferencesChanged()
   if ( makepk != window->makePK() )
     window->setMakePK( makepk );
 
-  int showPS = config->readNumEntry( "ShowPS", 1 );
+  int showPS = config->readBoolEntry( "ShowPS", true );
   if (showPS != window->showPS())
     window->setShowPS(showPS);
 
-  int showHyperLinks = config->readNumEntry( "ShowHyperLinks", 1 );
+  int showHyperLinks = config->readBoolEntry( "ShowHyperLinks", true );
   if (showHyperLinks != window->showHyperLinks())
     window->setShowHyperLinks(showHyperLinks);
 
