@@ -57,6 +57,7 @@
 #include <qglobal.h>
 #include "faxexpand.h"
 #include "version.h"
+#include "viewfax.h"
 
 #define VIEWFAXVERSION "2.3"
 
@@ -102,8 +103,6 @@ extern Window Win;
 extern int qwindow_width;
 extern int qwindow_height;
 
-extern void setstatusbarmem(int);
-extern void setfaxtitle(const QString& name);
 extern void kfaxerror(const QString& title, const QString& error);
 
 struct pagenode *firstpage, *lastpage, *thispage, *helppage, *auxpage;
@@ -112,12 +111,10 @@ struct pagenode defaultpage;
 Display *Disp;
 
 int Default_Screen;
-const char *ProgName;
 int verbose = 0;
 
 int abell = 1;			/* audio bell */
 int vbell = 0;			/* visual bell */
-int zfactor = 0;			/* zoom factor */
 bool have_cmd_opt = FALSE;
 
 size_t Memused = 0;		/* image memory usage */
@@ -149,33 +146,6 @@ static char Banner[] =
 "KFax comes with ABSOLUTELY NO WARRANTY; for details see the\n"
 "file \"COPYING\" in the distribution directory.\n";*/
 
-static KCmdLineOptions options[] =
-{
-   {"f", 0, 0 },
-   {"fine", 		I18N_NOOP("Fine resolution"), 0 },
-   {"n", 0, 0 },
-   {"normal", 		I18N_NOOP("Normal resolution"), 0 },
-   {"height", 		I18N_NOOP("Height (number of fax lines)"), 0 },
-   {"w", 0, 0 },
-   {"width", 		I18N_NOOP("Width (dots per fax line)"), 0 },
-   {"l", 0, 0 },
-   {"landscape", 	I18N_NOOP("Turn image 90 degrees (landscape mode)"), 0 },
-   {"u", 0, 0 },
-   {"upsidedown", 	I18N_NOOP("Turn image upside down"), 0 },
-   {"i", 0, 0 },
-   {"invert", 		I18N_NOOP("Invert black and white."), 0 },
-   {"m", 0, 0 },
-   {"mem <bytes>", 	I18N_NOOP("Limit memory use to 'bytes'."), "8M" },
-   {"r", 0, 0 },
-   {"reverse", 		I18N_NOOP("Fax data is packed lsb first"), 0 },
-   {"2" , 		I18N_NOOP("Raw files are g3-2d"), 0 },
-   {"4",	 	I18N_NOOP("Raw files are g4"), 0 },
-   {"+file(s)", 	I18N_NOOP("Fax file(s) to show"), 0 },
-   { 0, 0, 0 },
-};
-
-#define MAXZOOM	10
-
 XEvent Event;
 XImage *Image, *Images[MAXZOOM];
 XSizeHints size_hints;
@@ -184,12 +154,6 @@ Time Lasttime = 0;
 
 struct pagenode *viewpage = 0;  
 
-void
-viewfax_addCmdLineOptions()
-{
-  KCmdLineArgs::addCmdLineOptions( options );
-}
-
 int viewfaxmain()
 {
     int banner = 0;
@@ -202,8 +166,6 @@ int viewfaxmain()
     /* TODO Do I need to know this: */
     defaultpage.expander = g31expand;
 
-    ProgName = "KFax";
-
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
     if (args->isSet("height"))
@@ -798,8 +760,6 @@ void FreeImage(XImage *Image){
        Image);*/
   }
     XDestroyImage(Image);
-    setstatusbarmem(Memused);
-
 }
 
 #ifndef xmalloc
