@@ -190,7 +190,6 @@ static const char * const dsc_scan_section_name[15] = {
  "EOF"
 };
 
-
 /******************************************************************/
 /* Public functions                                               */
 /******************************************************************/
@@ -973,9 +972,13 @@ dsc_read_line(CDSC *dsc)
 	     */
 	    char begindata[MAXSTR+1];
 	    int cnt;
+            unsigned int num;
 	    const char *numberof, *bytesorlines;
-	    memcpy(begindata, dsc->line, dsc->line_length);
-	    begindata[dsc->line_length] = '\0';
+            if ((num = dsc->line_length) >= sizeof(begindata)-1)
+                num = sizeof(begindata)-1;
+ 
+            memcpy(begindata, dsc->line, num);
+            begindata[num] = '\0';
 	    numberof = strtok(begindata+12, " \r\n");
 	    strtok(NULL, " \r\n");	/* dump type */
 	    bytesorlines = strtok(NULL, " \r\n");
@@ -2313,7 +2316,7 @@ dsc_private int
 dsc_check_match_prompt(CDSC *dsc, const char *str, int count)
 {
     if (count != 0) {
-	char buf[MAXSTR+MAXSTR];
+	char buf[MAXSTR+MAXSTR] = "";
 	if (dsc->line_length < (unsigned int)(sizeof(buf)/2-1))  {
 	    strncpy(buf, dsc->line, dsc->line_length);
 	    buf[dsc->line_length] = '\0';
