@@ -76,8 +76,8 @@ KGVMiniWidget::KGVMiniWidget( KGVPart* part, const char* name ) :
     _psWidget = 0;
 
     _magnification = 1;
-    _fixedMagnifications << 0.125 << 0.25 << 0.5 << 1 << 1.25 << 1.50
-                         << 2 << 4 << 8;
+    _fixedMagnifications << 0.125 << 0.25 << 0.3333 << 0.5 << 0.6667 << 0.75 
+                         << 1 << 1.25 << 1.50 << 2 << 3 << 4 << 6 << 8;
      
     KLocale locale( "kghostview" );
     _fallBackPageMedia = pageSizeToString( 
@@ -115,7 +115,10 @@ KGVMiniWidget::KGVMiniWidget( KGVPart* part, const char* name ) :
 KGVMiniWidget::~KGVMiniWidget()
 {
     if( mGotoDialog != 0 )
+    {
 	delete mGotoDialog;
+    	mGotoDialog = 0;
+    }
     reset();
 }
 
@@ -205,6 +208,7 @@ void KGVMiniWidget::doOpenFile()
 	return;
     }
     else if( _mimetype == "application/postscript" 
+          || _mimetype == "application/illustrator" 
           || _mimetype == "image/x-eps" 
 	  || _mimetype == "text/plain" )
     {
@@ -217,7 +221,7 @@ void KGVMiniWidget::doOpenFile()
 	KMessageBox::sorry( _part->widget(),
 	        i18n( "<qt>Could not open <nobr><strong>%1</strong></nobr> "
 	              "which has type <strong>%2</strong>. KGhostview can "
-	              "only load Postscript (.ps, .eps) and Portable "
+	              "only load PostScript (.ps, .eps) and Portable "
 	              "Document Format (.pdf) files.</qt>" )
 		      .arg( _fileName )
 		      .arg( _mimetype ) );
@@ -396,6 +400,7 @@ void KGVMiniWidget::reset()
     if( _psFile )
     {
         fclose( _psFile );
+	_psFile = 0;
     }
     
     clearTemporaryFiles();
@@ -417,18 +422,13 @@ void KGVMiniWidget::setPSWidget( KPSWidget* psWidget )
 
 void KGVMiniWidget::goToPage()
 {
-    /*
-  //printf ("goToPage()\n");
   if (mGotoDialog==0)
     {
-      mGotoDialog = new GotoDialog( this, "goto", false );
+      mGotoDialog = new GotoDialog( _part->widget(), "goto", false );
       connect( mGotoDialog, SIGNAL(gotoPage(int)), this, SLOT(goToPage(int)) );
     }
 
-  mGotoDialog->setup(GotoDialogData(_currentPage+1,
-				    num_parts+1, pages_in_part));
   mGotoDialog->show();
-  */
 
 }
 
@@ -465,10 +465,26 @@ void KGVMiniWidget::zoomOut()
     QValueList<double>::ConstIterator it = _fixedMagnifications.begin();
     while( it != _fixedMagnifications.end() && *it < magnification() ) ++it;
    
-    if( it != _fixedMagnifications.begin() )
+    if( it != _fixedMagnifications.begin() ) 
         setMagnification( *(--it) );
 }
 
+bool KGVMiniWidget::atMaxZoom() const
+{
+    QValueList<double>::ConstIterator it = _fixedMagnifications.begin();
+    while( it != _fixedMagnifications.end() && *it <= magnification() ) ++it;
+    
+    return (it == _fixedMagnifications.end());
+}
+
+bool KGVMiniWidget::atMinZoom() const
+{
+    QValueList<double>::ConstIterator it = _fixedMagnifications.begin();
+    while( it != _fixedMagnifications.end() && *it < magnification() ) ++it;
+   
+    return (it == _fixedMagnifications.begin());
+}
+
 /*
 void KGVMiniWidget::fitWidth( unsigned int width )
 {
@@ -834,29 +850,39 @@ bool KGVMiniWidget::convertFromPDF( const QString& saveFileName,
                                     unsigned int firstPage,
                                     unsigned int lastPage )
 {
-    QString cmd = QString( "gs -q -dNOPAUSE -dBATCH -dSAFER -sDEVICE=pswrite "
-		           "-sOutputFile=\"%1\" -dFirstPage=%2 -dLastPage=%3 -c save "
-		           "pop -f \"%4\"" )
-                  .arg( QFile::encodeName( saveFileName ) )
-                  .arg( firstPage )
-		  .arg( lastPage )
-                  .arg( QFile::encodeName( _pdfFileName ) );
-
-    /*
-    QString cmd = QString( "pdftops -f %1 -l %2 \"%3\" \"%4\"" )
-                   .arg( firstPage )
-	           .arg( lastPage )
-	           .arg( QFile::encodeName( _pdfFileName ) )
-	           .arg( QFile::encodeName( saveFileName ) );
-    */
-    
     // TODO -- timeout/fail on this conversion (it can hang on a bad pdf)
     // TODO -- use output from gs (leave out -q) to drive a progress bar
 
-    kdDebug(4500) << "Executing command: " << cmd.local8Bit() << endl;
-    int r = system( cmd.local8Bit() );
+    KProcess process;
+    process << _interpreterPath
+            << "-q"
+            << "-dNOPAUSE"
+            << "-dBATCH"
+            << "-dSAFER"
+            << "-sDEVICE=pswrite"
+            << ( QCString("-sOutputFile=")+QFile::encodeName(saveFileName) )
+            << ( QString("-dFirstPage=")+QString::number( firstPage ) )
+            << ( QString("-dLastPage=")+QString::number( lastPage ) )
+            << "-c"
+            << "save"
+            << "pop"
+            << "-f"
+            << QFile::encodeName(_pdfFileName);
 
-    if( r ) {
+    /*QValueList<QCString> args = process.args();
+    QValueList<QCString>::Iterator it = args.begin();
+    for ( ; it != args.end() ; ++it )
+        kdDebug() << ( *it ) << endl;*/
+
+    if( !process.start( KProcess::Block ) )
+    {
+	kdError() << "convertFromPDF: Couldn't start gs process" << endl;
+	// TODO -- error message (gs not found?)
+	return false;
+    }
+    if ( !process.normalExit() || process.exitStatus() != 0 )
+    {
+	kdError() << "convertFromPDF: normalExit=" << process.normalExit() << " exitStatus=" << process.exitStatus() << endl;
 	// TODO -- error message (can't open, strerr())
 	return false;
     }
@@ -1060,20 +1086,36 @@ bool KGVMiniWidget::savePages( const QString& saveFileName,
 	return true;
     
     if( _format == PDF ) 
-    {	
+    {
 	KTempFile psSaveFile( QString::null, ".ps" );
 	psSaveFile.setAutoDelete( true );
 	if( psSaveFile.status() != 0 )
 	    return false;
+
+	// Find the minimum and maximum pagenumber in pageList.
+	int minPage = pageList.first(), maxPage = pageList.first();
+	for( PageList::const_iterator ci = pageList.begin();
+	     ci != pageList.end(); ++ci )
+	{
+	    minPage = QMIN( *ci, minPage );
+	    maxPage = QMAX( *ci, maxPage );
+	}
+	
+	// Convert the pages in the range [minPage,maxPage] from PDF to
+	// PostScript.
 	if( !convertFromPDF( psSaveFile.name(), 
-	                     pageList.first(), pageList.last() ) )
+	                     minPage, maxPage ) )
 	    return false;
 
+	// The page minPage in the original file becomes page 1 in the 
+	// converted file. We still have to select the desired pages from
+	// this file, so we need to take into account that difference.
 	PageList normedPageList;
 	transform( pageList.begin(), pageList.end(),
 	           back_inserter( normedPageList ),
-	           bind2nd( minus<int>(), pageList.first() - 1 ) );
+	           bind2nd( minus<int>(), minPage - 1 ) );
 	
+	// Finally select the desired pages from the converted file.
 	psCopyDoc( psSaveFile.name(), saveFileName, normedPageList );
     }
     else
@@ -1115,7 +1157,7 @@ bool KGVMiniWidget::psCopyDoc( const QString& inputFile,
 	KMessageBox::sorry( 0,
 		i18n( "Printing failed because the list of "
 				"pages to be printed was empty." ),
-			  i18n( "Error printing" ) );
+			  i18n( "Error Printing" ) );
 	return false;
     }
 
@@ -1146,7 +1188,8 @@ bool KGVMiniWidget::psCopyDoc( const QString& inputFile,
 	    free( comment );
 	    continue;
 	}
-	sscanf( comment + length("%%Pages:" ), "%s", text );
+	sscanf( comment + length("%%Pages:" ), "%256s", text );
+	text[256] = 0; // Just in case of an overflow
 	if( strcmp( text, "(atend)" ) == 0 ) {
 	    fputs( comment, to );
 	    pages_atend = true;
