@@ -182,6 +182,15 @@ public:
      */
     bool atLastPage()  const;
 
+    /**
+     * Return true if we're zoomed in fully, false otherwise.
+     */
+    bool atMaxZoom() const;
+    /**
+     * Return true if we're zoomed out fully, false otherwise.
+     */
+    bool atMinZoom()  const;
+
     int currentPage() const { return _currentPage; }
     
 public slots:
