@@ -46,7 +46,7 @@
 
 #define PAGELIST_WIDTH 75
 
-K_EXPORT_COMPONENT_FACTORY( libkghostview, KGVFactory );
+K_EXPORT_COMPONENT_FACTORY( libkghostviewpart, KGVFactory );
 
 KGVPart::KGVPart( QWidget* parentWidget, const char*, 
                   QObject* parent, const char* name,
@@ -136,7 +136,7 @@ KGVPart::KGVPart( QWidget* parentWidget, const char*,
     //-- File Menu ----------------------------------------------------------
     KStdAction::saveAs( miniWidget(), SLOT( saveAs() ), 
                         actionCollection() );
-    new KAction( i18n( "Document &Info..." ), 0,
+    new KAction( i18n( "Document &Info" ), 0,
                  miniWidget(), SLOT( info() ),
                  actionCollection(), "info" );
 
@@ -159,9 +159,9 @@ KGVPart::KGVPart( QWidget* parentWidget, const char*,
     connect( _selectMedia, SIGNAL( activated( int ) ),
              this, SLOT( slotMedia( int ) ) );
 
-    _zoomIn  = KStdAction::zoomIn( _docManager,  SLOT( zoomIn() ),
+    _zoomIn  = KStdAction::zoomIn( this,  SLOT( slotZoomIn() ),
                                    actionCollection(), "zoomIn" );
-    _zoomOut = KStdAction::zoomOut( _docManager,  SLOT( zoomOut() ),
+    _zoomOut = KStdAction::zoomOut( this,  SLOT( slotZoomOut() ),
 			            actionCollection(), "zoomOut" );
 
     /*
@@ -174,24 +174,20 @@ KGVPart::KGVPart( QWidget* parentWidget, const char*,
                                     actionCollection(), "prevPage" );
     _nextPage  = KStdAction::next( this, SLOT( slotNextPage() ),
                                    actionCollection(), "nextPage" );
-    _firstPage = new KAction( i18n( "Go to Start" ), "start",
-                              CTRL+Key_Home, this, SLOT( slotGotoStart() ),
-                              actionCollection(), "goToStart" );
-    _lastPage  = new KAction( i18n( "Go to End" ), "finish",
-                              CTRL+Key_End, this, SLOT( slotGotoEnd() ),
-                              actionCollection(), "goToEnd" );
+    _firstPage = KStdAction::firstPage( this, SLOT( slotGotoStart() ),
+                                   actionCollection(), "goToStart" );
+    _lastPage  = KStdAction::lastPage( this, SLOT( slotGotoEnd() ),
+                                   actionCollection(), "goToEnd" );
     _readUp    = new KAction( i18n( "Read up Document" ), "previous",
                               SHIFT+Key_Space, this, SLOT( slotReadUp() ),
                               actionCollection(), "readUp" );
     // don't specify Key_Space as Accel, it breaks the lineedit in konq! (Simon)
-    _readDown  = new KAction( i18n( "Read down Document" ), "next",
+    _readDown  = new KAction( i18n( "Read Down Document" ), "next",
                               /*Key_Space*/0, this, SLOT( slotReadDown() ),
                               actionCollection(), "readDown" );
 
-    /*
     _gotoPage = KStdAction::gotoPage( _docManager, SLOT( goToPage() ),
                                       actionCollection(), "goToPage" );
-    */
 
     //-- PageMarks Menu -----------------------------------------------------
     new KAction( i18n( "Mark Current Page" ), "flag", CTRL+Key_M,
@@ -225,7 +221,7 @@ KGVPart::KGVPart( QWidget* parentWidget, const char*,
     _showPageList   = new KToggleAction( i18n( "Show &Page List" ), 0,
                                 this, SLOT( slotShowMarkList() ),
                                 actionCollection(), "show_page_list" );
-    _showPageLabels = new KToggleAction( i18n("Show Page Labels"), 0,
+    _showPageLabels = new KToggleAction( i18n("Show Page &Labels"), 0,
                                 this, SLOT( slotShowPageLabels() ),
                                 actionCollection(), "show_page_labels" );
     new KAction( i18n( "&Configure KGhostView..." ), "configure", 0,
@@ -259,12 +255,12 @@ KAboutData* KGVPart::createAboutData()
 {
     KAboutData* about = new KAboutData( "kghostview", I18N_NOOP( "KGhostView"), 
             KGHOSTVIEW_VERSION, 
-            I18N_NOOP( "Viewer for Postscript (.ps, .eps) and Portable Document Format (.pdf) files."), 
+            I18N_NOOP( "Viewer for PostScript (.ps, .eps) and Portable Document Format (.pdf) files."), 
             KAboutData::License_GPL,
             "(C) 1998 Mark Donohoe, (C) 1999-2000 David Sweet, "
             "(C) 2000-2001 Wilco Greven",
             I18N_NOOP( "KGhostView displays, prints, and saves "
-                       "Postscript and PDF files.\n"
+                       "PostScript and PDF files.\n"
                        "Based on original work by Tim Theisen." ) );
     about->addAuthor( "Wilco Greven",
                       I18N_NOOP( "Current maintainer" ),
@@ -421,6 +417,15 @@ void KGVPart::slotFitWidth()
 }
 */
 
+void KGVPart::updateZoomActions()
+{
+    if( !_isDocumentOpen ) 
+	return;
+
+    _zoomIn->setEnabled(!_docManager->atMaxZoom());
+    _zoomOut->setEnabled(!_docManager->atMinZoom());
+}
+
 void KGVPart::updatePageDepActions()
 {
     if( !_isDocumentOpen ) 
@@ -531,7 +536,10 @@ void KGVPart::slotOpenFileCompleted()
 	stateChanged( "documentState" );
 	connect( _pageView, SIGNAL( nextPage() ), SLOT( slotNextPage() ));
 	connect( _pageView, SIGNAL( prevPage() ), SLOT( slotPrevPage() ));
-	_fileWatcher->addFile( m_file );
+        connect( _pageView, SIGNAL( zoomIn() ), SLOT( slotZoomIn() ));
+        connect( _pageView, SIGNAL( zoomOut() ), SLOT( slotZoomOut() ));
+	if ( !_fileWatcher->contains( m_file ) ) 
+	    _fileWatcher->addFile( m_file );
 	slotWatchFile();
 	emit completed();
     }
@@ -664,6 +672,18 @@ void KGVPart::slotShowPageLabels()
     _docManager->enablePageLabels( _showPageLabels->isChecked() );
 }
 
+void KGVPart::slotZoomIn()
+{
+    _docManager->zoomIn();
+    updateZoomActions();
+}
+
+void KGVPart::slotZoomOut()
+{
+    _docManager->zoomOut();
+    updateZoomActions();
+}
+
 
 KGVBrowserExtension::KGVBrowserExtension( KGVPart *parent ) :
     KParts::BrowserExtension( parent, "KGVBrowserExtension" )
