@@ -64,11 +64,13 @@ public slots:
     void scrollLeft();
     void scrollBottom();
     void scrollTop();
-   
+  
 signals:
     void viewSizeChanged( QSize size );
     void pageSizeChanged( QSize size );
     void nextPage();
+    void zoomOut();
+    void zoomIn();
     void prevPage();
     
 protected:
