@@ -1,4 +1,4 @@
-/** 
+/**
  * Copyright (C) 2000-2002 the KGhostView authors. See file AUTHORS.
  * 	
  * This program is free software; you can redistribute it and/or modify
@@ -40,19 +40,19 @@
 //TODO -- disable GUI when no file
 //TODO -- don't stay open when no file, go directly to KFileDialog
 
-KGVShell::KGVShell() : 
+KGVShell::KGVShell() :
     _tmpFile( 0 )
 {
     m_gvpart = new KGVPart( this, "kgvpart", this, "kgvpart" );
 
     /*---- File -----------------------------------------------------------*/
-    openact = 
-	    KStdAction::open( this, SLOT( slotFileOpen() ), 
+    openact =
+	    KStdAction::open( this, SLOT( slotFileOpen() ),
 			      actionCollection() );
-    recent = 
-	    KStdAction::openRecent( this, SLOT( openURL( const KURL& ) ), 
+    recent =
+	    KStdAction::openRecent( this, SLOT( openURL( const KURL& ) ),
 				    actionCollection() );
-	    KStdAction::print( m_gvpart->miniWidget(), SLOT( print() ), 
+	    KStdAction::print( m_gvpart->miniWidget(), SLOT( print() ),
 			       actionCollection() );
     (void)
 	    KStdAction::quit( this, SLOT( slotQuit() ), actionCollection() );
@@ -63,12 +63,12 @@ KGVShell::KGVShell() :
 	    new KAction( i18n( "&Fit to Page Width" ), 0, this,
 			 SLOT( slotFitToPage() ), actionCollection(),
 			 "fit_to_page");
-  
+
     /*---- Settings -------------------------------------------------------*/
-    showtoolbar = 
+    showtoolbar =
 	    KStdAction::showToolbar( this, SLOT(slotShowToolBar() ),
 				     actionCollection());
-    showstatusbar = 
+    showstatusbar =
 	    KStdAction::showStatusbar( this, SLOT(slotShowStatusBar() ),
 				       actionCollection());
 
@@ -100,14 +100,14 @@ KGVShell::KGVShell() :
 KGVShell::~KGVShell()
 {
     writeSettings();
-    
+
     if( _tmpFile )
     {
 	_tmpFile->setAutoDelete( true );
 	delete _tmpFile;
 	_tmpFile = 0;
     }
-    
+
     // delete m_gvpart;
 }
 
@@ -128,7 +128,7 @@ KGVShell::readProperties( KConfig *config )
     }
 }
 
-void 
+void
 KGVShell::saveProperties( KConfig* config )
 {
     config->writeEntry( "URL", m_gvpart->url().prettyURL() );
@@ -143,7 +143,7 @@ KGVShell::readSettings()
 
     showstatusbar->setChecked(!statusBar()->isHidden());
     showtoolbar->setChecked(!toolBar()->isHidden());
-    
+
     recent->loadEntries( KGlobal::config() );
 }
 
@@ -168,16 +168,16 @@ KGVShell::openURL( const KURL & url )
 
 void
 KGVShell::openStdin()
-{    
-    if( _tmpFile ) 
+{
+    if( _tmpFile )
     {
 	_tmpFile->setAutoDelete( true );
 	delete _tmpFile;
     }
- 
+
     _tmpFile = new KTempFile;
     _tmpFile->setAutoDelete( true );
-    
+
     if( _tmpFile->status() != 0 ) {
 	KMessageBox::error( this,
 		i18n( "Could not create temporary file: %1" )
@@ -215,8 +215,8 @@ void KGVShell::slotFileOpen()
 {
     KURL url = KFileDialog::getOpenURL( cwd, i18n(
 		    "*.ps *.ps.gz *.eps *.eps.gz *.pdf|All document files\n"
-		    "*.ps *.ps.gz|Postscript files\n"
-		    "*.eps *.eps.gz|Encapsulated Postscript files\n"
+		    "*.ps *.ps.gz|PostScript files\n"
+		    "*.eps *.eps.gz|Encapsulated PostScript files\n"
 		    "*.pdf|Portable Document Format files" ) );
 
     if( !url.isEmpty() )
