@@ -190,12 +190,10 @@ KPSWidget::KPSWidget( QWidget* parent, const char* name )
     _interpreterReady	 = false;
     _interpreterDisabled = false;
 
-#define GSATOM(name) (Atom) XInternAtom( x11Display(), name, false );
-    _Atoms.GHOSTVIEW        = GSATOM( "GHOSTVIEW" );
-    _Atoms.GHOSTVIEW_COLORS = GSATOM( "GHOSTVIEW_COLORS" );
-    _Atoms.NEXT             = GSATOM( "NEXT" );
-    _Atoms.PAGE             = GSATOM( "PAGE" );
-    _Atoms.DONE             = GSATOM( "DONE" );
+    const char* atomNames[] = { "GHOSTVIEW", "GHOSTVIEW_COLORS", 
+                                "NEXT", "PAGE", "DONE" };
+    XInternAtoms( x11Display(), const_cast<char**>( atomNames ), 
+                  5, false, _atoms );
 
     readSettings();
     setupWidget();
@@ -257,7 +255,7 @@ bool KPSWidget::nextPage()
 	e.xclient.type = ClientMessage;
 	e.xclient.display = x11Display();
 	e.xclient.window = _gsWindow;
-	e.xclient.message_type = _Atoms.NEXT;
+	e.xclient.message_type = _atoms[NEXT];
 	e.xclient.format = 32;
 
 	XSendEvent( x11Display(), _gsWindow, false, 0, &e );
@@ -469,7 +467,7 @@ void KPSWidget::setupWidget()
 	     boundingBox().urx(), boundingBox().ury(),
              _dpiX, _dpiY );
     XChangeProperty( x11Display(), winId(),
-                     _Atoms.GHOSTVIEW,
+                     _atoms[GHOSTVIEW],
                      XA_STRING, 8, PropModeReplace,
                      (unsigned char*)buf, strlen( buf ) );
 
@@ -478,7 +476,7 @@ void KPSWidget::setupWidget()
              (int)BlackPixel( x11Display(), DefaultScreen( x11Display() ) ),
              (int)WhitePixel( x11Display(), DefaultScreen( x11Display() ) ) );
     XChangeProperty( x11Display(), winId(),
-                     _Atoms.GHOSTVIEW_COLORS,
+                     _atoms[GHOSTVIEW_COLORS],
                      XA_STRING, 8, PropModeReplace,
                      (unsigned char*)buf, strlen( buf ) );
 
@@ -670,7 +668,7 @@ bool KPSWidget::x11Event( XEvent* e )
     {
 	_gsWindow = e->xclient.data.l[0];
 	
-	if( e->xclient.message_type == _Atoms.PAGE )
+	if( e->xclient.message_type == _atoms[PAGE] )
 	{
 	    kdDebug(4500) << "KPSWidget: received PAGE" << endl;
 	    _interpreterBusy = false;
@@ -678,7 +676,7 @@ bool KPSWidget::x11Event( XEvent* e )
 	    emit pageFinished();
 	    return true;
 	}
-	else if( e->xclient.message_type == _Atoms.DONE )
+	else if( e->xclient.message_type == _atoms[DONE] )
 	{
 	    kdDebug(4500) << "KPSWidget: received DONE" << endl;
 	    disableInterpreter();
