@@ -45,11 +45,15 @@ int main( int argc, char** argv )
     else {
 	KGVShell* shell = new KGVShell;
 	if( args->count() == 1 ) {
-	    if( QString( args->arg(0) ) == "-" )  
+	    if( QString( args->arg(0) ) == "-" ) {
 		shell->openStdin();
-	    else {
-		KURL url( QDir::currentDirPath() + "/", args->arg(0) );
-		shell->openURL( url );
+	    } else {
+                QFileInfo fi = QDir::current().absPath() +
+                               QDir::separator() +
+                               args->arg(0);
+		if (fi.exists())
+			shell->openURL( KURL::fromPathOrURL( fi.absFilePath() ) );
+		else shell->openURL( KURL::fromPathOrURL( args->arg(0) ));
 	    }
 	}
 	shell->show();
