@@ -23,7 +23,6 @@
 
 #include <qcursor.h>
 #include <qpointarray.h>
-#include <qtableview.h>
 #include <qdrawutil.h>
 #include <qbrush.h>
 #include <qpixmap.h>
@@ -35,11 +34,11 @@
 #include <qfileinfo.h>
 
 #include <kfiledialog.h> 
-#include <kapp.h>
+#include <kapplication.h>
 
 #include "utils.h"
 
-#define KArrayUint QArray<uint>
+#define KArrayUint QMemArray<uint>
 
 class KColorArray : public KArrayUint
 {
