@@ -158,7 +158,7 @@ KTemplateConfig::KTemplateConfig(QWidget *parent) : QWidget(parent)
 
   btadd = btremove = btedit = 0L;
 
-  QGroupBox* grp = new QGroupBox( i18n( "Templates:" ), this );
+  QGroupBox* grp = new QGroupBox( i18n( "Templates" ), this );
   templates = new KIconListBox( grp );
   connect( templates, SIGNAL( highlighted( int ) ), SLOT( checkSelection( int ) ) );
   connect( templates, SIGNAL(doubleClicked( QListBoxItem * ) ), SLOT( edit() ) );
@@ -169,17 +169,15 @@ KTemplateConfig::KTemplateConfig(QWidget *parent) : QWidget(parent)
   l->addSpacing( 10 );
   l->addWidget( templates );
 
-  tlist = new KIconTemplateContainer();
-
-  for( int i = 0; i < (int) tlist->count(); i++ )
-    templates->insertItem( new KIconListBoxItem( tlist->at( i ) ) );
+  for( unsigned int i = 0; i <  KIconTemplateContainer::self()->count(); i++ )
+    templates->insertItem( new KIconListBoxItem( *KIconTemplateContainer::self()->at( i ) ) ) ;
 
   KButtonBox *bbox = new KButtonBox( grp );
 
-  btadd = bbox->addButton( i18n( "&Add" ) );
+  btadd = bbox->addButton( i18n( "&Add..." ) );
   connect( btadd, SIGNAL( clicked() ), SLOT( add() ) );
 
-  btedit = bbox->addButton( i18n( "&Edit" ) );
+  btedit = bbox->addButton( i18n( "&Edit..." ) );
   connect( btedit, SIGNAL( clicked() ), SLOT( edit() ) );
   btedit->setEnabled( false );
 
@@ -195,25 +193,19 @@ KTemplateConfig::KTemplateConfig(QWidget *parent) : QWidget(parent)
 
 KTemplateConfig::~KTemplateConfig()
 {
-    delete tlist;
 }
 
 void KTemplateConfig::saveSettings()
 {
   kdDebug() << "KTemplateConfig::saveSettings" << endl;
+  
+  KIconTemplateContainer::self()->clear();
 
   for(int i = 0; i < (int)templates->count(); i++)
   {
-    if(!tlist->containsRef(templates->iconTemplate(i)))
-    {
-      KIconTemplate *it = new KIconTemplate;
-      it->path = templates->path(i);
-      it->title = templates->text(i);
-      tlist->append(it);
-      kdDebug() << "Name: " << templates->text(i) << "\nPath: " << templates->path(i) << endl;
-      kdDebug() << "Name: " << it->path << "\nPath: " << it->path << endl;
-    }
+      KIconTemplateContainer::self()->append(templates->iconTemplate(i));
   }
+  KIconTemplateContainer::self()->save();
   kdDebug() << "KTemplateConfig::saveSettings - done" << endl;
 
 }
@@ -244,10 +236,9 @@ void KTemplateConfig::add()
   KTemplateEditDlg dlg(this);
   if(dlg.exec())
   {
-    KIconTemplate *it = new KIconTemplate;
-    it->path = dlg.getPath();
-    it->title = dlg.getName();
-    //tlist->append(it);
+    KIconTemplate it;
+    it.path = dlg.getPath();
+    it.title = dlg.getName();
     templates->insertItem(new KIconListBoxItem(it));
   }
 }
@@ -260,16 +251,15 @@ void KTemplateConfig::edit()
   templates->item(templates->currentItem());
   if(dlg.exec())
   {
-    KIconTemplate *it=templates->iconTemplate(templates->currentItem());
-    int pos=templates->currentItem();
-    it->path = dlg.getPath();
-    it->title = dlg.getName();
+   
 
-    //refresh list
-    templates->clear();
-    for( int i = 0; i < (int) tlist->count(); i++ )
-        templates->insertItem( new KIconListBoxItem( tlist->at( i ) ) );
-    templates->setCurrentItem(pos);
+    //Edit the entry
+    KIconTemplate &it=templates->iconTemplate(templates->currentItem());
+    int pos=templates->currentItem();
+    it.path = dlg.getPath();
+    it.title = dlg.getName();
+    static_cast<KIconListBoxItem*>(templates->item(templates->currentItem()))->reloadIcon();
+    templates->update();
   }
 }
 
@@ -293,7 +283,7 @@ KBackgroundConfig::KBackgroundConfig( QWidget* parent )
 
   QVBoxLayout *mainLayout = new QVBoxLayout( this, 5 );
 
-  QGroupBox *grp1 = new QGroupBox( i18n( "Color or pixmap" ), this );
+  QGroupBox *grp1 = new QGroupBox( i18n( "Color or Pixmap" ), this );
   mainLayout->addWidget( grp1 );
 
   QGridLayout *grp1Layout = new QGridLayout( grp1, 3, 2, 15 );
@@ -426,7 +416,7 @@ KMiscConfig::KMiscConfig(QWidget *parent) : QWidget(parent)
 
   QBoxLayout *ml = new QVBoxLayout( this, 5 );
 
-  QGroupBox *grp1 = new QGroupBox( i18n( "Paste mode" ), this );
+  QGroupBox *grp1 = new QGroupBox( i18n( "Paste Mode" ), this );
   ml->addWidget(grp1);
 
   QBoxLayout *l1 = new  QVBoxLayout(grp1, 20);
