@@ -183,6 +183,11 @@ void KGridView::setAcceptDrop(bool a)
     paintDropSite();
 }
 
+void KGridView::checkClipboard()
+{
+     _grid->checkClipboard();
+}
+
 const QRect KGridView::viewRect()
 {
     int x, y, cx, cy;
@@ -796,11 +801,36 @@ void KIconEditGrid::checkClipboard()
   if(ok)
     emit clipboarddata(true);
   else
+  {
     emit clipboarddata(false);
+  }
 }
 
 QImage KIconEditGrid::clipboardImage(bool &ok)
 {
+  //###### Remove me later.
+  //Workaround Qt bug -- check whether format provided first.
+  //Code below is from QDragObject, to match the mimetype list....
+  
+  QStrList fileFormats = QImageIO::inputFormats();
+  fileFormats.first();
+  bool oneIsSupported = false;
+  while ( fileFormats.current() ) 
+  {
+    QCString format = fileFormats.current();
+    QCString type = "image/" + format.lower();	
+    if (kapp->clipboard()->data()->provides(type ) )
+    {
+      oneIsSupported = true;
+    }
+    fileFormats.next();
+  }
+  if (!oneIsSupported)
+  {
+     ok = false;
+     return QImage();
+  }
+  
   QImage image = kapp->clipboard()->image();
   ok = !image.isNull();
   if ( ok )
