@@ -1,3 +1,22 @@
+/***************************************************************************
+              kookaview.cpp  -  kookas visible stuff
+                             -------------------                                         
+    begin                : ?
+    copyright            : (C) 1999 by Klaas Freitag                         
+    email                : freitag@suse.de
+
+    $Id: kookaview.cpp,v 1.53 2002/10/11 12:22:28 freitag Exp $
+ ***************************************************************************/
+
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   * 
+ *                                                                         *
+ ***************************************************************************/
+
 #include "kookaview.h"
 #include "resource.h"
 #include "kscandevice.h"
@@ -6,7 +25,11 @@
 #include "img_saver.h"
 #include "kookapref.h"
 #include "imgnamecombo.h"
-
+#include "thumbview.h"
+#include "dwmenuaction.h"
+#if 0
+#include "paramsetdialogs.h"
+#endif
 #include <qlabel.h>
 #include <qpainter.h>
 #include <qlayout.h>
@@ -15,7 +38,7 @@
 #include <qpaintdevice.h>
 #include <qpaintdevicemetrics.h>
 #include <qpopupmenu.h>
-
+#include <qwidgetstack.h>
 
 #include <kurl.h>
 #include <krun.h>
@@ -30,60 +53,90 @@
 #include <kled.h>
 #include <kcombobox.h>
 #include <kaction.h>
+#include <kiconloader.h>
+#include <kshortcut.h>
+#include <kdockwidget.h>
+#include <qobject.h>
 
 #define PACKAGER_TAB 0
 #define PREVIEWER_TAB 1
 
 #define STARTUP_IMG_SELECTION   "SelectedImageOnStartup"
-#define STARTUP_SELECTED_PAGE   "TabWidgetPage"
-#define STARTUP_SCANPARAM_SIZES "ScanParamDialogSizes"
-#define STARTUP_VIEWER_SIZES    "ViewerSplitterSizes"
 
 
-KookaView::KookaView(QWidget *parent, const QCString& deviceToUse)
-    : QSplitter(parent)
+KookaView::KookaView( KDockMainWindow *parent, const QCString& deviceToUse)
+   : QObject(),
+     ocrFabric(0),
+     m_mainDock(0),
+     m_dockScanParam(0),
+     m_dockThumbs(0),
+     m_dockPackager(0),
+     m_dockRecent(0),
+     m_dockPreview(0)
 {
-
-   /* Another splitter for splitting the Packager Tree from the Scan Parameter */
-   ocrFabric = 0L;
+   KIconLoader *loader = KGlobal::iconLoader();
+   m_mainDock = parent->createDockWidget( "Kookas MainDock",
+			       loader->loadIcon( "folder_image", KIcon::Small ),
+			       0L, i18n("Image Viewer"));
+   m_mainDock->setEnableDocking(KDockWidget::DockNone );
+   m_mainDock->setDockSite(KDockWidget::DockCorner);
+   parent->setView( m_mainDock);
+   parent->setMainDockWidget( m_mainDock);
    
-   paramSplitter = new QSplitter( QSplitter::Vertical, this );
-   setOpaqueResize( false );
-   paramSplitter->setOpaqueResize( false );
-
-   /* An image canvas for the large image, right side */
-   
-   img_canvas  = new ImageCanvas( this );
+   img_canvas  = new ImageCanvas( m_mainDock );
    img_canvas->setMinimumSize(100,200);
    img_canvas->enableContextMenu(true);
+   m_mainDock->setWidget( img_canvas );
+
+   m_dockThumbs = parent->createDockWidget( "Thumbs",
+					    loader->loadIcon( "thumbnail", KIcon::Small ),
+					    0L,  i18n("Thumbnails"));
+   m_dockThumbs->setDockSite(KDockWidget::DockFullSite );
    
-   setResizeMode( img_canvas,    QSplitter::Stretch );
-   setResizeMode( paramSplitter, QSplitter::KeepSize);
-
-   /* Create a vbox to take the tabwidget and the the combobox */
-   QVBox *vbox = new QVBox( paramSplitter );
-   /* The Tabwidget to contain the preview and the packager */
-   tabw  = new QTabWidget( vbox, "TABWidget" );
+   /* thumbnail viewer widget */
+   m_thumbview = new ThumbView( m_mainDock );
+   m_dockThumbs->setWidget( m_thumbview );
+   m_dockThumbs->manualDock( m_mainDock, KDockWidget::DockLeft, 30 );
 
+   /* make the main dock widget */
    /* A new packager to contain the already scanned images */
-   packager = new ScanPackager( tabw );
-   {
-   }
-      
-   /* build up the Preview/Packager-Tabview */
-   tabw->insertTab( packager, i18n( "&Gallery"), PACKAGER_TAB );
-
-   tabw->setMinimumSize(100, 100);
+   m_dockPackager = parent->createDockWidget( "Scanpackager",
+					    loader->loadIcon( "palette_color", KIcon::Small ),
+					    0L, i18n("Gallery"));
+   m_dockPackager->setDockSite(KDockWidget::DockFullSite);
+   packager = new ScanPackager( m_dockPackager );
+   m_dockPackager->setWidget( packager );
+   m_dockPackager->manualDock( m_mainDock,              // dock target
+                         KDockWidget::DockLeft, // dock site
+                         30 );                  // relation target/this (in percent)
 
+   connect( packager, SIGNAL(showThumbnails( KFileTreeViewItem* )),
+	    this, SLOT( slShowThumbnails( KFileTreeViewItem* )));
+   connect( m_thumbview, SIGNAL( selectFromThumbnail( const KURL& )),
+	    packager, SLOT( slSelectImage(const KURL&)));
+   
    /*
     * Create a Kombobox that holds the last folders visible even on the preview page
     */
-   QHBox *recentBox = new QHBox( vbox );
+   m_dockRecent  = parent->createDockWidget( "Recent",
+				loader->loadIcon( "image", KIcon::Small ),
+				0L, i18n("Gallery Directories"));
+   
+   m_dockRecent->setDockSite(KDockWidget::DockFullSite);
+
+   
+   QHBox *recentBox = new QHBox( m_dockRecent );
    recentBox->setMargin(KDialog::marginHint());
-   QLabel *lab = new QLabel( i18n("Gallery"), recentBox );
+   QLabel *lab = new QLabel( i18n("Gallery:"), recentBox );
    lab->setSizePolicy( QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed) );
    recentFolder = new ImageNameCombo( recentBox );
 
+   m_dockRecent->setWidget( recentBox );
+   m_dockRecent->manualDock( m_dockPackager,              // dock target
+                         KDockWidget::DockBottom, // dock site
+                         5 );                  // relation target/this (in percent)
+
+
    
    connect( packager,  SIGNAL( galleryPathSelected( KFileTreeBranch*, const QString&)),
 	    recentFolder, SLOT( slotGalleryPathChanged( KFileTreeBranch*, const QString& )));
@@ -95,17 +148,33 @@ KookaView::KookaView(QWidget *parent, const QCString& deviceToUse)
 	    packager, SLOT(slotSelectDirectory( const QString& )));
    
    /* the object from the kscan lib to handle low level scanning */
-   sane = new KScanDevice( this );
-   Q_CHECK_PTR(sane);
-   // connect( sane, SIGNAL( sigCloseDevice()), this, SLOT( slCloseScanDevice()));
+   m_dockScanParam = parent->createDockWidget( "Scan Parameter",
+ 					     loader->loadIcon( "folder", KIcon::Small ),
+ 					     0L, i18n("Scan Parameter"));
+   //
+   m_dockScanParam->setDockSite(KDockWidget::DockFullSite);
 
+   m_dockScanParam->setWidget( 0 ); // later
+   sane = new KScanDevice( m_dockScanParam );
+   Q_CHECK_PTR(sane);
+
+   m_dockScanParam->manualDock( m_dockRecent,              // dock target
+   KDockWidget::DockBottom, // dock site
+   20 );                  // relation target/this (in percent)
+   m_dockScanParam->hide();
+   
+   
    /* select the scan device, either user or from config, this creates and assembles
     * the complete scanner options dialog
     * scan_params must be zero for that */
    scan_params = 0L;
    preview_canvas = 0L;
-   
-   preview_canvas = new Previewer( tabw );
+
+   m_dockPreview = parent->createDockWidget( "Preview ",
+					   loader->loadIcon( "viewmag", KIcon::Small ),
+					   0L, i18n("Scan Preview"));
+
+   preview_canvas = new Previewer( m_dockPreview );
    {
       preview_canvas->setMinimumSize( 100,100);
    	
@@ -113,26 +182,16 @@ KookaView::KookaView(QWidget *parent, const QCString& deviceToUse)
        * connections later
        */
    }
-   tabw->insertTab( preview_canvas, i18n("&Preview"), PREVIEWER_TAB );
-
+   m_dockPreview->setWidget( preview_canvas );
+   m_dockPreview->manualDock( m_dockPackager,              // dock target
+			    KDockWidget::DockCenter, // dock site
+			    100 );                  // relation target/this (in percent)
+   
+   
+   
    if( slSelectDevice(deviceToUse))
    {
-      /* If a scanner exists */
-
       /* Load from config which tab page was selected last time */
-      KConfig *konf = KGlobal::config ();
-      konf->setGroup(GROUP_STARTUP);
-      QString startup = konf->readEntry( STARTUP_SELECTED_PAGE, "nothing" );
-      if( startup == "previewer" )
-	 tabw->showPage(preview_canvas);
-      else
-	 tabw->showPage(packager);
-   }
-   else
-   {
-      /* If there is no scanner, disable the preview tab */
-      tabw->setTabEnabled( preview_canvas, false );
-      tabw->showPage( packager );
    }
 
    /* New image created after scanning */
@@ -147,11 +206,23 @@ KookaView::KookaView(QWidget *parent, const QCString& deviceToUse)
    connect( packager, SIGNAL( showImage( QImage* )),
             img_canvas, SLOT( newImage( QImage*)));
 
+   connect( packager, SIGNAL( aboutToShowImage(const KURL&)),
+	    this, SLOT( slStartLoading( const KURL& )));
+   
    /* Packager unloads the image */
    connect( packager, SIGNAL( unloadImage( QImage* )),
             img_canvas, SLOT( deleteView( QImage*)));
 
+   /* a image changed mostly through a image manipulation method like rotate */
+   connect( packager, SIGNAL( fileChanged( KFileItem* )),
+	    m_thumbview, SLOT( slImageChanged( KFileItem* )));
 
+   connect( packager, SIGNAL( fileDeleted( KFileItem* )),
+	    m_thumbview, SLOT( slImageDeleted( KFileItem* )));
+   
+   m_mainDock->setDockSite( KDockWidget::DockFullSite );
+
+   packager->openRoots();
 }
 
 
@@ -196,10 +267,11 @@ bool KookaView::slSelectDevice( const QCString& useDevice )
 	 slCloseScanDevice();
       }
       /* This connects to the selected scanner */
-      scan_params = new ScanParams( paramSplitter );
+      scan_params = new ScanParams( m_dockScanParam );
       Q_CHECK_PTR(scan_params);
-      paramSplitter->setResizeMode( scan_params, QSplitter::FollowSizeHint );
-
+      m_dockScanParam->setWidget( scan_params );
+      m_dockScanParam->show();
+      
       if( sane->openDevice( selDevice ) == KSCAN_OK )
       {
          connect( scan_params,    SIGNAL( scanResolutionChanged( int, int )),
@@ -222,6 +294,11 @@ bool KookaView::slSelectDevice( const QCString& useDevice )
 		     scan_params, SLOT(slMaximalScanSize()));
 	    // connect( scan_params,    SIGNAL( scanResolutionChanged( int, int )),
             // 		     preview_canvas, SLOT( slNewScanResolutions( int, int )));
+	    /* load the preview image */
+	    if( preview_canvas )
+	    {
+	       preview_canvas->loadPreviewImage( selDevice );
+	    }
 	 }
       }
       else
@@ -238,42 +315,6 @@ bool KookaView::slSelectDevice( const QCString& useDevice )
       if( scan_params )
 	 scan_params->connectDevice( 0L );
    }
-
-   KConfig *konf = KGlobal::config ();
-   QString referToScanner( sane->shortScannerName());
-   if( !haveConnection ) referToScanner = "gallery";
-
-   konf->setGroup( referToScanner );
-   QValueList<int> sizes = konf->readIntListEntry( STARTUP_SCANPARAM_SIZES );
-   QValueList<int> vsizes = konf->readIntListEntry( STARTUP_VIEWER_SIZES );
-   
-   if( sizes.count() == 0  )
-   {
-      kdDebug(28000) << "Setting default sizes" << endl;
-	 
-      /* Shitty, nothing yet in the config */
-      if( haveConnection )
-      {
-	 sizes << packager->height();
-	 sizes << scan_params->height();
-	 vsizes << (scan_params->sizeHint()).width();
-      }
-      else
-      {
-	 /* only push one value to vsizes */
-	 vsizes << 150;
-      }
-   }
-   kdDebug(28000) << "Setting sizes !" << endl;
-   setSizes( vsizes );
-   if( haveConnection )
-   {
-      paramSplitter->setSizes( sizes );
-
-      scan_params->show();
-      preview_canvas->loadPreviewImage( selDevice );
-   }
-
    return( haveConnection );
 }
 
@@ -404,7 +445,7 @@ void KookaView::slNewPreview( QImage *new_img )
       if( ! new_img->isNull() )
       {
 	 ImgSaveStat is_stat = ISS_OK;
-	 ImgSaver img_saver( this );
+	 ImgSaver img_saver( m_mainDock );
 
 	 is_stat = img_saver.savePreview( new_img, sane->shortScannerName() );
 
@@ -412,6 +453,11 @@ void KookaView::slNewPreview( QImage *new_img )
 	 {
 	    kdDebug(28000) << "ERROR in saving preview !" << endl;
 	 }
+	 else
+	 {
+	    /* flip preview to front */
+	    m_dockPreview->makeDockVisible();
+	 }
       }
       preview_canvas->newImage( new_img ); 
    }
@@ -479,7 +525,7 @@ void KookaView::startOCR( const QImage *img )
    if( img && ! img->isNull() )
    {
       if( ocrFabric == 0L )
-	 ocrFabric = new KSANEOCR(this );
+	 ocrFabric = new KSANEOCR( m_mainDock );
 
       Q_CHECK_PTR( ocrFabric );
       ocrFabric->setImage( img );
@@ -545,6 +591,8 @@ void KookaView::slCloseScanDevice( )
    if( scan_params ) {
       delete scan_params;
       scan_params = 0;
+      m_dockScanParam->setWidget(0L);
+      m_dockScanParam->hide();
    }
    sane->slCloseDevice();
 }
@@ -578,17 +626,17 @@ void KookaView::slRotateImage(int angle)
       switch( angle )
       {
 	 case 90:
-	    emit( signalChangeStatusbar( i18n("rotate image 90 degrees" )));
+	    emit( signalChangeStatusbar( i18n("Rotate image 90 degrees" )));
 	    resImg = rotateRight( img );
 	    break;
 	 case 180:
-	    emit( signalChangeStatusbar( i18n("rotate image 180 degrees" )));
+	    emit( signalChangeStatusbar( i18n("Rotate image 180 degrees" )));
 	    resImg = rotateRight( img );
 	    resImg = rotateRight( &resImg );
 	    break;
 	 case 270:
 	 case -90:
-	    emit( signalChangeStatusbar( i18n("rotate image -90 degrees" )));
+	    emit( signalChangeStatusbar( i18n("Rotate image -90 degrees" )));
 	    resImg = rotateLeft( img );
 
 	    break;
@@ -651,14 +699,31 @@ void KookaView::slMirrorImage( MirrorType m )
    }
 }
 
-void KookaView::slSaveScanParams( void )
+
+void KookaView::slLoadScanParams( )
+{
+   if( ! sane ) return;
+
+   /* not yet cooked */
+#if 0
+   LoadSetDialog loadDialog( m_mainDock, sane->shortScannerName() );
+   if( loadDialog.exec())
+   {
+      kdDebug(28000)<< "Executed successfully" << endl;
+   }
+#endif
+}
+
+void KookaView::slSaveScanParams( )
 {
    if( !sane ) return;
 
+   /* not yet cooked */
+#if 0
+
    KScanOptSet optSet( "SaveSet" );
    
    sane->getCurrentOptions( &optSet );
-#if 0
    SaveSetDialog dialog( this, &optSet );
    if( dialog.exec())
    {
@@ -668,11 +733,67 @@ void KookaView::slSaveScanParams( void )
 #endif
 }
 
+void KookaView::slShowThumbnails(KFileTreeViewItem *dirKfi, bool forceRedraw )
+{
+   /* If no item is specified, use the current one */
+   if( ! dirKfi )
+   {
+      /* do on the current visible dir */
+      KFileTreeViewItem *kftvi = packager->currentKFileTreeViewItem();
+      if( ! kftvi->isDir())
+	 kftvi = static_cast<KFileTreeViewItem*>(static_cast<QListViewItem*>(kftvi)->parent());
+      if( kftvi )
+      {
+	 dirKfi = kftvi;
+	 forceRedraw = true;
+	 packager->setSelected( static_cast<QListViewItem*>(dirKfi), true );
+      }
+   }
+
+   kdDebug(28000) << "Showing thumbs for " << dirKfi->url().prettyURL() << endl;	   
+
+   /* Only do the new thumbview if the old is on another dir */
+   if( m_thumbview && (forceRedraw || m_thumbview->currentDir() != dirKfi->url()) )
+   {
+      m_thumbview->clear();
+      /* Find a list of child KFileItems */
+      if( forceRedraw ) m_thumbview->readSettings();
+      
+      KFileItemList fileItemsList;
+
+      QListViewItem * myChild = dirKfi->firstChild();
+      while( myChild )
+      {
+         fileItemsList.append( static_cast<KFileTreeViewItem*>(myChild)->fileItem());
+         myChild = myChild->nextSibling();
+      }
+
+      m_thumbview->slNewFileItems( fileItemsList );
+      m_thumbview->setCurrentDir( dirKfi->url());
+      // m_thumbview->arrangeItemsInGrid();
+   }
+
+}
+
+/* this slot is called when the user clicks on an image in the packager
+ * and loading of the image starts
+ */
+void KookaView::slStartLoading( const KURL& url )
+{
+   emit( signalChangeStatusbar( i18n("Loading " ) + url.prettyURL()));
+
+   // if( m_stack->visibleWidget() != img_canvas )
+   // {
+   //    m_stack->raiseWidget( img_canvas );
+   // }
+
+}
+
 
 void KookaView::updateCurrImage( QImage& img )
 {
    emit( signalChangeStatusbar( i18n("Storing image changes" )));
-   packager->slotImageChanged( &img );
+   packager->slotCurrentImageChanged( &img );
    emit( signalCleanStatusbar());
 }
 
@@ -685,27 +806,11 @@ void KookaView::saveProperties(KConfig *config)
    config->writeEntry( STARTUP_IMG_SELECTION, packager->getCurrImageFileName(true));
 
    QString tabwPre = "packager";
-   int idx = tabw->currentPageIndex();
+   int idx = PREVIEWER_TAB; // FIXME !!
    kdDebug(28000) << "Idx ist" << idx << endl;
    if( idx == PREVIEWER_TAB )
       tabwPre = "previewer";
 
-   config->writeEntry( STARTUP_SELECTED_PAGE, tabwPre );
-
-   /* Save the scan parameters size in accordance to the selected scanner */
-   if( sane && scan_params )
-   {
-      config->setGroup( sane->shortScannerName());
-      QValueList<int> pssizes = paramSplitter->sizes();
-      config->writeEntry( STARTUP_SCANPARAM_SIZES, pssizes );
-   }
-   else
-   {
-      config->setGroup( "gallery" );
-   }
-   /* Sizes of the vertical splitter */
-   QValueList<int> vsizes = sizes();
-   config->writeEntry(STARTUP_VIEWER_SIZES, vsizes );
 }
 
 
@@ -841,5 +946,57 @@ void KookaView::connectViewerAction( KAction *action )
    }
 }
 
+void KookaView::connectGalleryAction( KAction *action )
+{
+   QPopupMenu *popup = packager->contextMenu();
+
+   if( popup && action )
+   {
+      action->plug( popup );
+   }
+}
+
+void KookaView::slFreshUpThumbView()
+{
+   if( m_thumbview )
+   {
+      /* readSettings returns true if something changes */
+      if( m_thumbview->readSettings() )
+      {
+	 kdDebug(28000) << "Thumbview-Settings changed, readraw thumbs" << endl;
+	 /* new settings */
+	 slShowThumbnails(0, true);
+      }
+   }
+}
+
+void KookaView::createDockMenu( KActionCollection *col, KDockMainWindow *mainWin, const char * name )
+{
+   KActionMenu *actionMenu = new KActionMenu( i18n("Tool Views"), "view_icon", col, name );
+
+   actionMenu->insert( new dwMenuAction( i18n("Show Image Viewer"),
+					 KShortcut(), m_mainDock, col,
+					 mainWin, "dock_viewer" ));
+
+   actionMenu->insert( new dwMenuAction( i18n("Show Preview"),
+					 KShortcut(), m_dockPreview, col,
+					 mainWin, "dock_preview" ));
+
+   actionMenu->insert( new dwMenuAction( i18n("Show Recent Gallery Folders"),
+					 KShortcut(), m_dockRecent, col,
+					 mainWin, "dock_recent" ));
+   actionMenu->insert( new dwMenuAction( i18n("Show Gallery"),
+					 KShortcut(), m_dockPackager, col,
+					 mainWin, "dock_gallery" ));
+
+   actionMenu->insert( new dwMenuAction( i18n("Show Thumbnail Window"),
+					 KShortcut(), m_dockThumbs, col,
+					 mainWin, "dock_thumbs" ));
+
+   actionMenu->insert( new dwMenuAction( i18n("Show Scan Parameters"),
+					 KShortcut(), m_dockScanParam, col,
+					 mainWin, "dock_scanparams" ));
+}
+
 
 #include "kookaview.moc"
