@@ -1,11 +1,11 @@
 /***************************************************************************
-                          scanpackager.cpp  -  description                              
-                             -------------------                                         
-    begin                : Fri Dec 17 1999                                           
-    copyright            : (C) 1999 by Klaas Freitag                         
+                          scanpackager.cpp  -  description
+                             -------------------
+    begin                : Fri Dec 17 1999
+    copyright            : (C) 1999 by Klaas Freitag
     email                : freitag@suse.de
 
-    $Id: scanpackager.cpp,v 1.45.2.1 2002/05/02 09:38:02 freitag Exp $   
+    $Id: scanpackager.cpp,v 1.68 2002/10/13 17:16:40 freitag Exp $
  ***************************************************************************/
 
 /***************************************************************************
@@ -13,7 +13,7 @@
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
@@ -23,6 +23,7 @@
 #include "img_saver.h"
 #include "kookaimage.h"
 #include "previewer.h"
+#include "devselector.h"
 
 #include <qapplication.h>
 #include <qdir.h>
@@ -42,6 +43,7 @@
 #include <kurldrag.h>
 #include <kpopupmenu.h>
 #include <kaction.h>
+#include <klineeditdlg.h>
 #include <kiconloader.h>
 #include <kfiledialog.h>
 #include <kurl.h>
@@ -54,16 +56,19 @@
 #include <kio/file.h>
 #include <kio/job.h>
 
-extern QDict<QPixmap> icons;
+#define STARTUP_FIRST_START "firstStart"
+
 
 /* ----------------------------------------------------------------------- */
 /* Constructor Scan Packager */
 ScanPackager::ScanPackager( QWidget *parent ) : KFileTreeView( parent )
 {
-   // TODO: setItemsRenameable (true );
+   // TODO:
+   setItemsRenameable (true );
+   setDefaultRenameAction( QListView::Reject );
    addColumn( i18n("Image Name" ));
    setColumnAlignment( 0, AlignLeft );
-	
+
    addColumn( i18n("Size") );
    setColumnAlignment( 1, AlignRight );
    setColumnAlignment( 2, AlignRight );
@@ -103,77 +108,74 @@ ScanPackager::ScanPackager( QWidget *parent ) : KFileTreeView( parent )
    /* Preload frequently used icons */
    KIconLoader *loader = KGlobal::iconLoader();
    m_floppyPixmap = loader->loadIcon( "3floppy_unmount", KIcon::Small );
-   m_grayPixmap = loader->loadIcon( "palette_gray", KIcon::Small );
-   m_bwPixmap = loader->loadIcon( "palette_lineart", KIcon::Small );
-   m_colorPixmap = loader->loadIcon( "palette_color", KIcon::Small );
+   m_grayPixmap   = loader->loadIcon( "palette_gray", KIcon::Small );
+   m_bwPixmap     = loader->loadIcon( "palette_lineart", KIcon::Small );
+   m_colorPixmap  = loader->loadIcon( "palette_color", KIcon::Small );
 
-	   
-   popup =0L;
-   /* open the image galleries */
-   openRoots();
+   m_startup = true;
+   
+   /* create a context menu and set the title */
+   m_contextMenu = new KPopupMenu();
+   static_cast<KPopupMenu*>(m_contextMenu)->insertTitle( i18n( "Gallery" ));
 
-   createMenus();
 }
 
 void ScanPackager::openRoots()
 {
-   /* First open the standard root */
-   QString localRoot = Previewer::galleryRoot();
-   
-   KURL rootUrl(localRoot);
-
    /* standard root always exists, ImgRoot creates it */
+   KURL rootUrl(Previewer::galleryRoot());
    kdDebug(28000) << "Open standard root " << rootUrl.url() << endl;
-   KIconLoader *loader = KGlobal::iconLoader();
-   
-   KFileTreeBranch *newbranch = addBranch( rootUrl, i18n("Kooka Gallery"),
-					   loader->loadIcon( "folder_image", KIcon::Small ),
-					   false /* do not showHidden */ );
-   setDirOnlyMode( newbranch, false );
-   newbranch->setShowExtensions( false );
 
-   newbranch->setOpenPixmap( loader->loadIcon( "folder_blue_open", KIcon::Small ));
-			 
-   connect( newbranch, SIGNAL(newTreeViewItems( KFileTreeBranch*, const KFileTreeViewItemList& )),
-	    this, SLOT( slotDecorate(KFileTreeBranch*, const KFileTreeViewItemList& )));
+   openRoot( rootUrl, true );
+   m_defaultBranch->setOpen(true);
 
-   connect( newbranch, SIGNAL( directoryChildCount( KFileTreeViewItem* , int )),
-	    this, SLOT( slotDirCount( KFileTreeViewItem *, int )));
-   
-   newbranch->setOpen(true);
-   
    /* open more configurable image repositories TODO */
-
-   /* select Incoming-Dir, TODO restore last selection ! */
-   KFileTreeViewItem *startit = findItem( newbranch, i18n( "Incoming/" ) );
-   
-   if( ! startit ) kdDebug(28000) << "No Start-Item found :(" << endl;
-   setCurrentItem( startit );
 }
 
-void ScanPackager::createMenus()
+KFileTreeBranch* ScanPackager::openRoot( const KURL& root, bool  )
 {
-   if( ! popup )
+   KIconLoader *loader = KGlobal::iconLoader();
+
+   /* working on the global branch. FIXME */
+   m_defaultBranch = addBranch( root, i18n("Kooka Gallery"),
+				loader->loadIcon( "folder_image", KIcon::Small ),
+				false /* do not showHidden */ );
+   
+   // Q_CHECK_PTR( m_defaultBranch );
+   m_defaultBranch->setOpenPixmap( loader->loadIcon( "folder_blue_open", KIcon::Small ));
+   
+   setDirOnlyMode( m_defaultBranch, false );
+   m_defaultBranch->setShowExtensions( true ); // false );
+   
+   connect( m_defaultBranch, SIGNAL( newTreeViewItems( KFileTreeBranch*, const KFileTreeViewItemList& )),
+	    this, SLOT( slotDecorate(KFileTreeBranch*, const KFileTreeViewItemList& )));
+
+   connect( m_defaultBranch, SIGNAL( directoryChildCount( KFileTreeViewItem* , int )),
+	    this, SLOT( slotDirCount( KFileTreeViewItem *, int )));
+   
+   connect( m_defaultBranch, SIGNAL( deleteItem( KFileItem* )),
+	    this, SLOT( slotDeleteFromBranch(KFileItem*)));
+
+   connect( m_defaultBranch, SIGNAL( populateFinished( KFileTreeViewItem * )),
+	    this, SLOT( slotStartupFinished( KFileTreeViewItem * )));
+
+
+   return( m_defaultBranch );
+}
+
+void ScanPackager::slotStartupFinished( KFileTreeViewItem *it )
+{
+   if( m_startup && (it == m_defaultBranch->root()) )
    {
-      popup = new KPopupMenu();
-      popup->insertTitle( i18n( "Gallery" ));
-      
-      KAction *newAct = new KAction(i18n("&Create Directory"), "folder_new",0 ,
-				    this, SLOT(slotCreateFolder()), this);
-      newAct->plug( popup );	
-      
-      newAct = new KAction(i18n("&Save Image"), "filesave",0 ,
-			   this, SLOT(slotExportFile()), this);
-      newAct->plug( popup );	
+      kdDebug(28000) << "Slot population finished hit!" << endl;
 
-      newAct = new KAction(i18n("&Delete Image"), "edittrash",0 ,
-			   this, SLOT(slotDeleteItems()), this);
-      newAct->plug( popup );	
+      /* If nothing is selected, select the root. */
+      if( ! currentKFileTreeViewItem() )
+      {
+	 (m_defaultBranch->root())->setSelected( true );
+      }
 
-      newAct = new KAction(i18n("&Unload Image"), "fileclose", 0,
-			   this, SLOT(slotUnloadItems()), this );
-      newAct->plug( popup );
-      popup->setCheckable( true );
+      m_startup = false;
    }
 }
 
@@ -181,7 +183,6 @@ void ScanPackager::slotDirCount( KFileTreeViewItem* item, int cnt )
 {
    if( item && item->isDir() )
    {
-      kdDebug(28000)<< "  ############## count " << cnt << " for " << item->url().prettyURL() << endl;
       QString cc = i18n( "%1 items").arg( cnt );
       item->setText( 1, cc );
    }
@@ -197,6 +198,7 @@ void ScanPackager::slotDecorate( KFileTreeViewItem* item )
    if( item->isDir())
    {
       // done in extra slot.
+      kdDebug(28000) << "Decorating directory!" << endl;
    }
    else
 
@@ -277,16 +279,71 @@ void ScanPackager::slotDecorate( KFileTreeBranch* branch, const KFileTreeViewIte
    {
       KFileTreeViewItem *kftvi = *it;
       slotDecorate( kftvi );
+      emit fileChanged( kftvi->fileItem() );
    }
 }
 
 
 
-void ScanPackager::slFileRename( QListViewItem* it, const QString& newStr, int col )
+void ScanPackager::slFileRename( QListViewItem* it, const QString& newStr, int )
 {
-   (void) it;
-   (void) newStr;
-   (void) col;
+
+   bool success = true;
+   if( !it ) return;
+
+   if( newStr.isEmpty() )
+      success = false;
+   
+   KFileTreeViewItem *item = static_cast<KFileTreeViewItem*>(it);
+
+   /* Free memory and imform everybody who is interested. */
+   KURL urlFrom = item->url();
+   KURL urlTo( urlFrom );
+
+   /* clean filename and apply new name */
+   urlTo.setFileName("");
+   urlTo.setFileName(newStr);
+
+   if( success )
+   {
+      if( urlFrom == urlTo )
+      {
+	 kdDebug(28000) << "Renaming to same url does not make sense!" << endl;
+	 success = false;
+      }
+      else
+      {
+	 /* clear selection, because the renamed image comes in through
+	  * kdirlister again
+	  */
+	 slotUnloadItem( item );
+
+	 kdDebug(28000) << "Renaming to " << urlTo.prettyURL() <<
+	    " from " << urlFrom.prettyURL() << endl;
+   
+	 /* to urlTo the really used filename is written */
+	 setSelected( item, false );
+	 if( ImgSaver::renameImage( urlFrom, urlTo, false, this ) )
+	 {      
+	    kdDebug(28000) << "renaming OK" << endl;
+	    success=true;
+	 }
+	 else
+	 {
+	    success = false;
+	 }
+      }
+   }
+
+   if( ! success )
+   {      
+      kdDebug(28000) << "renaming failed" << endl;
+      /* restore the name */
+      item->setText(0, urlFrom.fileName() );
+      setSelected( item, true );
+
+   }
+      
 }
 
 
@@ -325,7 +382,7 @@ QString ScanPackager::buildNewFilename( QString cmplFilename, QString currFormat
       /* new Ext. differs from the current extension. Later. */
       KMessageBox::sorry( 0L, i18n( "You entered a file extension that differs from the existing one. That is not yet possible. Converting 'on the fly' is planned for a future release.\n"
 				      "Kooka corrects the extension."),
-			  i18n("On the fly conversion"));
+			  i18n("On the Fly Conversion"));
       ext = base + "." + currFormat;
    }
    return( ext );
@@ -428,12 +485,14 @@ void ScanPackager::slSelectionChanged( QListViewItem *newItem )
       {
 	 kdDebug(28000) << "selectionChanged: Is a directory !" << endl;
 	 emit( showImage( 0L ));
+	 kdDebug(28000) << "emitting showThumbnails" << endl;
       }
       else
       {
 	 /* if not a dir, load the image if neccessary. This is done by loadImageForItem,
 	  * which is async( TODO ). The image finally arrives in slotImageArrived */
 	 QApplication::setOverrideCursor(waitCursor);
+	 emit( aboutToShowImage( item->url()));
 	 loadImageForItem( item );
 	 QApplication::restoreOverrideCursor();
       }
@@ -448,6 +507,15 @@ void ScanPackager::slSelectionChanged( QListViewItem *newItem )
 	 kdDebug(28000) << "Emitting " << relativUrl << " as new relative Url" << endl;
 	 /* Emit the signal with branch and the relative path */
 	 emit( galleryPathSelected( item->branch(), relativUrl ));
+
+	 if( item->isDir() )
+	 {
+	    emit( showThumbnails( item ));
+	 }
+	 else
+	 {
+	    emit( showThumbnails(  static_cast<KFileTreeViewItem*>(item->parent())));
+	 }
       }
       else
       {
@@ -462,23 +530,87 @@ void ScanPackager::slSelectionChanged( QListViewItem *newItem )
 
 void ScanPackager::loadImageForItem( KFileTreeViewItem *item )
 {
-
+   
    if( ! item ) return;
+   bool result = true;
    
-   KURL url = item->url();
+   KFileItem *kfi = item->fileItem();
+   if( ! kfi ) return;
    
-   if( url.isLocalFile() )
+   KookaImage *img = static_cast<KookaImage*>( kfi->extraData(this));
+
+   if( img )
    {
-      KookaImage *img = new KookaImage( ); 
-      if( img->load( localFileName(item) ) )
-      {
-	 slImageArrived( item, img );
-      }
+      kdDebug(28000) << "Image already loaded." << endl;
+      /* result is still true, image must be shown. */
    }
    else
    {
-      // TODO : non-local images.
-      kdDebug(28000) << "Non-local images: Not yet implemented!" << endl;
+      /* The image needs to be loaded. Possibly it is a multi-page image.
+       * If it is, the kookaImage has a subImageCount larger than one. We
+       * create an subimage-item for every subimage, but do not yet load
+       * them.
+       */
+      KURL url = item->url();
+   
+      img = new KookaImage( ); 
+      if( !img || !img->loadFromUrl( url ) )
+      {
+	 kdDebug(28000) << "Loading KookaImage from File failed!" << endl;
+	 result = false;
+      }
+      else
+      {
+	 /* care for subimages, create items for them */
+	 kdDebug(28000) << "subImage-count: " << img->subImagesCount() << endl;
+	 if( img->subImagesCount() > 1 )
+	 {
+	    KIconLoader *loader = KGlobal::iconLoader();
+	    kdDebug(28000) << "SubImages existing!" << endl;
+
+	    /* Start at the image with index 1, that makes  one less than are actually in the
+	     * image. But image 0 was already created above. */
+	    KFileTreeViewItem *prevItem=0;
+	    for( int i = 1; i < img->subImagesCount(); i++ )
+	    {
+	       kdDebug(28000) << "Creating subimage no " << i << endl;
+	       KFileItem *newKfi = new KFileItem( *kfi );
+	       KFileTreeViewItem *subImgItem = new KFileTreeViewItem( item, newKfi, item->branch());
+
+	       if( prevItem )
+	       {
+		  subImgItem->moveItem( prevItem );
+	       }
+	       prevItem = subImgItem;
+
+	       subImgItem->setPixmap( 0, loader->loadIcon( "editcopy", KIcon::Small ));
+	       subImgItem->setText( 0, i18n("Sub-image %1").arg( i ) );
+	       KookaImage  *subImgImg = new KookaImage( i, img );
+	    
+	       newKfi->setExtraData( (void*) this, (void*) subImgImg );
+	    }
+	 }
+      }
+   }
+
+   
+   if( result && img )
+   {
+      if( img->isSubImage() )
+      {
+	 kdDebug(28000) << "it _is_ a subimage" << endl;
+	 /* load if not loaded */
+	 if( img->isNull())
+	 {
+	    kdDebug(28000) << "extracting subimage" << endl;
+	    img->extractNow();
+	 }
+	 else
+	 {
+	    kdDebug(28000) << "Is not a null image" << endl;
+	 }
+      }
+      slImageArrived( item, img );
    }
 }
 
@@ -563,7 +695,7 @@ QString ScanPackager::localFileName( KFileTreeViewItem *it ) const
 }
 
 /* Called if the image exists but was changed by image manipulation func   */
-void ScanPackager::slotImageChanged( QImage *img )
+void ScanPackager::slotCurrentImageChanged( QImage *img )
 {
    KFileTreeViewItem *curr = currentKFileTreeViewItem();
    if( ! curr )
@@ -587,19 +719,19 @@ void ScanPackager::slotImageChanged( QImage *img )
    if( is_stat == ISS_ERR_FORMAT_NO_WRITE )
    {
       KMessageBox::error( this, i18n( "Cannot write this image format.\nImage will not be saved!"),
-			    i18n("Save error") );
+			    i18n("Save Error") );
    }
    else if( is_stat == ISS_ERR_PERM )
    {
       KMessageBox::error( this, i18n( "Image file is write protected.\nImage will not be saved!"),
-			    i18n("Save error") );
+			    i18n("Save Error") );
 
    }
    else if( is_stat == ISS_ERR_PROTOCOL )
    {
       KMessageBox::sorry( this, i18n( "Cannot save the image, because the file is local.\n"
 				      "Kooka will support other protocols later."),
-			    i18n("Save error") );
+			    i18n("Save Error") );
 
    }
    else if( is_stat != ISS_OK )
@@ -609,6 +741,7 @@ void ScanPackager::slotImageChanged( QImage *img )
 
    if( img && !img->isNull())
    {
+      emit( imageChanged( curr->fileItem()));
       KookaImage *newImage = new KookaImage(*img);
       slImageArrived( curr, newImage );
    }
@@ -656,12 +789,12 @@ void ScanPackager::slAddImage( QImage *img )
    if( is_stat == ISS_ERR_FORMAT_NO_WRITE )
    {
       KMessageBox::error( this, i18n( "Cannot write this image format.\nImage will not be saved!"),
-			    i18n("Save error") );
+			    i18n("Save Error") );
    }
    else if( is_stat == ISS_ERR_PERM )
    {
       KMessageBox::error( this, i18n( "Image file is write protected.\nImage will not be saved!"),
-			    i18n("Save error") );
+			    i18n("Save Error") );
 
    }
    else if( is_stat != ISS_OK )
@@ -685,15 +818,21 @@ void ScanPackager::slAddImage( QImage *img )
    kdDebug(28000) << "Updating directory with " << strdir << endl;
    
    if( kookaBranch ) kookaBranch->updateDirectory( KURL(strdir) );
-
    slotSetNextUrlToSelect( lurl );
-
+   
    QString s;
    /* Count amount of children of the father */
-   int childcount = curr->childCount();
-   s = i18n("%1 images").arg(childcount);
-   curr->setText( 1, s);
-   setOpen( curr, true );
+   QListViewItem *paps = curr->parent();
+   if( curr->isDir() ) /* take only father if the is no directory */
+      paps = curr;
+   
+   if( paps )
+   {
+      int childcount = paps->childCount();
+      s = i18n("%1 images").arg(childcount);
+      paps->setText( 1, s);
+      setOpen( paps, true );
+   }
 
 }
 
@@ -787,10 +926,10 @@ void ScanPackager::slShowContextMenue(QListViewItem *lvi, const QPoint &p, int c
 	 setSelected( curr, true );
    }
 
-   if( popup )
+   if( m_contextMenu )
    {
-      popup->move( p );
-      popup->show();
+      m_contextMenu->move( p );
+      m_contextMenu->show();
    }
 
 }
@@ -810,27 +949,21 @@ void ScanPackager::slotExportFile( )
    {
       KURL fromUrl( curr->url());
       QString filter = "*." + getImgFormat(curr).lower();
-      filter += "\n*|All Files";
+      filter += "\n*|" + i18n( "All Files" );
       
+      // initial += fromUrl.filename(false);
       QString initial = m_currCopyDir + "/";
       initial += fromUrl.filename(false);
       KURL fileName = KFileDialog::getSaveURL ( initial,
-                                                filter, this );
+						filter, this );
 
       if ( fileName.isValid() )                  // got a file name
       {
-	 
          if( fromUrl == fileName ) return;
-         copyjob = KIO::copy( curr->url(), fileName, false );
-         if( copyjob )
-         {
-	    
-	    storeJob( copyjob, curr, JobDescription::ExportJob );
-
-            connect( copyjob, SIGNAL(result(KIO::Job*)),
-                     this, SLOT(slotExportFinished( KIO::Job* )));
-         }
 
+	 /* Since it is asynchron, we will never get if it succeeded. */
+	 ImgSaver::exportImage( fromUrl, fileName );
+	 
          /* remember the filename for the next export */
 	 fileName.setFileName( QString());
 	 m_currCopyDir = fileName.url( );
@@ -898,10 +1031,30 @@ void ScanPackager::slotUnloadItem( KFileTreeViewItem *curr )
    {
       KFileItem *kfi = curr->fileItem();
       KookaImage *image = static_cast<KookaImage*>(kfi->extraData( this ));
-      emit( unloadImage( image ));
-      delete image;
-      kfi->removeExtraData( this );
-      slotDecorate( curr );
+
+      /* If image is zero, ok, than there is nothing to unload :) */
+      if( image )
+      {
+	 if( image->subImagesCount() > 0 )
+	 {
+	    KFileTreeViewItem *child = static_cast<KFileTreeViewItem*>(curr->firstChild());
+	 
+	    while( child )
+	    {
+	       KFileTreeViewItem *nextChild = 0;
+	       kdDebug(28000) << "Unloading subimage item " << child << endl;
+	       slotUnloadItem( child );
+	       nextChild = static_cast<KFileTreeViewItem*> (child->nextSibling());
+	       delete child;
+	       child = nextChild;
+	    }
+	 }
+      
+	 emit( unloadImage( image ));
+	 delete image;
+	 kfi->removeExtraData( this );
+	 slotDecorate( curr );
+      }
    }
 }
 
@@ -928,7 +1081,7 @@ void ScanPackager::slotDeleteItems( )
       {
 	 s = i18n("Do you really want to delete the folder %1\nand all the images inside?").arg("");
       }
-      result = KMessageBox::questionYesNo(this, s, i18n( "Delete collection item"),
+      result = KMessageBox::questionYesNo(this, s, i18n( "Delete Collection Item"),
 					  KStdGuiItem::yes(), KStdGuiItem::no(),
 					  "AskForDeleteFiles" );
    }
@@ -957,11 +1110,12 @@ void ScanPackager::slotDeleteItems( )
 /* ----------------------------------------------------------------------- */
 void ScanPackager::slotCreateFolder( )
 {
-   EntryDialog d( this, i18n("New Folder"), i18n("<B>Please enter a name for the new folder:</B>"));
-		  
-   if( d.exec() == QDialog::Accepted )
+   KLineEditDlg d(i18n("Please enter a name for the new folder:"), QString::null, this);
+   d.setCaption(i18n("New Folder"));
+
+   if( d.exec() )
    {
-      QString folder = d.getText();
+      QString folder = d.text();
       if( folder.length() > 0 )
       {
 	 /* KIO create folder goes here */
@@ -981,9 +1135,9 @@ void ScanPackager::slotCreateFolder( )
 	    /* Since the new directory arrives in the packager in the newItems-slot, we set a
 	     * variable urlToSelectOnArrive here. The newItems-slot will honor it and select
 	     * the treeviewitem with that url.
-	     */  
+	     */
 	    slotSetNextUrlToSelect( url );
-	       
+
 	    if( ! KIO::NetAccess::mkdir( url ))
 	    {
 	       kdDebug(28000) << "ERR: creation of " << url.prettyURL() << " failed !" << endl;
@@ -992,7 +1146,7 @@ void ScanPackager::slotCreateFolder( )
 	    {
 	       /* created successfully */
 	       /* open the branch if neccessary and select the new folder */
-	       
+
 	    }
 	 }
       }
@@ -1015,4 +1169,34 @@ ScanPackager::~ScanPackager(){
       kdDebug(29000) << "Destructor of ScanPackager" << endl;
 
 }
+
+/* called whenever one branch detects a deleted file */
+void ScanPackager::slotDeleteFromBranch( KFileItem* kfi )
+{
+   emit fileDeleted( kfi );
+}
+
+void ScanPackager::contentsDragMoveEvent( QDragMoveEvent *e )
+{
+   if( !e || ! acceptDrag( e ) )
+   {
+      e->ignore();
+      return;
+   }
+
+   QListViewItem *item = 0;
+   QListViewItem *par = 0;
+
+   findDrop( e->pos(), par, item );
+
+   if( item )
+   {
+      bool isDir = static_cast<KFileTreeViewItem*> (item)->isDir();
+      if( isDir )
+	 KFileTreeView::contentsDragMoveEvent( e );
+   }
+
+}
+
+
 #include "scanpackager.moc"
