@@ -10,8 +10,9 @@ class AreaSelect : public Tool
 {
 Q_OBJECT
 public:
-AreaSelect(const QString & toolname);
-  /*  virtual ~AreaSelect(); */
+  AreaSelect(const QString & toolname);
+  const char* pixmap() const;
+
   virtual void mousePressEvent(QMouseEvent *e);
   virtual void mouseMoveEvent(QMouseEvent *e);
   virtual void mouseReleaseEvent(QMouseEvent *e);
@@ -24,7 +25,6 @@ protected:
   virtual void activating();
   virtual void deactivating();
   virtual void timerEvent(QTimerEvent *);
-  virtual QPixmap pixmap() const;
 
 private:
   void drawFrame();
