@@ -1,4 +1,4 @@
-// $Id: ellipse.cpp,v 1.25 2000/11/25 10:06:51 mlaurent Exp $
+// $Id: ellipse.cpp,v 1.28 2002/09/25 23:45:28 waba Exp $
 
 #include <kdebug.h>
 #include <stdio.h>
@@ -101,7 +101,6 @@ void Ellipse::mouseReleaseEvent(QMouseEvent *e)
 {
   int x,y;
   QPainter paint;
-  QWMatrix m;
 
 kdDebug(4400) << "Ellipse::mouseReleaseEvent() handler called\n" << endl;
 
@@ -127,8 +126,7 @@ kdDebug(4400) << "Ellipse::mouseReleaseEvent() handler called\n" << endl;
 
     paint.begin(canvas->pixmap());
 
-    m.scale((float) 100/(canvas->zoom()), (float) 100/(canvas->zoom()));
-    paint.setWorldMatrix(m);
+    paint.setWorldMatrix(canvas->zoomMatrix());
     paint.setRasterOp(CopyROP);
 
     // Draw new ellipse
@@ -154,9 +152,9 @@ kdWarning(4400) << "Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
-QPixmap Ellipse::pixmap() const
+const char* Ellipse::pixmap() const
 {
-    return UserIcon("ellipse");
+    return "ellipse";
 }
 
 #include "ellipse.moc"
