@@ -1,4 +1,4 @@
-// $Id: kpaint.cpp,v 1.95 2002/03/13 08:47:36 zander Exp $
+// $Id: kpaint.cpp,v 1.105 2002/09/25 23:45:28 waba Exp $
 
 #include <qclipboard.h>
 #include <qlayout.h>
@@ -21,6 +21,7 @@
 #include <kimageio.h>
 #include <kio/netaccess.h>
 #include <klocale.h>
+#include <kkeydialog.h>
 #include <kmessagebox.h>
 #include <kmainwindow.h>
 #include <kstdaccel.h>
@@ -44,14 +45,15 @@ KPaint::KPaint(const KURL & _url) : KMainWindow(0)
     tmpFile = 0;
     zoom= 100;
 
-    mv = new MainView(this);
-    v = mv->getViewport();
-    c = mv->getCanvas();
+    m_mainView = new MainView(this);
+    m_view = m_mainView->getViewport();
+    m_canvas = m_mainView->getCanvas();
 
-    v->resize(c->size());
-    setCentralWidget( mv );
+    m_view->resize(m_canvas->size());
+    setCentralWidget( m_mainView );
 
-    man= new Manager(c);
+    man= new Manager(m_canvas);
+    connect(m_canvas, SIGNAL(startDrawing()), man, SLOT(updateProperties()));
 
     initMenus();
     initSideBar();
@@ -61,16 +63,16 @@ KPaint::KPaint(const KURL & _url) : KMainWindow(0)
     connect( kapp->clipboard(), SIGNAL( dataChanged() ), SLOT( enableEditPaste() ) );
     resize(640,480);
     show();
-    c->clearModified();
+    m_canvas->clearModified();
     
     if ( !_url.isEmpty() )
         loadFile(_url);
     else
         fileNew();
 
-    allowEditPalette = c->pixmap()->depth() == 8;
+    allowEditPalette = m_canvas->pixmap()->depth() == 8;
     updateCommands();
-    connect(c, SIGNAL(modified()), this, SLOT(updateCommands()));
+    connect(m_canvas, SIGNAL(modified()), this, SLOT(updateCommands()));
 }
 
 KPaint::~KPaint()
@@ -83,13 +85,15 @@ KPaint::~KPaint()
 void KPaint::setPixmap(QPixmap *p)
 {
     url = KURL();
-    c->setPixmap(p);
+    m_canvas->setPixmap(p);
 }
 
 
 bool KPaint::queryClose()
 {
-  if (!c->isModified())
+    saveMainWindowSettings(kapp->config(), "MainWindowSettings");
+
+  if (!m_canvas->isModified())
     return true;
 
   QString msg = i18n(""
@@ -122,42 +126,28 @@ bool KPaint::queryClose()
 
 }
 
+void KPaint::updateControls()
+{
+    if (statusbarAction->isChecked())
+	statusBar()->show();
+    else
+	statusBar()->hide();
+}
+
 void KPaint::updateCommands()
 {
-    revertAction->setEnabled(c->isModified());
-    saveAction->setEnabled(c->isModified());
-    saveAsAction->setEnabled(c->isModified());
+    revertAction->setEnabled(m_canvas->isModified());
     paletteAction->setEnabled(allowEditPalette);
-    setCaption(filename, c->isModified());
+    setCaption(filename, m_canvas->isModified());
 }
 
 void KPaint::readOptions()
 {
-    KConfig *config = KApplication::kApplication()->config();
+    applyMainWindowSettings(kapp->config(), "MainWindowSettings");
 
-    config->setGroup( "Appearance" );
-
-    // Read the entries
-    toolbarAction->setChecked(config->readBoolEntry("ShowToolsToolBar", true));
-    statusbarAction->setChecked(config->readBoolEntry("ShowStatusBar", true));
-
-    updateControls();
+    statusbarAction->setChecked(!statusBar()->isHidden());
 }
 
-
-void KPaint::writeOptions()
-{
-    KConfig *config = KApplication::kApplication()->config();
-
-    config->setGroup( "Appearance" );
-
-    // Write the entries
-    config->writeEntry("ShowToolsToolBar", toolbarAction->isChecked());
-    config->writeEntry("ShowStatusBar", statusbarAction->isChecked());
-    config->sync();
-}
-
-
 void KPaint::enableEditPaste()
 {
     QClipboard *cb = kapp->clipboard();
@@ -174,38 +164,11 @@ void KPaint::enableEditPaste()
 }
 
 
-void KPaint::updateControls()
-{
-    KToolBar *bar = toolBar("mainToolBar");
-    if (bar)
-    {
-        if (toolbarAction->isChecked())
-            bar->show();
-        else
-            bar->hide();
-    }
-
-    bar = toolBar("sideToolBar");
-    if (bar)
-    {
-        if (toolbarAction->isChecked())
-            bar->show();
-        else
-            bar->hide();
-    }
-
-    if (statusbarAction->isChecked())
-        statusbar->show();
-    else
-        statusbar->hide();
-}
-
-
 void KPaint::canvasSizeChanged()
 {
     QString size("%1 x %2");
-    statusbar->changeItem(size.arg( c->width() ).arg( c->height() ), ID_FILE_SIZE);
-    mv->updateLayout();
+    statusbar->changeItem(size.arg( m_canvas->width() ).arg( m_canvas->height() ), ID_FILE_SIZE);
+    m_mainView->updateLayout();
 }
 
 
@@ -215,10 +178,10 @@ void KPaint::initStatus()
 
     /* write the image size */
     QString size( "%1 x %2" );
-    statusbar->insertItem( size.arg( c->width() ).arg( c->height() ), ID_FILE_SIZE );
+    statusbar->insertItem( size.arg( m_canvas->width() ).arg( m_canvas->height() ), ID_FILE_SIZE );
 
     /* write the color depth */
-    size.sprintf(" %d bpp", c->getDepth());
+    size.sprintf(" %d bpp", m_canvas->getDepth());
     statusbar->insertItem(size, ID_COLOR_DEPTH);
 
     /* write the zoomfactor */
@@ -254,14 +217,6 @@ void KPaint::initStatus()
     /* update to the current toolname */
     statusbar->changeItem(man->getCurrentTool().getName(), ID_TOOL_NAME);
     man->setStatusBar(statusbar);
-
-    statusbar->show();
-}
-
-
-void KPaint::slotSideToolbarMoved()
-{
-    kdDebug() << "Sidebar moved" << endl;
 }
 
 /*
@@ -276,57 +231,41 @@ bool KPaint::initSideBar()
 
     // the toolbar itself
     sideToolbar = toolBar("sideToolBar");
-    sideToolbar->show();
-    sideToolbar->setBarPos(KToolBar::Right);
-
-    connect(sideToolbar, SIGNAL(orientationChanged(Orientation)),
-	    this, SLOT(slotSideToolbarMoved()));
+    sideToolbar->setText( i18n( "&Sidebar" ) );
 
     // the preview/navigation widget with container
+
     QWidget *navWidget = new QWidget(sideToolbar);
 
     navWidget->setMinimumWidth(iw);
     navWidget->setMinimumHeight(ih);
-    navWidget->setMaximumWidth(120);
-    navWidget->setMaximumHeight(120);
 
-    QBoxLayout *ml = new QVBoxLayout(navWidget);
-    //QLabel *navlabel = new QLabel(i18n("Image Preview"), navWidget);
+    QBoxLayout *ml = new QVBoxLayout(navWidget, 10);
 
     nav = new NavWidget(navWidget, "navwidget");
     nav->setMinimumSize(120, 80);
-    nav->setMaximumSize(120, 120);
-    nav->setPixmap(c->pixmap());
+    nav->setPixmap(m_canvas->pixmap());
 
-    connect(c, SIGNAL(pixmapChanged(QPixmap *)),
+    connect(m_canvas, SIGNAL(pixmapChanged(QPixmap *)),
 	    nav, SLOT(setPixmap(QPixmap *)));
-    connect(c, SIGNAL(modified()),
+    connect(m_canvas, SIGNAL(modified()),
         nav, SLOT(pixmapChanged()));
-    //ml->addWidget(navlabel);
     ml->addWidget(nav);
 
     QWidget *mouseWidget = new QWidget(sideToolbar);
-    mouseWidget->setFixedSize(66, 96);
     QBoxLayout *vl = new QVBoxLayout(mouseWidget);
 
     // The colour selector widgets with container widget
     QWidget *colorsWidget = new QWidget(mouseWidget);
-
     colorsWidget->setMinimumWidth(32);
     colorsWidget->setMinimumHeight(32);
-    colorsWidget->setMaximumWidth(66);
-    colorsWidget->setMaximumHeight(66);
 
-    ml = new QHBoxLayout(colorsWidget);
-    //QLabel *lmbLabel = new QLabel(i18n("LeftButton Color"), colorsWidget);
-    //QLabel *rmbLabel = new QLabel(i18n("RightButton Color"), colorsWidget);
+    ml = new QHBoxLayout(colorsWidget, 10);
     lmbColourBtn = new KColorButton(red, colorsWidget, "lmbColour");
     rmbColourBtn = new KColorButton(green, colorsWidget, "rmbColour");
-    //    QPushButton *mmbBtn = new QPushButton(colorsWidget, "mmbButton");
 
-    lmbColourBtn->setFixedSize(22, 30);
-    //    mmbBtn->setFixedSize(22, 30);
-    rmbColourBtn->setFixedSize(22, 30);
+    lmbColourBtn->setFixedSize(30, 30);
+    rmbColourBtn->setFixedSize(30, 30);
 
     man->setLMColorButton(lmbColourBtn);
     man->setRMColorButton(rmbColourBtn);
@@ -336,33 +275,18 @@ bool KPaint::initSideBar()
     connect(rmbColourBtn, SIGNAL(changed(const QColor &)),
 	    man, SLOT(setRMBcolour(const QColor &)));
 
-    //ml->addWidget(rmbLabel);
     ml->addWidget(lmbColourBtn);
-    //    ml->addWidget(mmbBtn);
     ml->addWidget(rmbColourBtn);
-    //ml->addWidget(lmbLabel);
-
     vl->addWidget(colorsWidget);
 
-    //    QWidget *mouseBodyWidget = new QWidget(mouseWidget);
-    //    ml = new QHBoxLayout(mouseBodyWidget);
-    //    QPushButton *mouseBtn = new QPushButton(mouseBodyWidget, "MouseButton");
-    //    mouseBtn->setFixedSize(66, 60);
-    //    ml->addWidget(mouseBtn);
-    //    vl->addWidget(mouseBodyWidget);
-
-
     KPaletteTable *paletteTable = new KPaletteTable( sideToolbar , 120 , 8 );
-    paletteTable->setMaximumHeight(66);
 
     connect(paletteTable, SIGNAL(colorSelected(const QColor &, const QString &)),
 	  man, SLOT(setLMBcolour(const QColor &)));
 
     // insert containter widgets so they show up as toolbar items
     sideToolbar->insertWidget(ID_NAV_WIDGET, iw, navWidget);
-    sideToolbar->insertSeparator();
     sideToolbar->insertWidget(ID_COLORS_WIDGET, iw, mouseWidget);
-    sideToolbar->insertSeparator();
     sideToolbar->insertWidget(ID_COLOR_BAR, iw, paletteTable);
 
     return true;
@@ -384,15 +308,16 @@ void KPaint::initMenus()
     copyAction = KStdAction::copy(this, SLOT(editCopy()), actionCollection());
     cutAction = KStdAction::cut(this, SLOT(editCut()), actionCollection());
     pasteAction = KStdAction::paste(this, SLOT(editPaste()), actionCollection());
-    pasteImageAction = new KAction(i18n("Paste &Image"), 0, this,
+    pasteImageAction = new KAction(i18n("Paste &Image"), KShortcut(), this,
                        SLOT(editPasteImage()), actionCollection(),
                        "edit_paste_image");
+    (void) new KAction(i18n("&Clear"), KShortcut(), this, SLOT(editClear()), actionCollection(), "edit_clear");
 
     // view menu
     zoomInAction = KStdAction::zoomIn(this, SLOT(editZoomIn()), actionCollection());
     zoomOutAction = KStdAction::zoomOut(this, SLOT(editZoomOut()), actionCollection());
     zoomNormalAction = KStdAction::actualSize(this, SLOT(editZoomNormal()), actionCollection());
-    zoomAction = new KSelectAction( i18n( "Zoom" ), 0, actionCollection(), "view_zoom" );
+    zoomAction = new KSelectAction( i18n( "Zoom" ), KShortcut(), actionCollection(), "view_zoom" );
     connect( zoomAction, SIGNAL( activated( const QString & ) ),
              this, SLOT( viewZoom( const QString & ) ) );
     QStringList lst;
@@ -418,36 +343,36 @@ void KPaint::initMenus()
     zoomAction ->setItems( lst );
     zoomAction ->setCurrentItem(9);
     // image menu
-    (void) new KAction(i18n("&Information..."), 0, this,
+    (void) new KAction(i18n("&Information"), KShortcut(), this,
                        SLOT(imageInfo()), actionCollection(),
                        "image_info");
-    (void) new KAction(i18n("&Resize..."), 0, this,
+    (void) new KAction(i18n("&Resize..."), KShortcut(), this,
                        SLOT(imageResize()), actionCollection(),
                        "image_resize");
-    paletteAction = new KAction(i18n("&Edit Palette..."), 0, this,
+    paletteAction = new KAction(i18n("&Edit Palette..."), KShortcut(), this,
                        SLOT(imageEditPalette()), actionCollection(),
                        "image_palette");
-    (void) new KAction(i18n("&Change Color Depth..."), 0, this,
+    (void) new KAction(i18n("&Change Color Depth..."), KShortcut(), this,
                        SLOT(imageChangeDepth()), actionCollection(),
                        "image_color");
 
     // settings menu
-    toolbarAction = KStdAction::showToolbar(this, SLOT(updateControls()), actionCollection());
     statusbarAction = KStdAction::showStatusbar(this, SLOT(updateControls()), actionCollection());
-    (void) KStdAction::saveOptions(this, SLOT(writeOptions()), actionCollection());
+
+    KStdAction::keyBindings(this, SLOT(editKeyBindings()), actionCollection());
 
 #if 0
     // window menu
-    (void) new KAction(i18n("&New window"), 0, this,
+    (void) new KAction(i18n("&New Window"), KShortcut(), this,
                        SLOT(newWindow()), actionCollection(),
                        "window_new");
-    (void) new KAction(i18n("&Close window"), 0, this,
+    (void) new KAction(i18n("&Close Window"), KShortcut(), this,
                        SLOT(closeWindow()), actionCollection(),
                        "window_close");
 #endif
 
     // tool menu
-    (void) new KAction(i18n("&Tool Properties..."), 0, this,
+    (void) new KAction(i18n("&Tool Properties"), "configure", KShortcut(), this,
                    SLOT(toolProperties()), actionCollection(),
                    "tool_config");
 
@@ -460,8 +385,7 @@ void KPaint::initMenus()
     for ( Tool *t= tl.first(); t; t= tl.next() )
     {
       if ( !t->isSpecial() ) {
-	KToggleAction *action = new KToggleAction(t->getName(), QIconSet(t->pixmap()), 0,
-						  0, 0,
+	KToggleAction *action = new KToggleAction(t->getName(), t->pixmap(), KShortcut(), 0, 0,
 						  actionCollection(),
 						  QCString().sprintf("tool_%d", id));
 	action->setExclusiveGroup( "tools" );
@@ -473,22 +397,27 @@ void KPaint::initMenus()
     }
 
     KStdAction::configureToolbars(this, SLOT(editToolbars()), actionCollection());
-    createGUI("kpaint.rc");
+    createGUI();
 }
 
 
 void KPaint::editToolbars()
 {
-  KEditToolbar dlg(actionCollection(),"kpaint.rc");
-  if (dlg.exec())
-    createGUI("kpaint.rc");
+    KEditToolbar dlg(actionCollection());
+    if (dlg.exec())
+	createGUI();
 }
 
+void KPaint::editKeyBindings()
+{
+    KKeyDialog::configure(actionCollection());
+    actionCollection()->readShortcutSettings();
+}
 
 bool KPaint::fileOpen()
 {
     bool result = false;
-    if (!url.isEmpty() || c->isModified())
+    if (!url.isEmpty() || m_canvas->isModified())
     {
         KPaint *kp = new KPaint();
         result = kp->fileOpen();
@@ -517,7 +446,7 @@ bool KPaint::loadFile(const KURL& _url)
 
     if (_url.isLocalFile())
     {
-       result = c->load(_url.path());
+       result = m_canvas->load(_url.path());
        if (result)
           filename = _url.path();
     }
@@ -529,7 +458,7 @@ bool KPaint::loadFile(const KURL& _url)
        QString tmpname = newTmpFile->name();
        if (KIO::NetAccess::download(_url, tmpname))
        {
-          result =  c->load(tmpname);
+          result =  m_canvas->load(tmpname);
        }
        if (result)
           filename = tmpname;
@@ -552,10 +481,10 @@ bool KPaint::loadFile(const KURL& _url)
     url = _url;
     format = KImageIO::type(url.fileName());
     statusbar->changeItem(url.prettyURL(), ID_FILE_NAME);
-    orig_width = c->width();
-    orig_height = c->height();
+    orig_width = m_canvas->width();
+    orig_height = m_canvas->height();
     canvasSizeChanged();
-    c->clearModified();
+    m_canvas->clearModified();
     updateCommands();
     return true;
 }
@@ -584,7 +513,7 @@ bool KPaint::saveFile(QString filename_, QString format_, KURL &url_)
 {
     kdDebug(4400) << "saveFile reached, calling canvas save...\n" << endl;
 
-    if (!c->save(filename_, format_.ascii()))
+    if (!m_canvas->save(filename_, format_.ascii()))
         return false;
 
     filename = filename_;
@@ -600,7 +529,7 @@ bool KPaint::saveFile(QString filename_, QString format_, KURL &url_)
     url = url_;
 
     statusbar->changeItem(filename, ID_FILE_NAME);
-    c->clearModified();
+    m_canvas->clearModified();
     updateCommands();
     return true;
 }
@@ -638,7 +567,7 @@ bool KPaint::fileSaveAs()
     delete tmpFile;
     tmpFile = newTmpFile;
 
-    c->clearModified();
+    m_canvas->clearModified();
     return true;
 }
 
@@ -647,7 +576,7 @@ void KPaint::fileClose()
     delete tmpFile;
     tmpFile = 0;
     url = KURL();
-    c->clearModified();
+    m_canvas->clearModified();
     fileNew();
 }
 
@@ -655,17 +584,17 @@ void KPaint::fileRevert()
 {
     if (!url.isEmpty())
     {
-       c->load(filename);
+       m_canvas->load(filename);
     }
     else
     {
        QPixmap p;
        p.resize(orig_width, orig_height);
        p.fill(QColor("white"));
-       c->setPixmap(&p);
+       m_canvas->setPixmap(&p);
     }
     canvasSizeChanged();
-    c->clearModified();
+    m_canvas->clearModified();
     updateCommands();
 }
 
@@ -673,7 +602,7 @@ void KPaint::fileNew()
 {
     kdDebug(4400) << "File New" << endl;
 
-    if (!url.isEmpty() || c->isModified())
+    if (!url.isEmpty() || m_canvas->isModified())
     {
         KPaint *kp = new KPaint();
         kp->show();
@@ -681,11 +610,11 @@ void KPaint::fileNew()
         return;
     }
 
-    c->clearModified();
+    m_canvas->clearModified();
     QPixmap p;
     p.resize(320, 200);
     p.fill(QColor("white"));
-    c->setPixmap(&p);
+    m_canvas->setPixmap(&p);
     man->setCurrentTool(0);
     format = "PNG";
     filename = i18n("untitled") + ".png";
@@ -694,16 +623,16 @@ void KPaint::fileNew()
     tmpFile = 0;
 
     statusbar->changeItem(filename, ID_FILE_NAME);
-    orig_width = c->width();
-    orig_height = c->height();
+    orig_width = m_canvas->width();
+    orig_height = m_canvas->height();
     canvasSizeChanged();
     repaint(0);
 
-//      canvasSizeDialog sz(this, "canvassizedlg",c->width(), c->height());
+//      canvasSizeDialog sz(this, "canvassizedlg",m_canvas->width(), m_canvas->height());
 //      if ( sz.exec() ) {
 //          p.resize( sz.getWidth(), sz.getHeight() );
 //          p.fill( QColor("white") );
-//          c->setPixmap(&p);
+//          m_canvas->setPixmap(&p);
 //          canvasSizeChanged();
 //          repaint(0);
 //      }
@@ -713,13 +642,13 @@ void KPaint::fileNew()
 void KPaint::editCopy()
 {
     kdDebug(4400) << "editCopy()\n" << endl;
-    c->copy();
+    m_canvas->copy();
 }
 
 void KPaint::editCut()
 {
     kdDebug(4400) << "editCut()\n" << endl;
-    c->cut();
+    m_canvas->cut();
 }
 
 /*
@@ -736,7 +665,7 @@ void KPaint::editPaste()
     if ( !clipPix.isNull() )
       man->setCurrentTool(9);
 
-    c->markModified();
+    m_canvas->markModified();
 }
 
 /* This is intended to copy clipboard to a
@@ -752,17 +681,23 @@ void KPaint::editPasteImage()
         QPixmap *p = new QPixmap( clipPix );
         KPaint *kp = new KPaint();
         kp->setPixmap(p);
-	kp->c->markModified();
+	kp->m_canvas->markModified();
         kp->show();
     }
 }
 
+void KPaint::editClear()
+{
+    kdDebug(4400) << "editClear()" << endl;
+    m_canvas->clear();
+}
+
 void KPaint::editZoomNormal()
 {
     kdDebug(4400) << "editZoomIn()" << endl;
 
     int zoom = 100;
-    c->setZoom( zoom );
+    m_canvas->setZoom( zoom );
     QString zoomstr;
     zoomstr.setNum(zoom);
     zoomstr += '%';
@@ -795,7 +730,7 @@ void KPaint::editZoomIn()
         zoomOutAction->setEnabled(true);
     }
 
-    c->setZoom(zoom);
+    m_canvas->setZoom(zoom);
 
     QString zoomstr;
     zoomstr.setNum(zoom);
@@ -831,7 +766,7 @@ void KPaint::viewZoom( const QString &_strZoom )
 
     if(zoom!=new_zoom)
     {
-        c->setZoom(new_zoom);
+        m_canvas->setZoom(new_zoom);
         zoom=new_zoom;
         statusbar->changeItem(_strZoom, ID_ZOOM_FACTOR);
     }
@@ -857,7 +792,7 @@ void KPaint::editZoomOut()
         }
     }
 
-    c->setZoom(zoom);
+    m_canvas->setZoom(zoom);
 
     QString zoomstr;
     zoomstr.setNum(zoom);
@@ -879,7 +814,7 @@ void KPaint::editOptions()
 
 void KPaint::imageInfo()
 {
-  imageInfoDialog info(c, 0, "Image Information");
+  imageInfoDialog info(m_canvas, 0, "Image Information");
   kdDebug(4400) << "imageInfo()" << endl;
   info.exec();
 }
@@ -889,14 +824,14 @@ void KPaint::imageResize()
 {
     kdDebug(4400) << "imageResize()" << endl;
 
-    canvasSizeDialog sz(this,"imageResize",c->width(), c->height());
+    canvasSizeDialog sz(this,"imageResize",m_canvas->imageWidth(), m_canvas->imageHeight());
     if (sz.exec())
     {
         int w= sz.getWidth();
         int h= sz.getHeight();
         if( w!=0 && h!=0)
         {
-            c->resizeImage(w, h);
+            m_canvas->resizeImage(w, h);
             canvasSizeChanged();
         }
     }
@@ -905,12 +840,12 @@ void KPaint::imageResize()
 void KPaint::imageEditPalette()
 {
     kdDebug(4400) << "imageEditPalette()" << endl;
-    paletteDialog pal(c->pixmap());
+    paletteDialog pal(m_canvas->pixmap());
 
     if (pal.exec())
     {
-        c->setPixmap(pal.pixmap());
-        c->repaint(0);
+        m_canvas->setPixmap(pal.pixmap());
+        m_canvas->repaint(0);
     }
 }
 
@@ -918,7 +853,7 @@ void KPaint::imageChangeDepth()
 {
     QString depthstr;
     KStatusBar *sb = statusBar();
-    depthDialog d(c);
+    depthDialog d(m_canvas);
 
     kdDebug(4400) << "imageChangeDepth()" << endl;
 
@@ -932,7 +867,7 @@ void KPaint::imageChangeDepth()
       depthstr.sprintf(" %d bpp", 1);
       sb->changeItem(depthstr, ID_COLOR_DEPTH);
       allowEditPalette= false;
-      c->setDepth(1);
+      m_canvas->setDepth(1);
       break;
 
     case ID_COLOR_4:
@@ -940,7 +875,7 @@ void KPaint::imageChangeDepth()
       depthstr.sprintf(" %d bpp", 4);
       sb->changeItem(depthstr, ID_COLOR_DEPTH);
       allowEditPalette= false;
-      c->setDepth(4);
+      m_canvas->setDepth(4);
       break;
 
     case ID_COLOR_8:
@@ -948,7 +883,7 @@ void KPaint::imageChangeDepth()
       depthstr.sprintf(" %d bpp", 8);
       sb->changeItem(depthstr, ID_COLOR_DEPTH);
       allowEditPalette= true;
-      c->setDepth(8);
+      m_canvas->setDepth(8);
       break;
 
     case ID_COLOR_15:
@@ -956,7 +891,7 @@ void KPaint::imageChangeDepth()
       depthstr.sprintf(" %d bpp", 15);
       sb->changeItem(depthstr, ID_COLOR_DEPTH);
       allowEditPalette= false;
-      c->setDepth(15);
+      m_canvas->setDepth(15);
       break;
 
     case ID_COLOR_16:
@@ -964,7 +899,7 @@ void KPaint::imageChangeDepth()
       depthstr.sprintf(" %d bpp", 16);
       sb->changeItem(depthstr, ID_COLOR_DEPTH);
       allowEditPalette= false;
-      c->setDepth(16);
+      m_canvas->setDepth(16);
       break;
 
     case ID_COLOR_24:
@@ -972,7 +907,7 @@ void KPaint::imageChangeDepth()
       depthstr.sprintf(" %d bpp", 24);
       sb->changeItem(depthstr, ID_COLOR_DEPTH);
       allowEditPalette= false;
-      c->setDepth(24);
+      m_canvas->setDepth(24);
       break;
 
     case ID_COLOR_32:
@@ -980,7 +915,7 @@ void KPaint::imageChangeDepth()
       depthstr.sprintf("%d bpp", 32);
       sb->changeItem(depthstr, ID_COLOR_DEPTH);
       allowEditPalette= false;
-      c->setDepth(32);
+      m_canvas->setDepth(32);
       break;
 
     default:
@@ -1002,9 +937,4 @@ void KPaint::toolProperties()
     man->showPropertiesDialog();
 }
 
-void KPaint::dummy()
-{
-  // just here to make KAction happy
-}
-
 #include "kpaint.moc"
