@@ -9,21 +9,22 @@
 
 
 paletteWidget::paletteWidget(QPixmap *p, QWidget *parent, const char *name)
-    : QtTableView(parent, name)
+    : QTable(parent, name)
 {
     img = NULL;
     setPixmap(p);
 
-    setTableFlags( Tbl_autoScrollBars | Tbl_cutCells | Tbl_snapToGrid );
-    setCellWidth(20);
-    setCellHeight(15);
+    setVScrollBarMode(Auto);
+    setHScrollBarMode(Auto);
 }
 
 
 paletteWidget::paletteWidget(QWidget *parent, const char *name)
-    : QtTableView(parent, name)
+    : QTable(parent, name)
 {
-    setTableFlags( Tbl_autoScrollBars | Tbl_cutCells | Tbl_snapToGrid );
+    setVScrollBarMode(Auto);
+    setHScrollBarMode(Auto);
+
     image = NULL;
     img = NULL;
     numColours= 0;
@@ -43,7 +44,7 @@ void paletteWidget::setPixmap(QPixmap *p)
 
     if (d != 8) 
     {
-        kdDebug(4400) << "paletteWidget: Invalid pixmap depth\n" << endl;
+        kdDebug(4400) << "paletteWidget: Invalid pixmap depth " << d << "\n" << endl;
         numColours= 0;
         // image = NULL;  // can't make an arg passed in NULL
         return;
@@ -61,34 +62,34 @@ QPixmap *paletteWidget::pixmap()
 }
 
 
-void paletteWidget::paintCell(QPainter *p, int row, int col)
+void paletteWidget::paintCell(QPainter *p, int row, int col, int cellWidth, int cellHeight)
 {
     int i = row*numCols()+col;
 
     p->setPen(QPen(black));
-    p->drawRect(0,0, cellWidth()-1, cellHeight()-1);
+    p->drawRect(0,0, cellWidth-1, cellHeight-1);
 
     if (i < numColours) 
     {
         p->setPen(QPen(img->color(i)));
         p->setBrush(QBrush(img->color(i)));
-        p->drawRect(1,1, cellWidth()-2, cellHeight()-2);
+        p->drawRect(1,1, cellWidth-2, cellHeight-2);
     }
     else 
     {
         p->setPen(QPen(darkGray));
         p->setBrush(QBrush(darkGray));
-        p->drawRect(1,1, cellWidth()-2, cellHeight()-2);
+        p->drawRect(1,1, cellWidth-2, cellHeight-2);
     }
 }
 
 
 void paletteWidget::mousePressEvent(QMouseEvent *e)
 {
-  // Convert coordinates to colour index
-  int i = findRow(e->y())*numCols()+findCol(e->x());
+    // Convert coordinates to colour index
+    int i = rowAt(e->y())*numCols()+columnAt(e->x());
 
-kdDebug(4400) << "paletteWidget:: Color Selected (" << i << ")\n" << endl;
+    kdDebug(4400) << "paletteWidget:: Color Selected (" << i << ")\n" << endl;
 
     emit colourSelected(i);
 }
