@@ -1,5 +1,5 @@
 // -*- c++ -*-
-// $Id: pen.h,v 1.7 2000/08/06 10:25:10 bieker Exp $
+// $Id: pen.h,v 1.9 2002/09/02 16:56:27 winkvist Exp $
 
 #ifndef PEN_H
 #define PEN_H
@@ -17,7 +17,7 @@ public:
   void mouseMoveEvent(QMouseEvent *e);
   void mouseReleaseEvent(QMouseEvent *e);
   void activating();
-    virtual QPixmap pixmap() const;
+  const char* pixmap() const;
 signals:
   void modified();
 private:
