@@ -24,9 +24,8 @@ propertiesDialog::propertiesDialog(int pages,
   addTab(lineProps, i18n("Line Properties"));
   fillProps= new fillPropertiesWidget(this);
   addTab(fillProps, i18n("Fill Properties"));
+  setOKButton(i18n("&OK"));
 
-  setCancelButton( i18n( "Cancel" ) );
-  setApplyButton( i18n( "Apply" ));
   setPages(pages);
 }
 
@@ -69,7 +68,7 @@ fillPropertiesWidget::fillPropertiesWidget(QWidget *parent)
   // Now create the contents
   //
 
-  patternLabel= new QLabel(i18n("Fill Pattern:"), this);
+  patternLabel= new QLabel(i18n("Fill pattern:"), this);
   patternLabel->move(40, 40);
 
   // Need to use an item that can display a sample of each one
@@ -95,7 +94,7 @@ fillPropertiesWidget::fillPropertiesWidget(QWidget *parent)
   patternBox->insertItem(i18n("Custom"));
   patternBox->move(150, 40);
 
-  customPatternLabel= new QLabel(i18n("Pattern Filename:"), this);
+  customPatternLabel= new QLabel(i18n("Pattern filename:"), this);
   customPatternLabel->move(40, 100);
 
   customPatternField= new QLineEdit(this);
@@ -124,7 +123,7 @@ fillPropertiesWidget::fillPropertiesWidget(QWidget *parent)
   vertical->addStretch();
   vertical->addLayout(grid);
 
-  patternLabel= new QLabel(i18n("Fill Pattern:"), this);
+  patternLabel= new QLabel(i18n("Fill pattern:"), this);
   SETMINSIZE(patternLabel);
   grid->addWidget(patternLabel, 0, 0);
 
@@ -150,7 +149,7 @@ fillPropertiesWidget::fillPropertiesWidget(QWidget *parent)
 
   //  patternBox->insertItem(i18n("Custom"));
 
-  customPatternLabel= new QLabel(i18n("Pattern Filename:"), this);
+  customPatternLabel= new QLabel(i18n("Pattern filename:"), this);
   SETMINSIZE(customPatternLabel);
   grid->addWidget(customPatternLabel, 1, 0);
 
@@ -286,7 +285,7 @@ linePropertiesWidget::linePropertiesWidget(QWidget *parent)
   // Now create the contents
   //
 
-  styleLabel= new QLabel(i18n("Line Style:"), this);
+  styleLabel= new QLabel(i18n("Line style:"), this);
   styleLabel->move(40, 40);
 
   // These should have a picture
@@ -300,7 +299,7 @@ linePropertiesWidget::linePropertiesWidget(QWidget *parent)
   styleBox->move(150, 40);
 
   
-  widthLabel= new QLabel(i18n("Line Width:"), this);
+  widthLabel= new QLabel(i18n("Line width:"), this);
   widthLabel->move(40, 100);
 
   widthBox= new QComboBox(TRUE, this, 0);
@@ -347,7 +346,7 @@ linePropertiesWidget::linePropertiesWidget(QWidget *parent)
   QGridLayout *grid= new QGridLayout(4, 2);
   vertical->addLayout(grid);
 
-  styleLabel= new QLabel(i18n("Line Style:"), this);
+  styleLabel= new QLabel(i18n("Line style:"), this);
   grid->addWidget(styleLabel, 0, 0);
 
   styleBox= new QComboBox(FALSE, this, 0);
@@ -359,7 +358,7 @@ linePropertiesWidget::linePropertiesWidget(QWidget *parent)
   styleBox->insertItem(i18n("None"));
   grid->addWidget(styleBox, 0, 1);
 
-  widthLabel= new QLabel(i18n("Line Width:"), this);
+  widthLabel= new QLabel(i18n("Line width:"), this);
   grid->addWidget(widthLabel, 1, 0);
 
   widthBox= new QComboBox(TRUE, this, 0);
