@@ -1,4 +1,4 @@
-// $Id: tool.cpp,v 1.14 2000/11/25 10:06:51 mlaurent Exp $
+// $Id: tool.cpp,v 1.15 2001/07/25 15:35:16 rich Exp $
 
 #include <kdebug.h>
 #include <stdio.h>
@@ -7,24 +7,17 @@
 #include "tool.h"
 
 Tool::Tool()
+  : id( -1 ), active( false ),
+    pix( 0 ), canvas( 0 ), 
+    props( 0 ), special( false )
 {
-  active= false;
-  canvas= 0;
-  props= 0;
 }
 
 Tool::Tool(const QString & toolname)
-  : name(toolname)
+  : id( -1 ), active( false ),
+  pix( 0 ), name(toolname), canvas( 0 ),
+  props( 0 ), special( false )
 {
-  active = false;
-  canvas = 0;
-  props = 0;
-}
-
-
-int Tool::getPages()
-{
-  return props;
 }
 
 void Tool::activate(Canvas *c)
@@ -43,11 +36,6 @@ void Tool::deactivate()
   canvas= 0;
 }
 
-bool Tool::isActive()
-{
-  return active;
-}
-
 void Tool::setLeftPen(QPen &p)
 {
   kdDebug(4400) << "Tool::setLeftPen()" << endl;
