@@ -1,6 +1,6 @@
 // -*- c++ -*-
 
-// $Id: tool.h,v 1.14 2001/11/03 14:22:04 andreas Exp $
+// $Id: tool.h,v 1.16 2002/09/02 16:56:27 winkvist Exp $
 
 #ifndef TOOL_H
 #define TOOL_H
@@ -66,7 +66,7 @@ public:
   void setRightBrush(QBrush &b);
 
   QString tip() { return tooltip; };
-  virtual QPixmap pixmap() const = 0;
+  virtual const char* pixmap() const = 0;
 
   bool isSpecial() const { return special; }
   void setSpecial( bool s ) { special = s; }
