@@ -15,30 +15,35 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <iostream.h>
+#include <iostream>
+
 #include <kconfig.h>
-#include <kwin.h>
 #include <kcursor.h>
 #include <kdebug.h>
 #include <kglobal.h>
-#include <kpopupmenu.h>
 #include <kiconloader.h>
+#include <kimageeffect.h>
 #include <klocale.h>
 #include <kmainwindow.h>
-#include <qwhatsthis.h>
-#include <kstandarddirs.h>
-#include <qpixmap.h>
-#include <qiconset.h>
 #include <knotifyclient.h>
+#include <kpopupmenu.h>
+#include <kstandarddirs.h>
+#include <kwin.h>
 
-#include <qdialog.h>
-#include <qcursor.h>
-#include <qpainter.h>
 #include <qbitmap.h>
+#include <qcursor.h>
+#include <qdialog.h>
+#include <qiconset.h>
+#include <qimage.h>
+#include <qpainter.h>
+#include <qpixmap.h>
+#include <qwhatsthis.h>
 
 #include "klineal.h"
 
 #define CFG_KEY_BGCOLOR "BgColor"
+#define CFG_KEY_SCALE_FONT "ScaleFont"
+#define CFG_KEY_LENGTH "Length"
 #define CFG_GROUP_SETTINGS "StoredSettings"
 /**
 * this is our cursor bitmap:
@@ -54,15 +59,6 @@ static const uchar cursorBits[] = {
   0xfe, 0xfe, 0x7c, 0x7c, 0x38, 0x38, 0x10, 0x10,
 };
 
-/**
-* load an icon from our data dir
-*/
-QIconSet KLineal::menuIcon(const char *name)
-{
-    QString path = KGlobal::dirs()->findResource("data", "kruler/" + QString(name) + ".png");
-    // kdDebug() << "found: " << path << endl;
-    return QIconSet(QPixmap(path));
-}
 /**
 * create the thingy with no borders and set up
 * its members
@@ -73,7 +69,7 @@ KLineal::KLineal(QWidget*parent,const char* name):KMainWindow(parent,name){
 	}
   KWin::setType(winId(), NET::Override);   // or NET::Normal
   KWin::setState(winId(), NET::StaysOnTop);
-
+  setPaletteBackgroundColor(black);
   QWhatsThis::add(this,
   i18n(
   	"This is a tool to measure pixel distances and colors on the screen. "
@@ -95,27 +91,35 @@ KLineal::KLineal(QWidget*parent,const char* name):KMainWindow(parent,name){
   setMaximumSize(8000,8000);
   KConfig *cfg = kapp->config();
   QColor defaultColor(255, 200, 80);
+  QFont defaultFont("Helvetica", 8);
+  defaultFont.setPixelSize(8);
   if (cfg) {
-  		cfg->setGroup(CFG_GROUP_SETTINGS);
-      setBackgroundColor(cfg->readColorEntry(CFG_KEY_BGCOLOR, &defaultColor));
+      cfg->setGroup(CFG_GROUP_SETTINGS);
+      mColor = cfg->readColorEntry(CFG_KEY_BGCOLOR, &defaultColor);
+      mScaleFont = cfg->readFontEntry(CFG_KEY_SCALE_FONT, &defaultFont);
+      mLongEdgeLen = cfg->readNumEntry(CFG_KEY_LENGTH, 600);
     } else {
-  		setBackgroundColor(defaultColor);
+  		mColor = defaultColor;
+      mScaleFont = defaultFont;
+      mLongEdgeLen = 400;
   }
+  kdDebug() << "mLongEdgeLen=" << mLongEdgeLen << endl;
   mShortEdgeLen = 70;
 
   mLabel = new QLabel(this);
   mLabel->setGeometry(0,height()-12,32,12);
-  mLabel->setBackgroundColor(backgroundColor());
+  mLabel->setBackgroundOrigin(ParentOrigin);
   QFont labelFont("Helvetica", 10);
   labelFont.setPixelSize(10);
   mLabel->setFont(labelFont);
   QWhatsThis::add(mLabel,
   	i18n(
-  		"This is the current distance measured in pixels"
+  		"This is the current distance measured in pixels."
   	));
 	mColorLabel = new QLabel(this);
   mColorLabel->resize(45,12);
-  mColorLabel->setBackgroundColor(backgroundColor());
+  mColorLabel->setPaletteBackgroundColor(mColor);
+  mColorLabel->hide();
   QFont colorFont("fixed", 10);
   colorFont.setPixelSize(10);
   mColorLabel->setFont(colorFont);
@@ -131,32 +135,34 @@ KLineal::KLineal(QWidget*parent,const char* name):KMainWindow(parent,name){
   setMouseTracking(TRUE);
   mDragging = FALSE;
   mOrientation = South;
+  _clicked = false;
   setOrientation(South);
-  setMediumLength();
+  // setMediumLength();
   mMenu = new KPopupMenu();
-  mMenu->insertTitle(i18n("K-Ruler"));
+  mMenu->insertTitle(i18n("KRuler"));
   KPopupMenu *oriMenu = new KPopupMenu(this);
-  oriMenu->insertItem(menuIcon("kruler-north"), i18n("North"), this, SLOT(setNorth()), Key_N);
-  oriMenu->insertItem(menuIcon("kruler-east"), i18n("East"), this, SLOT(setEast()), Key_E);
-  oriMenu->insertItem(menuIcon("kruler-south"), i18n("South"), this, SLOT(setSouth()), Key_S);
-  oriMenu->insertItem(menuIcon("kruler-west"), i18n("West"), this, SLOT(setWest()), Key_W);
-  oriMenu->insertItem(i18n("Turn Right"), this, SLOT(turnRight()), Key_R);
-  oriMenu->insertItem(i18n("Turn Left"), this, SLOT(turnLeft()), Key_L);
-  mMenu->insertItem(i18n("Orientation"), oriMenu);
+  oriMenu->insertItem(UserIconSet("kruler-north"), i18n("&North"), this, SLOT(setNorth()), Key_N);
+  oriMenu->insertItem(UserIconSet("kruler-east"), i18n("&East"), this, SLOT(setEast()), Key_E);
+  oriMenu->insertItem(UserIconSet("kruler-south"), i18n("&South"), this, SLOT(setSouth()), Key_S);
+  oriMenu->insertItem(UserIconSet("kruler-west"), i18n("&West"), this, SLOT(setWest()), Key_W);
+  oriMenu->insertItem(i18n("&Turn Right"), this, SLOT(turnRight()), Key_R);
+  oriMenu->insertItem(i18n("Turn &Left"), this, SLOT(turnLeft()), Key_L);
+  mMenu->insertItem(i18n("&Orientation"), oriMenu);
   KPopupMenu *lenMenu = new KPopupMenu(this);
-  lenMenu->insertItem(i18n("Short"), this, SLOT(setShortLength()), CTRL+Key_S);
-  lenMenu->insertItem(i18n("Medium"), this, SLOT(setMediumLength()), CTRL+Key_M);
-  lenMenu->insertItem(i18n("Tall"), this, SLOT(setTallLength()), CTRL+Key_T);
-  lenMenu->insertItem(i18n("Full Screen Width"), this, SLOT(setFullLength()), CTRL+Key_F);
-  mMenu->insertItem(i18n("Length"), lenMenu);
-  mMenu->insertItem(i18n("Choose Color..."), this, SLOT(choseColor()), CTRL+Key_C);
+  lenMenu->insertItem(i18n("&Short"), this, SLOT(setShortLength()), CTRL+Key_S);
+  lenMenu->insertItem(i18n("&Medium"), this, SLOT(setMediumLength()), CTRL+Key_M);
+  lenMenu->insertItem(i18n("&Tall"), this, SLOT(setTallLength()), CTRL+Key_T);
+  lenMenu->insertItem(i18n("&Full Screen Width"), this, SLOT(setFullLength()), CTRL+Key_F);
+  mMenu->insertItem(i18n("&Length"), lenMenu);
+  mMenu->insertItem(i18n("&Choose Color..."), this, SLOT(choseColor()), CTRL+Key_C);
+  mMenu->insertItem(i18n("Choose &Font..."), this, SLOT(choseFont()), Key_F);
   mMenu->insertSeparator();
-  mMenu->insertItem(i18n("Help"), helpMenu());
+  mMenu->insertItem(SmallIcon( "help" ), i18n("&Help"), helpMenu());
   mMenu->insertSeparator();
-  mMenu->insertItem(i18n("Quit"), kapp, SLOT(quit()), CTRL+Key_Q);
-	mLastClickPos = geometry().topLeft()+QPoint(width()/2, height()/2);
-	_clicked = false;
+  mMenu->insertItem(SmallIcon( "exit" ), i18n("&Quit"), kapp, SLOT(quit()), CTRL+Key_Q);
+  mLastClickPos = geometry().topLeft()+QPoint(width()/2, height()/2);
 }
+
 KLineal::~KLineal(){
 }
 
@@ -169,7 +175,7 @@ void KLineal::move(const QPoint &p) {
 }
 
 QPoint KLineal::pos() {
-  QRect r = geometry();
+  QRect r = frameGeometry();
   return r.topLeft();
 }
 int KLineal::x() {
@@ -200,17 +206,47 @@ static void rotateRect(QRect &r, QPoint center, int nineties) {
   r.moveBy(center.x(), center.y());
 }
 
+void KLineal::setupBackground() {
+  QColor a, b, bg = mColor;
+  KImageEffect::GradientType gradType = KImageEffect::HorizontalGradient;
+  switch (mOrientation) {
+    case North:
+      a = bg.light(120);
+      b = bg.dark(130);
+      gradType = KImageEffect::VerticalGradient;
+      break;
+    case South:
+      b = bg.light(120);
+      a = bg.dark(130);
+      gradType = KImageEffect::VerticalGradient;
+      break;
+    case West:
+      a = bg.light(120);
+      b = bg.dark(130);
+      gradType = KImageEffect::HorizontalGradient;
+      break;
+    case East:
+      b = bg.light(120);
+      a = bg.dark(130);
+      gradType = KImageEffect::HorizontalGradient;
+      break;
+  }
+  QPixmap bgPixmap = QPixmap(KImageEffect::gradient(size(), a, b, gradType));
+  setErasePixmap(bgPixmap);
+  mLabel->setErasePixmap(bgPixmap);
+}
+
 void KLineal::setOrientation(int inOrientation) {
-  QRect r = geometry();
+  QRect r = frameGeometry();
   int nineties = (int)inOrientation - (int)mOrientation;
-	QPoint center = mLastClickPos;
+  QPoint center = mLastClickPos;
 	
-	if (_clicked) {
-		center = mLastClickPos;
-		_clicked = false;
-	} else {
-		center = r.topLeft()+QPoint(width()/2, height()/2);
-	}
+  if (_clicked) {
+    center = mLastClickPos;
+    _clicked = false;
+   } else {
+     center = r.topLeft()+QPoint(width()/2, height()/2);
+   }
 	
   rotateRect(r, center, nineties);
   setGeometry(r);
@@ -238,6 +274,7 @@ void KLineal::setOrientation(int inOrientation) {
     break;
   }
   setCursor(mCurrentCursor);
+  setupBackground();
   repaint();
 }
 void KLineal::setNorth() {
@@ -276,6 +313,7 @@ void KLineal::reLength(int percentOfScreen) {
   if (y()+height() < 10) {
     move (x(), 10);
   }
+  saveSettings();
 }
 void KLineal::setShortLength() {
   reLength(30);
@@ -298,10 +336,10 @@ void KLineal::choseColor() {
 	if (pos.y() + mColorSelector.height() > screen.height()) {
 		pos.setY(screen.height() - mColorSelector.height());
 	}
-  mStoredColor = backgroundColor();
+  mStoredColor = mColor;
   mColorSelector.move(pos);
   mColorSelector.show();
-  mColorSelector.setColor(backgroundColor());
+  mColorSelector.setColor(mColor);
 
 
   connect(&mColorSelector, SIGNAL(okClicked()), this, SLOT(setColor()));
@@ -315,31 +353,54 @@ void KLineal::choseColor() {
   */
 }
 
+/**
+* slot to choose a font
+*/
+void KLineal::choseFont() {
+  QFont font = mScaleFont;
+  int result = KFontDialog::getFont(font, false, this);
+  if (result == KFontDialog::Accepted) {
+    setFont(font);
+  }
+}
+
+/**
+* set the ruler color to the previously selected color
+*/
+void KLineal::setFont(QFont &font) {
+	mScaleFont = font;
+	saveSettings();
+  repaint();
+}
+
+
 /**
 * set the ruler color to the previously selected color
 */
 void KLineal::setColor() {
 	setColor(mColorSelector.color());
-	saveColor();
+	saveSettings();
 }
 
 /**
-* set the rulere color to some color
+* set the ruler color to some color
 */
 void KLineal::setColor(const QColor &color) {
-  setBackgroundColor(color);
-  mLabel->setBackgroundColor(color);
+  mColor = color;
+  setupBackground();
 }
 
 /**
 * save the ruler color to the config file
 */
-void KLineal::saveColor() {
+void KLineal::saveSettings() {
   KConfig *cfg = kapp->config(); // new KConfig(locateLocal("config", kapp->name()+"rc"));
   if (cfg) {
-      QColor color = backgroundColor();
+      QColor color = mColor;
       cfg->setGroup(CFG_GROUP_SETTINGS);
     	cfg->writeEntry(QString(CFG_KEY_BGCOLOR), color);
+    	cfg->writeEntry(QString(CFG_KEY_SCALE_FONT), mScaleFont);
+    	cfg->writeEntry(QString(CFG_KEY_LENGTH), mLongEdgeLen);
       cfg->sync();
   }
 }
@@ -355,16 +416,7 @@ void KLineal::restoreColor() {
 */
 void KLineal::showMenu() {
 	QPoint pos = QCursor::pos();
-	QSize screen(QApplication::desktop()->size());
-  mMenu->move(pos);
-  mMenu->show();
-	if (pos.x() + mMenu->width() > screen.width()) {
-		pos.setX(screen.width() - mMenu->width());
-	}
-	if (pos.y() + mMenu->height() > screen.height()) {
-		pos.setY(screen.height() - mMenu->height());
-	}
-  mMenu->move(pos);
+	mMenu->popup(pos);
 }
 
 /**
@@ -404,16 +456,16 @@ void KLineal::adjustLabel() {
   QPoint cpos = QCursor::pos();
   switch (mOrientation) {
   case North:
-    s.sprintf("%d", cpos.x()-x());
+    s.sprintf("%d px", cpos.x()-x());
     break;
   case East:
-    s.sprintf("%d", cpos.y()-y());
+    s.sprintf("%d px", cpos.y()-y());
     break;
   case West:
-    s.sprintf("%d", cpos.y()-y());
+    s.sprintf("%d px", cpos.y()-y());
     break;
   case South:
-    s.sprintf("%d", cpos.x()-x());
+    s.sprintf("%d px", cpos.x()-x());
     break;
   }
   mLabel->setText(s);
@@ -421,6 +473,9 @@ void KLineal::adjustLabel() {
 void KLineal::keyPressEvent(QKeyEvent *e) {
 	QPoint dist(0,0);
 	switch (e->key()) {
+	case Key_F1:
+    	kapp->invokeHelp();
+ 			break;
   	case Key_Left:
     	dist.setX(-1);
  			break;
@@ -471,7 +526,7 @@ void KLineal::mouseMoveEvent(QMouseEvent * /*inEvent*/) {
     int h, s, v;
     color.hsv(&h, &s, &v);
  		mColorLabel->setText(color.name().upper());
-  	mColorLabel->setBackgroundColor(color);
+  	mColorLabel->setPaletteBackgroundColor(color);
   	if (v < 255/2) {
   		v = 255;
   	} else {
@@ -521,77 +576,114 @@ void KLineal::mouseReleaseEvent(QMouseEvent * /*inEvent*/) {
 */
 void KLineal::drawScale(QPainter &painter) {
   painter.setPen(black);
-  QFont scaleFont("Helvetica", 8);
-  scaleFont.setPixelSize(8);
-  painter.setFont(scaleFont);
+  QFont font = mScaleFont;
+  // font.setPixelSize(9);
+  painter.setFont(font);
   QFontMetrics metrics = painter.fontMetrics();
   int longCoo;
   int longLen;
   int shortStart;
+  int w = width();
+  int h = height();
+
+  // draw a frame around the whole thing
+  // (for some unknown reason, this doesn't show up anymore)
   switch (mOrientation) {
   case North:
   default:
     shortStart = 0;
-    longLen = width();
-    painter.drawLine(0, 0, 0, height()-1);
-    painter.drawLine(0, height()-1, width()-1, height()-1);
-    painter.drawLine(width()-1, height()-1, width()-1, 0);
+    longLen = w;
+    painter.drawLine(0, 0, 0, h-1);
+    painter.drawLine(0, h-1, w-1, h-1);
+    painter.drawLine(w-1, h-1, w-1, 0);
     // painter.drawLine(width()-1, 0, 0, 0);
     break;
   case East:
-    shortStart = width();
-    longLen = height();
-    painter.drawLine(0, 0, 0, height()-1);
-    painter.drawLine(0, height()-1, width()-1, height()-1);
+    shortStart = w;
+    longLen = h;
+    painter.drawLine(0, 0, 0, h-1);
+    painter.drawLine(0, h-1, w-1, h-1);
     // painter.drawLine(width()-1, height()-1, width()-1, 0);
-    painter.drawLine(width()-1, 0, 0, 0);
+    painter.drawLine(w-1, 0, 0, 0);
     break;
   case South:
-    shortStart = height();
-    longLen = width();
-    painter.drawLine(0, 0, 0, height()-1);
+    shortStart = h;
+    longLen = w;
+    painter.drawLine(0, 0, 0, h-1);
     // painter.drawLine(0, height()-1, width()-1, height()-1);
-    painter.drawLine(width()-1, height()-1, width()-1, 0);
-    painter.drawLine(width()-1, 0, 0, 0);
+    painter.drawLine(w-1, h-1, w-1, 0);
+    painter.drawLine(w-1, 0, 0, 0);
     break;
   case West:
     shortStart = 0;
-    longLen = height();
+    longLen = h;
     // painter.drawLine(0, 0, 0, height()-1);
-    painter.drawLine(0, height()-1, width()-1, height()-1);
-    painter.drawLine(width()-1, height()-1, width()-1, 0);
-    painter.drawLine(width()-1, 0, 0, 0);
+    painter.drawLine(0, h-1, w-1, h-1);
+    painter.drawLine(w-1, h-1, w-1, 0);
+    painter.drawLine(w-1, 0, 0, 0);
     break;
   }
-
+  int ten = 10, twenty = 20, fourty = 40, hundred = 100;
   for (longCoo = 0; longCoo < longLen; longCoo+=2) {
-    int len;
-    if (!(longCoo % 10)) {
-      if (!(longCoo % 20)) {
-      	len = 15;
+    int len = 6;
+    if (ten == 10) {
+      if (twenty == 20) {
+        /**/
+        if (hundred == 100) {
+          font.setBold(true);
+          painter.setFont(font);
+          len = 18;
+        } else {
+      	  len = 15;
+        }
       	QString units;
-      	units.sprintf("%d", longCoo);
+        int digits;
+        if (hundred == 100 || mOrientation == West || mOrientation == East) {
+          digits = longCoo;
+        } else {
+          digits = longCoo % 100;
+        }
+      	units.sprintf("%d", digits);
       	QSize textSize = metrics.size(SingleLine, units);
-      	switch (mOrientation) {
-      	case North:
-      	default:
-      	  painter.drawText(longCoo - textSize.width()/2, shortStart + len + textSize.height(), units);
-      	  break;
-      	case South:
-      	  painter.drawText(longCoo - textSize.width()/2, shortStart - len - 2, units);
-      	  break;
-      	case East:
-      	  painter.drawText(shortStart - len - textSize.width() - 2, longCoo + textSize.height()/2 - 2, units);
-      	  break;
-      	case West:
-      	  painter.drawText(shortStart + len + 2, longCoo + textSize.height()/2 - 2, units);
-      	  break;
-      	}
+        int tw = textSize.width();
+        int th = textSize.height();
+       	switch (mOrientation) {
+       	case North:
+           if (digits < 1000  || fourty == 40 || hundred == 100) {
+            if (longCoo != 0) {
+       	      painter.drawText(longCoo - tw/2, shortStart + len + th, units);
+            } else {
+              painter.drawText(1, shortStart + len + th, units);
+            }
+           }
+       	  break;
+       	case South:
+           if (digits < 1000  || fourty == 40 || hundred == 100) {
+            if (longCoo != 0) {
+       	      painter.drawText(longCoo - tw/2, shortStart - len - 2, units);
+            } else {
+       	      painter.drawText(1, shortStart - len - 2, units);
+            }
+           }
+       	  break;
+       	case East:
+          if (longCoo != 0) {
+       	    painter.drawText(shortStart - len - tw - 2, longCoo + th/2 - 2, units);
+          } else {
+       	    painter.drawText(shortStart - len - tw - 2, th-2, units);
+          }
+       	  break;
+       	case West:
+          if (longCoo != 0) {
+       	    painter.drawText(shortStart + len + 2, longCoo + th/2 - 2, units);
+          } else {
+       	    painter.drawText(shortStart + len + 2, th-2, units);
+          }
+       	  break;
+       	}
       } else {
        	len = 10;
       }
-    } else {
-      len = 6;
     }
     switch(mOrientation) {
     case North:
@@ -607,6 +699,16 @@ void KLineal::drawScale(QPainter &painter) {
       painter.drawLine(shortStart, longCoo, shortStart+len, longCoo);
       break;
     }
+    ten = (ten == 10) ? 2: ten + 2;
+    twenty = (twenty == 20) ? 2: twenty + 2;
+    fourty = (fourty == 40) ? 2: fourty + 2;
+    if (hundred == 100) {
+      hundred = 2;
+      font.setBold(false);
+      painter.setFont(font);
+    } else {
+      hundred += 2;
+    }
   }
 }
 /**
