@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: aboutwidget.h,v 1.1.1.1 2001/08/16 21:31:25 pfeiffer Exp $
+** $Id: aboutwidget.h,v 1.2 2002/03/26 01:20:16 pfeiffer Exp $
 **
 ** AboutWidget, shows some logos and copyright notice
 **
@@ -17,6 +17,8 @@
 #include <qevent.h>
 #include <qvbox.h>
 
+class KURLWidget;
+
 class AboutWidget : public QVBox
 {
     Q_OBJECT
@@ -26,9 +28,10 @@ public:
 
 protected:
     ~AboutWidget();
+    bool eventFilter( QObject*, QEvent * );
 
 private:
-    bool eventFilter( QObject*, QEvent * );
+    KURLWidget *m_homepage;
 
 };
 
