@@ -1,5 +1,5 @@
 /**
- * $Id: defaultswidget.h,v 1.1.1.1 2001/08/16 21:31:23 pfeiffer Exp $
+ * $Id: defaultswidget.h,v 1.5 2002/10/08 15:37:21 pfeiffer Exp $
  *
  * Copyright 1998, 1999 by Carsten Pfeiffer
  */
@@ -8,7 +8,7 @@
 #ifndef DEFAULTSWIDGET_H
 #define DEFAULTSWIDGET_H
 
-#include "basewidget.h"
+#include "kuickdata.h"
 
 class ImlibWidget;
 class ImData;
@@ -18,9 +18,8 @@ class QLabel;
 
 class KComboBox;
 class KIntNumInput;
-class KuickData;
 
-class DefaultsWidget : public BaseWidget
+class DefaultsWidget : public QWidget
 {
   Q_OBJECT
 
@@ -28,13 +27,11 @@ public:
   DefaultsWidget( QWidget *parent, const char *name );
   ~DefaultsWidget();
 
-  void 		loadSettings();
-  void 		applySettings();
-  void 		resetDefaults();
+  void 		loadSettings( const KuickData& data );
+  void 		applySettings( KuickData& data );
 
 private:
-  const int 	currentRotation();
-  void 		init( const KuickData& data );
+  Rotation      currentRotation() const;
 
   QCheckBox 	*cbEnableMods;
 
@@ -57,7 +54,6 @@ private:
 
 private slots:
   void 		updatePreview();
-  void 		slotEnableMaxScale( bool );
   void 		slotNoImage()		{ imFiltered = 0L; }
   void 		enableWidgets( bool );
 
