@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: filewidget.cpp,v 1.10.2.2 2002/07/17 15:02:00 pfeiffer Exp $
+** $Id: filewidget.cpp,v 1.12.2.3 2003/01/13 18:59:53 pfeiffer Exp $
 **
 ** Created : 98
 **
@@ -9,7 +9,6 @@
 
 #include <qkeycode.h>
 
-#include <kapplication.h> // KDE_VERSION
 #include <kglobal.h>
 #include <kglobalsettings.h>
 #include <klocale.h>
@@ -53,6 +52,9 @@ FileWidget::FileWidget( const KURL& url, QWidget *parent, const char *name )
     connect( this, SIGNAL( fileHighlighted( const KFileItem * )),
 	     SLOT( slotHighlighted( const KFileItem * )));
 
+    connect( this, SIGNAL(urlEntered(const KURL&)),
+             SLOT( slotURLEntered( const KURL& )));
+    
     // should actually be KDirOperator's job!
     connect( this, SIGNAL( finishedLoading() ), SLOT( slotFinishedLoading() ));
 }
@@ -125,12 +127,12 @@ void FileWidget::findCompletion( const QString& text )
 {
     if ( text.at(0) == '/' || text.at(0) == '~' ||
 	 text.find('/') != -1 ) {
-	QString t = m_fileFinder->completionObject()->makeCompletion( text );
+	QString t = m_fileFinder->completion()->makeCompletion( text );
 
 	if (m_fileFinder->completionMode() == KGlobalSettings::CompletionPopup ||
             m_fileFinder->completionMode() == KGlobalSettings::CompletionPopupAuto)
 	    m_fileFinder->setCompletedItems(
-			      m_fileFinder->completionObject()->allMatches() );
+			      m_fileFinder->completion()->allMatches() );
 	else
             if ( !t.isNull() )
                 m_fileFinder->setCompletedText( t );
@@ -200,14 +202,31 @@ bool FileWidget::eventFilter( QObject *o, QEvent *e )
     return KDirOperator::eventFilter( o, e );
 }
 
+
+// KIO::NetAccess::stat() does NOT give us the right mimetype, while
+// KIO::NetAccess::mimetype() does. So we have this hacklet to tell
+// showImage that the KFileItem is really an image.
+#define IS_IMAGE 5
+#define MY_TYPE 55
+
 bool FileWidget::isImage( const KFileItem *item )
 {
-    return item && !item->isDir();
-
-//     return ( item && item->isReadable() &&
-//  	     item->mimetype().startsWith( "image/") );
+//     return item && !item->isDir();
+    if ( item )
+    {
+        return item->isReadable() && item->mimetype().startsWith( "image/") ||
+            item->extraData( (void*) MY_TYPE ) == (void*) IS_IMAGE;
+    }
+    return false;
 }
 	
+void FileWidget::setImage( KFileItem& item, bool enable )
+{
+    if ( enable )
+        item.setExtraData( (void*) MY_TYPE, (void*) IS_IMAGE );
+    else
+        item.removeExtraData( (void*) MY_TYPE );
+}
 
 KFileItem * FileWidget::gotoFirstImage()
 {
@@ -347,7 +366,7 @@ void FileWidget::slotReturnPressed( const QString& t )
 	text += '/';
 
     if ( text.at(0) == '/' || text.at(0) == '~' ) {
-	QString dir = (static_cast<KURLCompletion*>( m_fileFinder->completionObject() ))->replacedPath( text );
+	QString dir = m_fileFinder->completion()->replacedPath( text );
 	
 	KURL url;
 	url.setPath( dir );
@@ -355,9 +374,8 @@ void FileWidget::slotReturnPressed( const QString& t )
     }
 
     else if ( text.find('/') != (int) text.length() -1 ) { // relative path
-	QString dir = (static_cast<KURLCompletion*>( m_fileFinder->completionObject() ))->replacedPath( text );
-	KURL u = url();
-	u.addPath( dir );
+	QString dir = m_fileFinder->completion()->replacedPath( text );
+	KURL u( url(), dir );
 	setURL( u, true );
     }
 
@@ -386,6 +404,12 @@ void FileWidget::setInitialItem( const QString& filename )
     m_initialName = filename;
 }
 
+void FileWidget::slotURLEntered( const KURL& url )
+{
+    if ( m_fileFinder )
+        m_fileFinder->completion()->setDir( url.path() );
+}
+
 void FileWidget::slotFinishedLoading()
 {
     KFileItem *current = getCurrentItem( false );
