@@ -1,5 +1,5 @@
 /**
- * $Id: generalwidget.h,v 1.1.1.1 2001/08/16 21:31:23 pfeiffer Exp $
+ * $Id: generalwidget.h,v 1.3 2002/06/12 03:13:54 nhasan Exp $
  *
  * Copyright 1998-2001 by Carsten Pfeiffer <pfeiffer@kde.org>
  */
@@ -7,16 +7,17 @@
 #ifndef GENERALWIDGET_H
 #define GENERALWIDGET_H
 
+#include <qwidget.h>
+
+#include "kuickdata.h"
+
 class QCheckBox;
 class KColorButton;
 class KLineEdit;
 class KIntNumInput;
 
-#include "basewidget.h"
 
-class KuickData;
-
-class GeneralWidget : public BaseWidget
+class GeneralWidget : public QWidget
 {
     Q_OBJECT
 
@@ -24,13 +25,10 @@ public:
     GeneralWidget( QWidget *parent, const char *name );
     ~GeneralWidget();
 
-    void 	loadSettings();
-    void 	applySettings();
-    void 	resetDefaults();
+    void 	loadSettings( const KuickData& data );
+    void 	applySettings( KuickData& data );
 
 private:
-    void 	init( const KuickData& );
-
     QCheckBox 	*cbFullscreen, *cbActiveWindow, *cbPreload;
     QCheckBox   *cbFastRemap, *cbFastRender;
     QCheckBox 	*cbDither16bit, *cbDither8bit, *cbOwnPalette;
@@ -42,9 +40,10 @@ private:
     KIntNumInput 	*sbZoomFactor;
 
     KColorButton        *colorButton;
-    
+
 private slots:
     void 	useOwnPalette();
+    void slotURLClicked( const QString & );
 
 };
 
