@@ -1,5 +1,5 @@
 /***************************************************************************
-** $Id: imagewindow.cpp,v 1.15.2.3 2002/07/17 15:02:00 pfeiffer Exp $
+** $Id: imagewindow.cpp,v 1.38.2.3 2003/01/11 02:23:14 pfeiffer Exp $
 **
 ** ImageWindow: extends the simple  ImlibWidget to display image in a Qt window
 **		can zoom and scroll images inside the QWidget
@@ -12,10 +12,10 @@
 
 #include <stdlib.h>
 
+#include <qcheckbox.h>
 #include <qcursor.h>
 #include <qdrawutil.h>
 #include <qkeycode.h>
-#include <qpaintdevicemetrics.h>
 #include <qpainter.h>
 #include <qpen.h>
 #include <qpopupmenu.h>
@@ -30,7 +30,6 @@
 #include <qtimer.h>
 #include <qdragobject.h>
 
-#include <kaccel.h>
 #include <kapplication.h>
 #include <kconfig.h>
 #include <kcursor.h>
@@ -44,6 +43,7 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kprinter.h>
+#include <kpropertiesdialog.h>
 #include <kstdaccel.h>
 #include <kstandarddirs.h>
 #include <ktempfile.h>
@@ -53,8 +53,7 @@
 #include "imagewindow.h"
 #include "kuick.h"
 #include "kuickdata.h"
-#include "version.h"
-#include <qapplication.h>
+#include "printing.h"
 
 #undef GrayScale
 
@@ -80,7 +79,20 @@ ImageWindow::~ImageWindow()
 
 void ImageWindow::init()
 {
-//   KCursor::setAutoHideCursor( this, true, true );
+    KCursor::setAutoHideCursor( this, true, true );
+    KCursor::setHideCursorDelay( 1500 );
+
+    // give the image window a different WM_CLASS
+    XClassHint hint;
+    hint.res_name = const_cast<char*>( kapp->name() );
+    hint.res_class = const_cast<char*>( "ImageWindow" );
+    XSetClassHint( x11Display(), winId(), &hint );
+
+    viewerMenu = 0L;
+    gammaMenu = 0L;
+    brightnessMenu = 0L;
+    contrastMenu = 0L;
+
 
     m_actions = new KActionCollection( this );
 
@@ -92,26 +104,19 @@ void ImageWindow::init()
             s_handCursor = new QCursor( arrowCursor );
     }
 
-    new KAction( i18n("Show next Image"), KStdAccel::next(),
-                 this, SLOT( slotRequestNext() ),
-                 m_actions, "next_image" );
+    setupActions();
+    imageCache->setMaxImages( kdata->maxCachedImages );
 
-    new KAction( i18n("Show previous Image"), KStdAccel::prior(),
-                 this, SLOT( slotRequestPrevious() ),
-                 m_actions, "previous_image" );
-
-
-    m_accel        = 0L;
     transWidget    = 0L;
     myIsFullscreen = false;
     initialFullscreen = kdata->fullScreen;
     ignore_resize_hack = false;
 
     xpos = 0, ypos = 0;
+    m_width = width(); m_height = height();
     m_numHeads = ScreenCount( x11Display() );
 
     setAcceptDrops( true );
-    updateAccel();
     setBackgroundColor( kdata->backgroundColor );
 
     static QPixmap imageIcon = UserIcon( "imageviewer-medium" );
@@ -119,59 +124,106 @@ void ImageWindow::init()
     KWin::setIcons( winId(), imageIcon, miniImageIcon );
 }
 
-
-void ImageWindow::updateAccel()
+void ImageWindow::updateActions()
 {
-  delete m_accel;
+    m_actions->readShortcutSettings();
+}
 
-  // configurable shortcuts
-  // yeah, I know you've waited for them for a long time :o)
-  m_accel = new KAccel( this );
+void ImageWindow::setupActions()
+{
+    new KAction( i18n("Show Next Image"), KStdAccel::next(),
+                 this, SLOT( slotRequestNext() ),
+                 m_actions, "next_image" );
+    new KAction( i18n("Show Previous Image"), KStdAccel::prior(),
+                 this, SLOT( slotRequestPrevious() ),
+                 m_actions, "previous_image" );
 
-  m_accel->insert( "Scroll Up", i18n( "Scroll Up" ), QString::null,
-                   Key_Up, this, SLOT( scrollUp() ) );
-  m_accel->insert( "Scroll Down", i18n( "Scroll Down" ), QString::null,
-                   Key_Down, this, SLOT( scrollDown() ) );
-  m_accel->insert( "Scroll Left", i18n( "Scroll Left" ), QString::null,
-                   Key_Left, this, SLOT( scrollLeft() ) );
-  m_accel->insert( "Scroll Right", i18n( "Scroll Right" ), QString::null,
-                   Key_Right, this, SLOT( scrollRight() ) );
-  m_accel->insert( "Zoom In", i18n( "Zoom In" ), QString::null,
-                   Key_Plus, this, SLOT( zoomIn() ) );
-  m_accel->insert( "Zoom Out", i18n( "Zoom Out" ), QString::null,
-                   Key_Minus, this, SLOT( zoomOut() ) );
-  m_accel->insert( "Flip Horizontally", i18n( "Flip Horizontally" ), QString::null,
-                   Key_Asterisk, this, SLOT( flipHoriz() ) );
-  m_accel->insert( "Flip Vertically", i18n( "Flip Vertically" ), QString::null,
-                   Key_Slash, this, SLOT( flipVert() ) );
-  m_accel->insert( "Rotate 90", i18n( "Rotate 90 degrees" ), QString::null,
-                   Key_9, this, SLOT( rotate90() ) );
-  m_accel->insert( "Rotate 180", i18n( "Rotate 180 degrees" ), QString::null,
-                   Key_8, this, SLOT( rotate180() ) );
-  m_accel->insert( "Rotate 270", i18n( "Rotate 270 degrees" ), QString::null,
-                   Key_7, this, SLOT( rotate270() ) );
-  m_accel->insert( "Maximize", i18n( "Maximize" ), QString::null,
-                   Key_M, this, SLOT( maximize() ) );
-  m_accel->insert( "OriginalSize", i18n( "Restore original size" ), QString::null,
-                   Key_O, this, SLOT( showImageOriginalSize() ));
-  m_accel->insert( "More Brightness", i18n( "More Brightness" ), QString::null,
-                   Key_B, this, SLOT( moreBrightness() ) );
-  m_accel->insert( "Less Brightness", i18n( "Less Brightness" ), QString::null,
-                   SHIFT + Key_B, this, SLOT( lessBrightness() ) );
-  m_accel->insert( "More Contrast", i18n( "More Contrast" ), QString::null,
-                   Key_C, this, SLOT( moreContrast() ) );
-  m_accel->insert( "Less Contrast", i18n( "Less Contrast" ), QString::null,
-                   SHIFT + Key_C, this, SLOT( lessContrast() ) );
-  m_accel->insert( "More Gamma", i18n( "More Gamma" ), QString::null,
-                   Key_G, this, SLOT( moreGamma() ) );
-  m_accel->insert( "Less Gamma", i18n( "Less Gamma" ), QString::null,
-                   SHIFT + Key_G, this, SLOT( lessGamma() ) );
-  m_accel->insert( "Toggle Fullscreen", i18n( "Toggle Fullscreen mode" ), QString::null,
-                   Key_Return, this, SLOT( toggleFullscreen() ) );
-  m_accel->insert( "Close", i18n( "Close Viewer" ), QString::null,
-                   Key_Q, this, SLOT( close() ) );
+    new KAction( i18n("Zoom In"), Key_Plus,
+                 this, SLOT( zoomIn() ),
+                 m_actions, "zoom_in" );
+    new KAction( i18n("Zoom Out"), Key_Minus,
+                 this, SLOT( zoomOut() ),
+                 m_actions, "zoom_out" );
+    new KAction( i18n("Restore Original Size"), Key_O,
+                 this, SLOT( showImageOriginalSize() ),
+                 m_actions, "original_size" );
+    new KAction( i18n("Maximize"), Key_M,
+                 this, SLOT( maximize() ),
+                 m_actions, "maximize" );
 
-  m_accel->readSettings();
+    new KAction( i18n("Rotate 90 degrees"), Key_9,
+                 this, SLOT( rotate90() ),
+                 m_actions, "rotate90" );
+    new KAction( i18n("Rotate 180 degrees"), Key_8,
+                 this, SLOT( rotate180() ),
+                 m_actions, "rotate180" );
+    new KAction( i18n("Rotate 270 degrees"), Key_7,
+                 this, SLOT( rotate270() ),
+                 m_actions, "rotate270" );
+
+    new KAction( i18n("Flip Horizontally"), Key_Asterisk,
+                 this, SLOT( flipHoriz() ),
+                 m_actions, "flip_horicontally" );
+    new KAction( i18n("Flip Vertically"), Key_Slash,
+                 this, SLOT( flipVert() ),
+                 m_actions, "flip_vertically" );
+
+    new KAction( i18n("Print Image..."), KStdAccel::print(),
+                 this, SLOT( printImage() ),
+                 m_actions, "print_image" );
+    new KAction( i18n("Save As..."), KStdAccel::save(),
+                 this, SLOT( saveImage() ),
+                 m_actions, "save_image_as" );
+
+    new KAction( i18n("Close"), Key_Q,
+                 this, SLOT( close() ),
+                 m_actions, "close_image" );
+    // --------
+    new KAction( i18n("More Brightness"), Key_B,
+                 this, SLOT( moreBrightness() ),
+                 m_actions, "more_brightness" );
+    new KAction( i18n("Less Brightness"), SHIFT + Key_B,
+                 this, SLOT( lessBrightness() ),
+                 m_actions, "less_brightness" );
+    new KAction( i18n("More Contrast"), Key_C,
+                 this, SLOT( moreContrast() ),
+                 m_actions, "more_contrast" );
+    new KAction( i18n("Less Contrast"), SHIFT + Key_C,
+                 this, SLOT( lessContrast() ),
+                 m_actions, "less_contrast" );
+    new KAction( i18n("More Gamma"), Key_G,
+                 this, SLOT( moreGamma() ),
+                 m_actions, "more_gamma" );
+    new KAction( i18n("Less Gamma"), SHIFT + Key_G,
+                 this, SLOT( lessGamma() ),
+                 m_actions, "less_gamma" );
+
+    // --------
+    new KAction( i18n("Scroll Up"), Key_Up,
+                 this, SLOT( scrollUp() ),
+                 m_actions, "scroll_up" );
+    new KAction( i18n("Scroll Down"), Key_Down,
+                 this, SLOT( scrollDown() ),
+                 m_actions, "scroll_down" );
+    new KAction( i18n("Scroll Left"), Key_Left,
+                 this, SLOT( scrollLeft() ),
+                 m_actions, "scroll_left" );
+    new KAction( i18n("Scroll Right"), Key_Right,
+                 this, SLOT( scrollRight() ),
+                 m_actions, "scroll_right" );
+
+    new KAction( i18n("Toggle Fullscreen mode"), Key_Return,
+                 this, SLOT( toggleFullscreen() ),
+                 m_actions, "toggle_fullscreen" );
+    new KAction( i18n("Reload Image"), Key_Enter,
+                 this, SLOT( reload() ),
+                 m_actions, "reload_image" );
+
+    new KAction( i18n("Properties..."), ALT + Key_Return,
+                 this, SLOT( slotProperties() ),
+                 m_actions, "properties" );
+
+    m_actions->readShortcutSettings();
 }
 
 
@@ -180,42 +232,43 @@ void ImageWindow::setFullscreen( bool enable )
     xpos = 0; ypos = 0;
 
     if ( enable && !myIsFullscreen ) { // set Fullscreen
-	KWin::Info info = KWin::info( winId() );
-	oldGeometry = info.frameGeometry;
+        KWin::Info info = KWin::info( winId() );
+        oldGeometry = info.frameGeometry;
 
 	// qDebug("** oldGeometry: %i, %i, %i, %i",
 	// oldGeometry.x(), oldGeometry.y(),
 	// oldGeometry.width(), oldGeometry.height());
 
         int scnum = QApplication::desktop()->screenNumber(this);
-	setFixedSize( QApplication::desktop()->screenGeometry(scnum).size() );
+        setFixedSize( QApplication::desktop()->screenGeometry(scnum).size() );
 
-	KWin::setType( winId(), NET::Override );
-	KWin::setState( winId(), NET::StaysOnTop );
+        KWin::setType( winId(), NET::Override );
+        KWin::setState( winId(), NET::StaysOnTop );
+
+        setGeometry( QApplication::desktop()->screenGeometry(scnum) );
+        // qApp->processEvents(); // not necessary anymore
 
-	setGeometry( QApplication::desktop()->screenGeometry(scnum) );
-	// qApp->processEvents(); // not necessary anymore
     }
 
     else if ( !enable && myIsFullscreen ) { // go into window mode
-	bool wasInitialFullscreen = initialFullscreen;
-	initialFullscreen = false;
+        bool wasInitialFullscreen = initialFullscreen;
+        initialFullscreen = false;
 	
-	ignore_resize_hack = true; //ignore the resizeEvent triggered by move()
-	move( oldGeometry.topLeft() );
- 	setMinimumSize(0,0);
-	myIsFullscreen = false; // we want resizeOptimal to use window-mode
-	resizeOptimal( imageWidth(), imageHeight() ); // resizeEvent centers
+        ignore_resize_hack = true; //ignore the resizeEvent triggered by move()
+        move( oldGeometry.topLeft() );
+        setMinimumSize(0,0);
+        myIsFullscreen = false; // we want resizeOptimal to use window-mode
+        resizeOptimal( imageWidth(), imageHeight() ); // resizeEvent centers
 
-	KWin::setType( winId(), NET::Normal );
-	KWin::clearState( winId(), NET::StaysOnTop );
+        KWin::setType( winId(), NET::Normal );
+        KWin::clearState( winId(), NET::StaysOnTop );
 
-	// hack around kwin not giving us a decoration, when going into window
-	// mode and initially started in fullscreen mode
+        // hack around kwin not giving us a decoration, when going into window
+        // mode and initially started in fullscreen mode
         if ( wasInitialFullscreen ) {
             hide();
             show();
-    }
+        }
     }
 
     myIsFullscreen = enable;
@@ -225,6 +278,7 @@ void ImageWindow::setFullscreen( bool enable )
 
 void ImageWindow::updateGeometry( int imWidth, int imHeight )
 {
+//     qDebug("::updateGeometry: %i, %i", imWidth, imHeight);
     //  XMoveWindow( x11Display(), win, 0, 0 );
     XResizeWindow( x11Display(), win, imWidth, imHeight );
 
@@ -244,10 +298,10 @@ void ImageWindow::updateGeometry( int imWidth, int imHeight )
 
     QString caption = i18n( "Filename (Imagewidth x Imageheight)",
                             "%1 (%2 x %3)" );
-    caption = caption.arg( kuim->filename() ).
-              arg( kuim->originalWidth() ).
-              arg( kuim->originalHeight() );
-    setCaption( kapp->makeStdCaption( caption ));
+    caption = caption.arg( m_kuim->filename() ).
+              arg( m_kuim->originalWidth() ).
+              arg( m_kuim->originalHeight() );
+    setCaption( kapp->makeStdCaption( caption ) );
 }
 
 
@@ -337,6 +391,10 @@ bool ImageWindow::showNextImage( const QString& filename )
     }
 }
 
+void ImageWindow::reload()
+{
+    showNextImage( filename() );
+}
 
 void ImageWindow::addBrightness( int factor )
 {
@@ -507,16 +565,18 @@ void ImageWindow::mousePressEvent( QMouseEvent *e )
             setCursor( *s_handCursor );
     }
 
-    if ( e->button() == RightButton )
-	viewerMenu->popup( mapToGlobal( e->pos() ) );
+    ImlibWidget::mousePressEvent( e );
 }
 
-void ImageWindow::mouseDoubleClickEvent( QMouseEvent *e )
+void ImageWindow::contextMenuEvent( QContextMenuEvent *e )
 {
-    if ( e->button() == LeftButton )
-	close( true );
-}
+    e->accept();
 
+    if ( !viewerMenu )
+        setPopupMenu();
+
+    viewerMenu->popup( e->globalPos() );
+}
 
 void ImageWindow::mouseMoveEvent( QMouseEvent *e )
 {
@@ -534,6 +594,7 @@ void ImageWindow::mouseMoveEvent( QMouseEvent *e )
 
   	transWidget->hide();
 	QPainter p( transWidget );
+ 	// really required?
  	p.eraseRect( transWidget->rect() );
 	transWidget->show();
 	qApp->processOneEvent();
@@ -641,7 +702,7 @@ void ImageWindow::mouseReleaseEvent( QMouseEvent *e )
     xtmp += xcenter;
     ytmp += ycenter;
 
-    kuim->resize( w, h );
+    m_kuim->resize( w, h );
     XResizeWindow( x11Display(), win, w, h );
     updateWidget( false );
 
@@ -662,6 +723,10 @@ void ImageWindow::resizeEvent( QResizeEvent *e )
 {
     ImlibWidget::resizeEvent( e );
 
+    // to save a lot of calls in scrollImage() for example
+    m_width  = width();
+    m_height = height();
+
     if ( ignore_resize_hack ) {
 	ignore_resize_hack = false;
 	
@@ -676,10 +741,6 @@ void ImageWindow::resizeEvent( QResizeEvent *e )
 	}
     }
 
-    // to save a lot of calls in scrollImage() for example
-    m_width  = width();
-    m_height = height();
-
     centerImage();
 }
 
@@ -714,191 +775,116 @@ void ImageWindow::dropEvent( QDropEvent *e )
 
 void ImageWindow::setPopupMenu()
 {
-  viewerMenu = new QPopupMenu( this );
+    viewerMenu = new QPopupMenu( this );
 
-  m_actions->action("next_image")->plug( viewerMenu );
-  m_actions->action("previous_image")->plug( viewerMenu );
-  viewerMenu->insertSeparator();
+    m_actions->action("next_image")->plug( viewerMenu );
+    m_actions->action("previous_image")->plug( viewerMenu );
+    viewerMenu->insertSeparator();
 
-  brightnessMenu = new QPopupMenu( viewerMenu );
+    brightnessMenu = new QPopupMenu( viewerMenu );
+    m_actions->action("more_brightness")->plug(brightnessMenu);
+    m_actions->action("less_brightness")->plug(brightnessMenu);
 
-  itemBrightnessPlus = brightnessMenu->insertItem( i18n("+"), this,
-						   SLOT( moreBrightness() ));
-  itemBrightnessMinus = brightnessMenu->insertItem( i18n("-"), this,
-						    SLOT( lessBrightness() ));
+    contrastMenu = new QPopupMenu( viewerMenu );
+    m_actions->action("more_contrast")->plug(contrastMenu);
+    m_actions->action("less_contrast")->plug(contrastMenu);
 
-  contrastMenu = new QPopupMenu( viewerMenu );
-  itemContrastPlus = contrastMenu->insertItem( i18n("+"), this,
-					       SLOT( moreContrast() ));
-  itemContrastMinus = contrastMenu->insertItem( i18n("-"), this,
-						SLOT( lessContrast() ));
+    gammaMenu = new QPopupMenu( viewerMenu );
+    m_actions->action("more_gamma")->plug(gammaMenu);
+    m_actions->action("less_gamma")->plug(gammaMenu);
 
-  gammaMenu = new QPopupMenu( viewerMenu );
-  itemGammaPlus = gammaMenu->insertItem( i18n("+"), this, SLOT( moreGamma() ));
-  itemGammaMinus = gammaMenu->insertItem( i18n("-"), this,SLOT( lessGamma() ));
+    m_actions->action("zoom_in")->plug( viewerMenu );
+    m_actions->action("zoom_out")->plug( viewerMenu );
+    m_actions->action("original_size")->plug( viewerMenu );
+    m_actions->action("maximize")->plug( viewerMenu );
 
-  itemViewerZoomIn = viewerMenu->insertItem( i18n("Zoom in"), this,
-					     SLOT( zoomIn() ));
-  itemViewerZoomOut = viewerMenu->insertItem( i18n("Zoom out"), this,
-					      SLOT( zoomOut() ));
-  viewerMenu->insertSeparator();
-  itemRotate90    = viewerMenu->insertItem( i18n("Rotate 90 degrees"), this,
-					    SLOT( rotate90() ));
-  itemRotate180   = viewerMenu->insertItem( i18n("Rotate 180 degrees"), this,
-					    SLOT( rotate180() ));
-  itemRotate270   = viewerMenu->insertItem( i18n("Rotate 270 degrees"), this,
-					    SLOT( rotate270() ));
-  viewerMenu->insertSeparator();
-  itemViewerFlipH = viewerMenu->insertItem( i18n("Flip horizontally"), this,
-					    SLOT( flipHoriz() ));
-  itemViewerFlipV = viewerMenu->insertItem( i18n("Flip vertically"), this,
-					    SLOT( flipVert() ));
-  viewerMenu->insertSeparator();
-  viewerMenu->insertItem( i18n("Brightness"), brightnessMenu );
-  viewerMenu->insertItem( i18n("Contrast"), contrastMenu );
-  viewerMenu->insertItem( i18n("Gamma"), gammaMenu );
-  viewerMenu->insertSeparator();
-  itemViewerPrint = viewerMenu->insertItem( i18n("Print image..."), this,
-					    SLOT( printImage() ));
-  itemViewerSave = viewerMenu->insertItem( i18n("Save as..."), this,
-					   SLOT( saveImage() ));
-  viewerMenu->insertSeparator();
-  itemViewerClose = viewerMenu->insertItem( i18n("Close"), this,
-					    SLOT( close() ));
+    viewerMenu->insertSeparator();
+    m_actions->action("rotate90")->plug( viewerMenu );
+    m_actions->action("rotate180")->plug( viewerMenu );
+    m_actions->action("rotate270")->plug( viewerMenu );
 
-  setPopupAccels();
+    viewerMenu->insertSeparator();
+    m_actions->action("flip_vertically")->plug( viewerMenu );
+    m_actions->action("flip_horicontally")->plug( viewerMenu );
+    viewerMenu->insertSeparator();
+    viewerMenu->insertItem( i18n("Brightness"), brightnessMenu );
+    viewerMenu->insertItem( i18n("Contrast"), contrastMenu );
+    viewerMenu->insertItem( i18n("Gamma"), gammaMenu );
+    viewerMenu->insertSeparator();
+
+    m_actions->action("print_image")->plug( viewerMenu );
+    m_actions->action("save_image_as")->plug( viewerMenu );
+    m_actions->action("properties")->plug( viewerMenu );
+
+    viewerMenu->insertSeparator();
+    m_actions->action("close_image")->plug( viewerMenu );
 }
 
-
-void ImageWindow::setPopupAccels()
-{
-  brightnessMenu->setAccel(m_accel->shortcut("More Brightness").keyCodeQt(),
-                           itemBrightnessPlus);
-  brightnessMenu->setAccel(m_accel->shortcut("Less Brightness").keyCodeQt(),
-                           itemBrightnessMinus);
-  contrastMenu->setAccel(m_accel->shortcut("More Contrast").keyCodeQt(),
-                         itemContrastPlus);
-  contrastMenu->setAccel(m_accel->shortcut("Less Contrast").keyCodeQt(),
-                         itemContrastMinus);
-  gammaMenu->setAccel(m_accel->shortcut("More Gamma").keyCodeQt(),
-                      itemGammaPlus);
-  gammaMenu->setAccel(m_accel->shortcut("Less Gamma").keyCodeQt(),
-                      itemGammaMinus);
-  viewerMenu->setAccel(m_accel->shortcut("Zoom In").keyCodeQt(),
-                       itemViewerZoomIn);
-  viewerMenu->setAccel(m_accel->shortcut("Zoom Out").keyCodeQt(),
-                       itemViewerZoomOut);
-  viewerMenu->setAccel(m_accel->shortcut("Rotate 90").keyCodeQt(),
-                       itemRotate90);
-  viewerMenu->setAccel(m_accel->shortcut("Rotate 180").keyCodeQt(),
-                       itemRotate180);
-  viewerMenu->setAccel(m_accel->shortcut("Rotate 270").keyCodeQt(),
-                       itemRotate270);
-  viewerMenu->setAccel(m_accel->shortcut("Flip Horizontally").keyCodeQt(),
-                       itemViewerFlipH);
-  viewerMenu->setAccel(m_accel->shortcut("Flip Vertically").keyCodeQt(),
-                       itemViewerFlipV);
-  viewerMenu->setAccel(m_accel->shortcut("Close Viewer").keyCodeQt(),
-                       itemViewerClose);
-  viewerMenu->setAccel(KStdAccel::print().keyCodeQt(), itemViewerPrint);
-  viewerMenu->setAccel(KStdAccel::save().keyCodeQt(),  itemViewerSave);
-}
-
-
 void ImageWindow::printImage()
 {
-    if ( !kuim )
+    if ( !m_kuim )
         return;
-    
-  KPrinter printer;
-  printer.setFullPage( true );
-  printer.setDocName( kuim->filename() );
-  printer.setCreator( "KuickShow-" KUICKSHOWVERSION );
-    
-  if ( printer.setup( this ) ) 
-  {
-      QString tmpName;
-      bool ok = false;
-      
-      KTempFile tmpFile( "kuickshow", ".png" );
-      if ( tmpFile.status() == 0 ) 
-      {
-          tmpFile.setAutoDelete( true );
-          tmpName = tmpFile.name();
 
-          ok = saveImage( tmpName );
-      }
-      
-      if ( ok )
-      printImageWithQt( tmpName, printer );
-      else
-          qDebug("KuickShow: Couldn't print image."); // FIXME, show messagebox
-  }
-
-//   if ( Imlib_save_image( id, kuim->imlibImage(),
-//                          QFile::encodeName( tmpName ).data(), &info ) == 0 )
-
-}
-
-void ImageWindow::printImageWithQt( const QString& filename, KPrinter& printer)
-{
-    QImage image( filename );
-    if ( image.isNull() ) {
-        kdWarning() << "Can't load image: " << filename << " for printing.\n";
-        return;
+    if ( !Printing::printImage( *this, this ) )
+    {
+        KMessageBox::sorry( this, i18n("Unable to print the image."),
+                            i18n("Printing Failed") );
     }
-    
-    QPainter p;
-    p.begin( &printer );
-    
-    QPaintDeviceMetrics metrics( &printer );
-    int w = metrics.width();
-    int h = metrics.height();
-
-    // shrink image to pagesize, if necessary
-    if ( image.width() > w || image.height() > h ) {
-        image = image.smoothScale( w, h, QImage::ScaleMin );
-    }
-    
-    // center image
-    int x = (w - image.width())/2;
-    int y = (h - image.height())/2;
-    p.drawImage( x, y, image );
-    p.end();
 }
 
 void ImageWindow::saveImage()
 {
-    QString file;
+    if ( !m_kuim )
+        return;
+
     KuickData tmp;
-    file = KFileDialog::getSaveFileName( kuim->filename(), tmp.fileFilter );
-    if ( !file.isEmpty() )
+    QCheckBox *keepSize = new QCheckBox( i18n("Keep original Image Size"), 0L);
+    keepSize->setChecked( true );
+    KFileDialog dlg( QString::null, tmp.fileFilter, this, "filedialog", true,
+                     keepSize );
+    dlg.setSelection( m_kuim->filename() );
+    dlg.setOperationMode( KFileDialog::Saving );
+    dlg.setCaption( i18n("Save As") );
+    if ( dlg.exec() == QDialog::Accepted )
     {
-        if ( !saveImage( file ) ) 
+        QString file = dlg.selectedFile();
+        if ( !file.isEmpty() )
         {
-            QString tmp = i18n("Couldn't save the file.\n"
-                               "Perhaps the disk is full, or you don't "
-                               "have write permission to the file.");
-            KMessageBox::sorry( this, tmp, i18n("File saving failed"));
+            if ( !saveImage( file, keepSize->isChecked() ) )
+            {
+                QString tmp = i18n("Couldn't save the file.\n"
+                                   "Perhaps the disk is full, or you don't "
+                                   "have write permission to the file.");
+                KMessageBox::sorry( this, tmp, i18n("File Saving Failed"));
+            }
+        
+            if ( file == m_kuim->filename() ) {
+                Imlib_apply_modifiers_to_rgb( id, m_kuim->imlibImage() );
+            }
         }
     }
 }
 
-bool ImageWindow::saveImage( const QString& filename )
+bool ImageWindow::saveImage( const QString& filename, bool keepOriginalSize ) const
 {
-    ImlibImage *saveIm = Imlib_clone_scaled_image( id, kuim->imlibImage(),
-                                                   kuim->width(), 
-                                                   kuim->height() );
+    int w = keepOriginalSize ? m_kuim->originalWidth()  : m_kuim->width();
+    int h = keepOriginalSize ? m_kuim->originalHeight() : m_kuim->height();
+    if ( m_kuim->absRotation() == ROT_90 || m_kuim->absRotation() == 270 )
+        qSwap( w, h );
+        
+    ImlibImage *saveIm = Imlib_clone_scaled_image( id, m_kuim->imlibImage(),
+                                                   w, h );
+    bool success = false;
+    
     if ( saveIm ) {
         Imlib_apply_modifiers_to_rgb( id, saveIm );
-        bool success = Imlib_save_image( id, saveIm, 
-                                         QFile::encodeName( filename ).data(), 
+        success = Imlib_save_image( id, saveIm,
+                                         QFile::encodeName( filename ).data(),
                                          NULL );
         Imlib_kill_image( id, saveIm );
-        return success;
     }
 
-    return false;
+    return success;
 }
 
 void ImageWindow::toggleFullscreen()
@@ -906,14 +892,21 @@ void ImageWindow::toggleFullscreen()
     setFullscreen( !myIsFullscreen );
 }
 
-// upscale/downscale depending on configuration
 void ImageWindow::loaded( KuickImage *kuim )
 {
-    if ( !(kdata->isModsEnabled || kdata->upScale || kdata->downScale) ) {
+    if ( !kdata->isModsEnabled ) {
 	kuim->restoreOriginalSize();
-	return;
     }
+    else
+    {
+        autoRotate( kuim );
+        autoScale( kuim );
+    }
+}
 
+// upscale/downscale depending on configuration
+void ImageWindow::autoScale( KuickImage *kuim )
+{
     int newW = kuim->originalWidth();
     int newH = kuim->originalHeight();
 
@@ -921,8 +914,17 @@ void ImageWindow::loaded( KuickImage *kuim )
     int mw = s.width();
     int mh = s.height();
 
-    if ( kdata->upScale ) {
-	if ( (newW < mw) && (newH < mh) ) {
+    if ( kuim->absRotation() == ROT_90 || kuim->absRotation() == ROT_270 )
+        qSwap( newW, newH );
+
+    bool doIt = false;
+
+    if ( kdata->upScale )
+    {
+	if ( (newW < mw) && (newH < mh) )
+        {
+            doIt = true;
+
 	    float ratio1, ratio2;
 	    int maxUpScale = kdata->maxUpScale;
 
@@ -936,10 +938,15 @@ void ImageWindow::loaded( KuickImage *kuim )
 	}
     }
 
-    if ( kdata->downScale ) {
+    if ( kdata->downScale )
+    {
 	// eventually set width and height to the best/max possible screen size
-	if ( (newW > mw) || (newH > mh) ) {
-	    if ( newW > mw ) {
+	if ( (newW > mw) || (newH > mh) )
+        {
+            doIt = true;
+
+	    if ( newW > mw )
+            {
 		float ratio = (float) newW / (float) newH;
 		newW = mw;
 		newH = (int) ((float) newW / ratio);
@@ -954,17 +961,47 @@ void ImageWindow::loaded( KuickImage *kuim )
 	}
     }
 
-    kuim->resize( newW, newH );
+    if ( doIt )
+        kuim->resize( newW, newH );
+}
+
+// only called when kdata->isModsEnabled is true
+bool ImageWindow::autoRotate( KuickImage *kuim )
+{
+    if ( kdata->autoRotation && ImlibWidget::autoRotate( kuim ) )
+        return true;
+
+    else // rotation by metadata not available or not configured
+    {
+        // only apply default mods to newly loaded images
+
+        // ### actually we should have a dirty flag ("neverManuallyFlipped")
+        if ( kuim->flipMode() == FlipNone )
+        {
+            int flipMode = 0;
+            if ( kdata->flipVertically )
+                flipMode |= FlipVertical;
+            if ( kdata->flipHorizontally )
+                flipMode |= FlipHorizontal;
+
+            kuim->flipAbs( flipMode );
+        }
+
+        if ( kuim->absRotation() == ROT_0 )
+            kuim->rotateAbs( kdata->rotation );
+    }
+
+    return true;
 }
 
 int ImageWindow::desktopWidth( bool totalScreen ) const
 {
-    if ( myIsFullscreen || totalScreen ) {
+    if ( myIsFullscreen || totalScreen )
+    {
         int scnum = QApplication::desktop()->screenNumber(topLevelWidget());
 	return QApplication::desktop()->screenGeometry(scnum).width();
-    } else {
+    } else
 	return Kuick::workArea().width();
-    }
 }
 
 
@@ -983,7 +1020,8 @@ QSize ImageWindow::maxImageSize() const
     if ( myIsFullscreen || initialFullscreen ) {
         int scnum = QApplication::desktop()->screenNumber(topLevelWidget());
 	return QApplication::desktop()->screenGeometry(scnum).size();
-    } else {
+    }
+    else {
 	return Kuick::workArea().size() - Kuick::frameSize( winId() );
     }
 }
@@ -1004,7 +1042,7 @@ void ImageWindow::resizeOptimal( int w, int h )
 
 void ImageWindow::maximize()
 {
-    if ( !kuim )
+    if ( !m_kuim )
 	return;
 
     bool oldUpscale = kdata->upScale;
@@ -1013,7 +1051,7 @@ void ImageWindow::maximize()
     kdata->upScale = true;
     kdata->downScale = true;
 
-    loaded( kuim );
+    autoScale( m_kuim );
     updateWidget( true );
 
     if ( !myIsFullscreen )
@@ -1023,4 +1061,12 @@ void ImageWindow::maximize()
     kdata->downScale = oldDownscale;
 }
 
+void ImageWindow::slotProperties()
+{
+    KURL url;
+    url.setPath( filename() ); // ###
+    (void) new KPropertiesDialog( url, this, "props dialog", true );
+}
+
+
 #include "imagewindow.moc"
