@@ -1,5 +1,5 @@
 /***************************************************************************
-** $Id: imlibwidget.cpp,v 1.1.1.1.2.2 2002/07/05 13:57:27 pfeiffer Exp $
+** $Id: imlibwidget.cpp,v 1.11.2.2 2003/01/11 02:23:14 pfeiffer Exp $
 **
 ** ImlibWidget: maps an Xlib window with Imlib's contents on a QWidget
 **		can zoom and modify (brighten, ...) images inside the QWidget
@@ -19,14 +19,17 @@
 
 #include <qcolor.h>
 #include <qfile.h>
+#include <qglobal.h>
 #include <qobject.h>
 #include <qpalette.h>
 
 #include <kcursor.h>
 #include <kdebug.h>
+#include <kfilemetainfo.h>
 
 #include "imlibwidget.h"
 
+const int ImlibWidget::ImlibOffset = 256;
 
 ImlibWidget::ImlibWidget( ImData *_idata, QWidget *parent, const char *name ) :
   QWidget( parent, name, WDestructiveClose )
@@ -86,10 +89,8 @@ void ImlibWidget::init()
 {
     int w = 1; // > 0 for XCreateWindow
     int h = 1;
-    myRotation        = ROT_0;
-    myFlipMode        = FlipNone;
     myBackgroundColor = Qt::black;
-    kuim              = 0L;
+    m_kuim              = 0L;
 
     if ( !id )
 	qFatal("ImlibWidget: Imlib not initialized, aborting.");
@@ -99,7 +100,7 @@ void ImlibWidget::init()
     setPalette( QPalette( myBackgroundColor ));
     setBackgroundMode( PaletteBackground );
 
-    imageCache = new ImageCache( id, 3 ); // cache three images (FIXME?)
+    imageCache = new ImageCache( id, 4 ); // cache 4 images (FIXME?)
     connect( imageCache, SIGNAL( sigBusy() ), SLOT( setBusyCursor() ));
     connect( imageCache, SIGNAL( sigIdle() ), SLOT( restoreCursor() ));
 
@@ -108,10 +109,10 @@ void ImlibWidget::init()
 
 ImlibWidget::~ImlibWidget()
 {
-    if ( deleteImlibData ) delete id;
+    delete imageCache;
+    if ( deleteImlibData && id ) free ( id );
     if ( win ) XDestroyWindow( x11Display(), win );
     if ( deleteImData ) delete idata;
-    delete imageCache;
 }
 
 KURL ImlibWidget::url() const
@@ -121,7 +122,7 @@ KURL ImlibWidget::url() const
         url.setPath( m_filename );
     else
         url = m_filename;
-    
+
     return url;
 }
 
@@ -134,15 +135,15 @@ KuickImage * ImlibWidget::loadImageInternal( const QString& filename )
     mod.contrast = idata->contrast + ImlibOffset;
     mod.gamma = idata->gamma + ImlibOffset;
 
-    KuickImage *myKuim = imageCache->getKuimage( filename, mod );
-    if ( !myKuim ) {// couldn't load file, maybe corrupt or wrong format
+    KuickImage *kuim = imageCache->getKuimage( filename, mod );
+    if ( !kuim ) {// couldn't load file, maybe corrupt or wrong format
 	kdWarning() << "ImlibWidget: can't load image " << filename << endl;
 	return 0L;
     }
 
-    loaded( myKuim ); // maybe upscale/downscale in subclasses
+    loaded( kuim ); // maybe upscale/downscale/rotate in subclasses
 
-    return myKuim;
+    return kuim;
 }
 
 // overridden in subclass
@@ -152,12 +153,11 @@ void ImlibWidget::loaded( KuickImage * )
 
 bool ImlibWidget::loadImage( const QString& filename )
 {
-    KuickImage *myKuim = loadImageInternal( filename );
+    KuickImage *kuim = loadImageInternal( filename );
     // FIXME - check everywhere if we have a kuim or not!
 
-    if ( myKuim ) {
-	kuim = myKuim;
-
+    if ( kuim ) {
+	m_kuim = kuim;
 	autoUpdate( true ); // -> updateWidget() -> updateGeometry()
 	m_filename = filename;
         return true;
@@ -169,9 +169,9 @@ bool ImlibWidget::loadImage( const QString& filename )
 
 bool ImlibWidget::cacheImage( const QString& filename )
 {
-    KuickImage *myKuim = loadImageInternal( filename );
-    if ( myKuim ) {
-        myKuim->renderPixmap();
+    KuickImage *kuim = loadImageInternal( filename );
+    if ( kuim ) {
+        kuim->renderPixmap();
         return true;
     }
     return false;
@@ -217,152 +217,175 @@ void ImlibWidget::setGamma( int factor )
 
 void ImlibWidget::zoomImage( float factor )
 {
-    if ( factor == 1 || factor == 0 || !kuim )
+    if ( factor == 1 || factor == 0 || !m_kuim )
 	return;
 
     float wf, hf;
 
-    wf = (float) kuim->width() * factor;
-    hf = (float) kuim->height() * factor;
+    wf = (float) m_kuim->width() * factor;
+    hf = (float) m_kuim->height() * factor;
 
     if ( wf <= 2.0 || hf <= 2.0 ) // minimum size for an image is 2x2 pixels
 	return;
 
-    kuim->resize( (int) wf, (int) hf );
+    m_kuim->resize( (int) wf, (int) hf );
     autoUpdate( true );
 }
 
 
 void ImlibWidget::showImageOriginalSize()
 {
-    if ( !kuim )
+    if ( !m_kuim )
 	return;
 
-    kuim->restoreOriginalSize();
+    m_kuim->restoreOriginalSize();
     autoUpdate( true );
 
     showImage();
 }
 
+bool ImlibWidget::autoRotate( KuickImage *kuim )
+{
+    KFileMetaInfo metadatas( kuim->filename() );
+    if ( !metadatas.isValid() )
+        return false;
+
+    KFileMetaInfoItem metaitem = metadatas.item("Orientation");
+    if ( !metaitem.isValid()
+#if QT_VERSION >= 0x030100
+        || metaitem.value().isNull()
+#endif
+        )
+        return false;
+
+
+    switch ( metaitem.value().toInt() )
+    {
+        //  Orientation:
+        //  1:      normal
+        //  2:      flipped horizontally
+        //  3:      ROT 180
+        //  4:      flipped vertically
+        //  5:      ROT 90 -> flip horizontally
+        //  6:      ROT 90
+        //  7:      ROT 90 -> flip vertically
+        //  8:      ROT 270
+
+        case 1:
+        default:
+            kuim->rotateAbs( ROT_0 );
+            break;
+        case 2:
+            kuim->flipAbs( FlipHorizontal );
+            break;
+        case 3:
+            kuim->rotateAbs( ROT_180 );
+            break;
+        case 4:
+            kuim->flipAbs( FlipVertical );
+            break;
+        case 5:
+            kuim->rotateAbs( ROT_90 );
+            kuim->flipAbs( FlipHorizontal );
+            break;
+        case 6:
+            kuim->rotateAbs( ROT_90 );
+            break;
+        case 7:
+            kuim->rotateAbs( ROT_90 );
+            kuim->flipAbs( FlipVertical );
+            break;
+        case 8:
+            kuim->rotateAbs( ROT_270 );
+            break;
+    }
+
+    return true;
+}
+
 
 void ImlibWidget::setRotation( Rotation rot )
 {
-    if ( myRotation == rot )
-	return;
-
-    int diff = rot - myRotation;
-    bool clockWise = (diff > 0);
-
-    switch( abs(diff) ) {
-    case ROT_90:
-	if ( clockWise ) rotate90();
-	else 	     rotate270();
-	break;
-    case ROT_180:
-	rotate180();
-	break;
-    case ROT_270:	
-	if ( clockWise ) rotate270();
-	else 	     rotate90();
-	break;
+    if ( m_kuim )
+    {
+        if ( m_kuim->rotateAbs( rot ) )
+            autoUpdate( true );
     }
-
-    // image is automatically updated in rotateXX()
 }
 
 
 // slots connected to Accels and popupmenu
 void ImlibWidget::rotate90()
 {
-    if ( !kuim )
+    if ( !m_kuim )
 	return;
 
-    kuim->rotate( ROT_90 );
+    m_kuim->rotate( ROT_90 );
     autoUpdate( true );
-    myRotation = (Rotation) ((myRotation + ROT_90) % 4);
 }
 
 void ImlibWidget::rotate180()
 {
-    if ( !kuim )
+    if ( !m_kuim )
 	return;
 
-    kuim->rotate( ROT_180 );
+    m_kuim->rotate( ROT_180 );
     autoUpdate();
-    myRotation = (Rotation) ((myRotation + ROT_180) % 4);
 }
 
 void ImlibWidget::rotate270()
 {
-    if ( !kuim )
+    if ( !m_kuim )
 	return;
 
-    kuim->rotate( ROT_270 );
+    m_kuim->rotate( ROT_270 );
     autoUpdate( true );
-    myRotation = (Rotation) ((myRotation + ROT_270) % 4);
 }
 
 
 // should this go into a subclass?
 void ImlibWidget::flipHoriz()
 {
-    if ( !kuim )
+    if ( !m_kuim )
 	return;
 
-    kuim->flip( FlipHorizontal );
+    m_kuim->flip( FlipHorizontal );
     autoUpdate();
 }
 
 void ImlibWidget::flipVert()
 {
-    if ( !kuim )
+    if ( !m_kuim )
 	return;
 
-    kuim->flip( FlipVertical );
+    m_kuim->flip( FlipVertical );
     autoUpdate();
 }
 // end slots
 
 
-void ImlibWidget::setFlipMode( FlipMode mode )
+void ImlibWidget::setFlipMode( int mode )
 {
-    if ( !kuim )
-	return;
+    if ( !m_kuim )
+        return;
 
-    bool changed = false;
-
-    if ( (myFlipMode & FlipHorizontal) && !(mode & FlipHorizontal) ||
-	 (!(myFlipMode & FlipHorizontal) && mode & FlipHorizontal) ) {
-	Imlib_flip_image_horizontal( id, kuim->imlibImage() );
-	changed = true;
-    }
-
-    if ( (myFlipMode & FlipVertical) && (mode & ~FlipVertical) ||
-	 ((myFlipMode & ~FlipVertical) && mode & FlipVertical) ) {
-	Imlib_flip_image_vertical( id, kuim->imlibImage() );
-	changed = true;
-    }
-
-    if ( changed ) {
-	kuim->setDirty( true );
+    if ( m_kuim->flipAbs( mode ) )
 	autoUpdate();
-	myFlipMode = mode;
-    }
 }
 
 
 void ImlibWidget::updateWidget( bool geometryUpdate )
 {
-    if ( !kuim )
+    if ( !m_kuim )
 	return;
 
 //     if ( geometryUpdate )
 //         XUnmapWindow( x11Display(), win );// remove the old image -> no flicker
 
-    XSetWindowBackgroundPixmap( x11Display(), win, kuim->pixmap() );
+    XSetWindowBackgroundPixmap( x11Display(), win, m_kuim->pixmap() );
 
     if ( geometryUpdate )
-	updateGeometry( kuim->width(), kuim->height() );
+	updateGeometry( m_kuim->width(), m_kuim->height() );
 
     XClearWindow( x11Display(), win );
 
@@ -370,7 +393,7 @@ void ImlibWidget::updateWidget( bool geometryUpdate )
 }
 
 
-// here we just use the size of kuim, may be overridden in subclass
+// here we just use the size of m_kuim, may be overridden in subclass
 void ImlibWidget::updateGeometry( int w, int h )
 {
     XMoveWindow( x11Display(), win, 0, 0 ); // center?
@@ -401,31 +424,36 @@ const QColor& ImlibWidget::backgroundColor() const
 
 void ImlibWidget::setImageModifier()
 {
-    if ( !kuim )
+    if ( !m_kuim )
 	return;
 
-    Imlib_set_image_modifier( id, kuim->imlibImage(), &mod );
-    kuim->setDirty( true );
+    Imlib_set_image_modifier( id, m_kuim->imlibImage(), &mod );
+    m_kuim->setDirty( true );
 }
 
 int ImlibWidget::imageWidth() const
 {
-    return kuim ? kuim->width() : 0;
+    return m_kuim ? m_kuim->width() : 0;
 }
 
 int ImlibWidget::imageHeight() const
 {
-    return kuim ? kuim->height() : 0;
+    return m_kuim ? m_kuim->height() : 0;
 }
 
 void ImlibWidget::setBusyCursor()
 {
+    if ( ownCursor() )
+        m_oldCursor = cursor();
+    else
+        m_oldCursor = QCursor();
+    
     setCursor( KCursor::waitCursor() );
 }
 
 void ImlibWidget::restoreCursor()
 {
-    setCursor( KCursor::arrowCursor() );
+    setCursor( m_oldCursor );
 }
 
 //----------
@@ -445,10 +473,13 @@ KuickImage::KuickImage( const QString& filename, ImlibImage *im, ImlibData *id)
 
     myOrigWidth  = myWidth;
     myOrigHeight = myHeight;
+    myRotation   = ROT_0;
+    myFlipMode   = FlipNone;
 }
 
 KuickImage::~KuickImage()
 {
+    if ( myPixmap )
     Imlib_free_pixmap( myId, myPixmap );
     Imlib_destroy_image( myId, myIm );
 }
@@ -473,6 +504,9 @@ void KuickImage::restoreOriginalSize()
     myWidth   = myOrigWidth;
     myHeight  = myOrigHeight;
     myIsDirty = true;
+
+    if ( myRotation == ROT_90 || myRotation == ROT_270 )
+        qSwap( myWidth, myHeight );
 }
 
 
@@ -490,6 +524,8 @@ void KuickImage::renderPixmap()
     if ( !myIsDirty )
 	return;
 
+//     qDebug("### rendering: %s", myFilename.latin1());
+
     if ( myPixmap )
 	Imlib_free_pixmap( myId, myPixmap );
 
@@ -524,7 +560,7 @@ void KuickImage::rotate( Rotation rot )
     }
 
     else if ( rot == ROT_90 || rot == ROT_270 ) {
-	swap( &myWidth, &myHeight );
+	qSwap( myWidth, myHeight );
 	Imlib_rotate_image( myId, myIm, -1 );
 
 	if ( rot == ROT_90 ) 		// rotate 90 degrees
@@ -533,10 +569,34 @@ void KuickImage::rotate( Rotation rot )
 	    Imlib_flip_image_vertical( myId, myIm );
     }
 
+    myRotation = (Rotation) ((myRotation + rot) % 4);
     myIsDirty = true;
 }
 
 
+bool KuickImage::rotateAbs( Rotation rot )
+{
+    if ( myRotation == rot )
+	return false;
+
+    int diff = rot - myRotation;
+    bool clockWise = (diff > 0);
+
+    switch( abs(diff) ) {
+    case ROT_90:
+        rotate( clockWise ? ROT_90 : ROT_270 );
+	break;
+    case ROT_180:
+	rotate( ROT_180 );
+	break;
+    case ROT_270:
+        rotate( clockWise ? ROT_270 : ROT_90 );
+	break;
+    }
+
+    return true;
+}
+
 void KuickImage::flip( FlipMode flipMode )
 {
     if ( flipMode & FlipHorizontal )
@@ -544,17 +604,37 @@ void KuickImage::flip( FlipMode flipMode )
     if ( flipMode & FlipVertical )
 	Imlib_flip_image_vertical( myId, myIm );
 
+    myFlipMode = (FlipMode) (myFlipMode ^ flipMode);
     myIsDirty = true;
 }
 
-
-void KuickImage::swap( int *a, int *b )
+bool KuickImage::flipAbs( int mode )
 {
-    int help = *a;
-    *a = *b;
-    *b = help;
-}
+    if ( myFlipMode == mode )
+	return false;
 
+    bool changed = false;
+
+    if ( ((myFlipMode & FlipHorizontal) && !(mode & FlipHorizontal)) ||
+	 (!(myFlipMode & FlipHorizontal) && (mode & FlipHorizontal)) ) {
+	Imlib_flip_image_horizontal( myId, myIm );
+	changed = true;
+    }
+
+    if ( ((myFlipMode & FlipVertical) && !(mode & FlipVertical)) ||
+	 (!(myFlipMode & FlipVertical) && (mode & FlipVertical)) ) {
+	Imlib_flip_image_vertical( myId, myIm );
+	changed = true;
+    }
+
+    if ( changed ) {
+        myFlipMode = (FlipMode) mode;
+        myIsDirty = true;
+        return true;
+    }
+
+    return false;
+}
 
 
 //----------
@@ -663,6 +743,7 @@ KuickImage * ImageCache::getKuimage( const QString& file,
     }
 
     if ( kuickList.count() > (uint) myMaxImages ) {
+//         qDebug(":::: now removing from cache: %s", (*fileList.fromLast()).latin1());
 	kuickList.removeLast();
 	fileList.remove( fileList.fromLast() );
     }
@@ -674,13 +755,13 @@ KuickImage * ImageCache::getKuimage( const QString& file,
 /*
 KuickImage * ImageCache::find( const QString& file )
 {
-  KuickImage *myKuim = 0L;
+  KuickImage *kuim = 0L;
   int index = fileList.findIndex( file );
   if ( index >= 0 )
-    myKuim = kuickList.at( index );
+    kuim = kuickList.at( index );
 
-  debug("found cached KuickImage? : %p", myKuim );
-  return myKuim;
+  qDebug("found cached KuickImage? : %p", kuim );
+  return kuim;
 }
 */
 #include "imlibwidget.moc"
