@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: imlibwidget.h,v 1.2.2.1 2002/07/05 13:57:27 pfeiffer Exp $
+** $Id: imlibwidget.h,v 1.10.2.1 2003/01/11 02:23:14 pfeiffer Exp $
 **
 ** ImlibWidget: maps an Xlib window with Imlib's contents on a QWidget
 **
@@ -14,6 +14,7 @@
 
 #include <qvariant.h>
 
+#include <qcursor.h>
 #include <qevent.h>
 #include <qptrlist.h>
 #include <qtimer.h>
@@ -28,16 +29,11 @@
 // #include <X11/extensions/shape.h>
 
 #include "imdata.h"
+#include "kuickdata.h"
 
 
 // hmm, global declaration for now
-typedef 	int FlipMode;
-#define 	FlipHorizontal 	(1 << 1)
-#define 	FlipVertical 	(1 << 2)
-#define 	FlipNone 	~FlipHorizontal & ~FlipVertical
-enum Rotation { ROT_0=0, ROT_90=1, ROT_180=2, ROT_270=3 };
-
-
+enum FlipMode { FlipNone = 0, FlipHorizontal = 1, FlipVertical = 2 };
 
 class KuickImage : public QObject
 {
@@ -55,7 +51,9 @@ public:
   void 		resize( int width, int height );
   void 		restoreOriginalSize();
   void 		rotate( Rotation rot );
+  bool          rotateAbs( Rotation rot );
   void 		flip( FlipMode flipMode );
+  bool 		flipAbs( int mode );
   ImlibImage *	imlibImage()	const { return myIm;      }
   Pixmap& 	pixmap();
   void 		renderPixmap();
@@ -63,6 +61,8 @@ public:
 
   void 		setDirty( bool d )    { myIsDirty = d;    }
   bool 		isDirty() 	const { return myIsDirty; }
+  Rotation      absRotation()   const { return myRotation; }
+  FlipMode      flipMode()      const { return myFlipMode; }
 
 private:
   int 		myWidth;
@@ -75,8 +75,8 @@ private:
 
   int 		myOrigWidth;
   int 		myOrigHeight;
-
-  void 		swap( int *a, int *b );
+  Rotation 	myRotation;
+  FlipMode 	myFlipMode;
 
 signals:
   void 		startRendering();
@@ -145,23 +145,29 @@ public:
   void 		setContrast( int );
   void 		setGamma( int );
   void 		setRotation( Rotation );
-  void 		setFlipMode( FlipMode mode );
+  void 		setFlipMode( int mode );
 
   int 		brightness() 		 const;
   int 		contrast()		 const;
   int 		gamma() 		 const;
-  Rotation 	rotation() 		 const { return myRotation; 	  }
-  FlipMode	flipMode() 		 const { return myFlipMode; 	  }
+  Rotation 	rotation() 		 const { return m_kuim ? m_kuim->absRotation() : ROT_0; }
+  FlipMode	flipMode() 		 const { return m_kuim ? m_kuim->flipMode() : FlipNone; }
 
   int 		imageWidth() 		 const;
   int 		imageHeight() 		 const;
 
-  void 		setAutoRender( bool enable )  { isAutoRendering = enable;}
+  void 		setAutoRender( bool enable )   { isAutoRendering = enable;}
   bool 		isAutoRenderEnabled() 	const  { return isAutoRendering;  }
   void 		setMaxImageCache( int );
   int 		maxImageCache() 	const  { return myMaxImageCache;  }
   const QColor& backgroundColor() 	const;
   void 		setBackgroundColor( const QColor& );
+    
+  /**
+   * @return true if auto-rotation is not possible, e.g. because no metadata
+   * about orientation is available
+   */
+  virtual bool  autoRotate( KuickImage *kuim );
 
   ImlibData*	getImlibData() const 	       { return id; 		  }
 
@@ -176,7 +182,6 @@ public slots:
 
 
 protected:
-  void 		init();
   KuickImage *	loadImageInternal( const QString&  );
   void 		showImage();
   void          setImageModifier();
@@ -195,7 +200,7 @@ protected:
   bool		stillResizing, deleteImData, deleteImlibData;
   bool          imlibModifierChanged;
 
-  KuickImage 	*kuim;
+  KuickImage 	*m_kuim;
   ImageCache 	*imageCache;
   ImlibData     *id;
   ImData    	*idata;
@@ -203,14 +208,14 @@ protected:
   ImlibColorModifier mod;
 
   QString m_filename;
+  QCursor m_oldCursor;
 
-  static const int ImlibOffset = 256;
+  static const int ImlibOffset;
 
 
 private:
+  void 		init();
   bool 		isAutoRendering;
-  FlipMode 	myFlipMode;
-  Rotation 	myRotation;
   int 		myMaxImageCache;
   QColor 	myBackgroundColor;
 
