@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: kuickconfigdlg.h,v 1.4 2002/01/27 14:54:53 ellis Exp $
+** $Id: kuickconfigdlg.h,v 1.6 2002/06/12 03:13:54 nhasan Exp $
 **
 ** Configuration dialog for KuickShow
 **
@@ -16,13 +16,14 @@
 
 #include <kkeydialog.h>
 
-#include "logotabdialog.h"
+#include <kdialogbase.h>
 
 class GeneralWidget;
 class DefaultsWidget;
+class SlideShowWidget;
 class ImageWindow;
 
-class KuickConfigDialog : public LogoTabDialog
+class KuickConfigDialog : public KDialogBase
 {
     Q_OBJECT
 
@@ -39,6 +40,7 @@ private slots:
 private:
     DefaultsWidget   *defaultsWidget;
     GeneralWidget    *generalWidget;
+    SlideShowWidget  *slideshowWidget;
     KKeyChooser      *imageKeyChooser, *browserKeyChooser;
     KActionCollection *coll;
 
