@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: kuickdata.h,v 1.2 2001/09/28 20:18:51 mueller Exp $
+** $Id: kuickdata.h,v 1.7 2002/11/05 02:35:04 pfeiffer Exp $
 **
 ** KuickData, a class containing/loading/saving  all preferences of KuickShow
 **
@@ -19,6 +19,9 @@
 
 class KConfig;
 
+// values are also used as combobox index defaultswidget.*
+enum Rotation { ROT_0=0, ROT_90=1, ROT_180=2, ROT_270=3 };
+
 class KuickData
 {
 public:
@@ -29,13 +32,12 @@ public:
     void 	save();
 
 
+    ImData 	*idata;
+
     QString 	fileFilter;
     uint 	slideDelay;
-    bool 	preloadImage;
-    bool 	showInOneWindow;
-    ImData 	*idata;
-    bool 	fullScreen;
-
+    uint        slideshowCycles;
+    bool        slideshowFullscreen :1;
 
     int 	brightnessSteps;
     int 	contrastSteps;
@@ -44,19 +46,21 @@ public:
     int 	scrollSteps;
     float	zoomSteps;
 
+    bool 	preloadImage     :1;
+    bool 	autoRotation     :1;
+    bool 	fullScreen       :1;
 
     // default image modifications
-    bool 	isModsEnabled;
+    bool 	isModsEnabled :1;
 
-    bool 	downScale;
-    bool 	upScale;
+    bool 	flipVertically   :1;
+    bool 	flipHorizontally :1;
+    bool 	downScale        :1;
+    bool 	upScale          :1;
     int 	maxUpScale;
     uint 	maxWidth, maxHeight;
-
-
-    bool 	flipVertically;
-    bool 	flipHorizontally;
-    int 	rotation;
+    uint        maxCachedImages;
+    Rotation 	rotation;
 
     QColor      backgroundColor;
 
