@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: kuickshow.cpp,v 1.22.2.5 2002/07/18 16:13:08 pfeiffer Exp $
+** $Id: kuickshow.cpp,v 1.55.2.7 2003/01/13 18:59:53 pfeiffer Exp $
 **
 ** KuickShow - a fast and comfortable image viewer based on Rasterman's Imlib
 **
@@ -19,20 +19,29 @@
 #include <qsize.h>
 #include <qstring.h>
 
+#include <kaboutdata.h>
 #include <kaccel.h>
 #include <kaction.h>
 #include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <kconfig.h>
 #include <kcursor.h>
+#include <kfiledialog.h>
+#include <kfilemetainfo.h>
 #include <kglobal.h>
+#include <khelpmenu.h>
 #include <kiconloader.h>
+#include <kio/netaccess.h>
 #include <klocale.h>
+#include <kmenubar.h>
 #include <kmessagebox.h>
+#include <kpopupmenu.h>
 #include <kpropertiesdialog.h>
+#include <kprotocolinfo.h>
 #include <kstatusbar.h>
 #include <kstdaction.h>
 #include <kstandarddirs.h>
+#include <kstartupinfo.h>
 #include <ktoolbar.h>
 #include <kurldrag.h>
 #include <kwin.h>
@@ -60,19 +69,20 @@
 
 KuickData* kdata;
 
-static const int SIZE_ITEM = 0;
-static const int URL_ITEM  = 1;
+static const int URL_ITEM  = 0;
+static const int META_ITEM = 1;
 
 QValueList<ImageWindow*> KuickShow::s_viewers;
 
 
 KuickShow::KuickShow( const char *name )
     : KMainWindow( 0L, name ),
+      m_slideshowCycle( 1 ),
       fileWidget( 0L ),
       dialog( 0L ),
       id( 0L ),
       m_viewer( 0L ),
-      newWindowAction( 0L ),
+      oneWindowAction( 0L ),
       m_accel( 0L ),
       m_delayedRepeatItem( 0L )
 {
@@ -82,6 +92,10 @@ KuickShow::KuickShow( const char *name )
   initImlib();
   resize( 400, 500 );
 
+  m_slideTimer = new QTimer( this );
+  connect( m_slideTimer, SIGNAL( timeout() ), SLOT( nextSlide() ));
+
+
   KConfig *kc = KGlobal::config();
 
   bool isDir = false; // true if we get a directory on the commandline
@@ -91,24 +105,47 @@ KuickShow::KuickShow( const char *name )
 		
   // files to display
   // either a directory to display, an absolute path, a relative path, or a URL
-  KURL base;
-  base.setPath( QDir::currentDirPath() + '/' );
-  KURL startDir = base;
+  KURL startDir;
+  startDir.setPath( QDir::currentDirPath() + '/' );
   for ( int i = 0; i < args->count(); i++ ) {
-      KURL url( base, args->arg( i ) );
+      KURL url = args->url( i );
       KFileItem item( KFileItem::Unknown, KFileItem::Unknown, url, false );
 
       // for remote URLs, we don't know if it's a file or directory, but
       // FileWidget::isImage() should correct in most cases.
       // For non-local non-images, we just assume directory.
+
       if ( FileWidget::isImage( &item ) )
-	  showImage( &item, true ); // show in new window
-      else {
-	  if ( item.isDir() || !url.isLocalFile() ) {
+      {
+	  showImage( &item, true, false, true ); // show in new window, not fullscreen-forced and move to 0,0
+// 	  showImage( &item, true, false, false ); // show in new window, not fullscreen-forced and not moving to 0,0
+      }
+      else if ( item.isDir() )
+      {
+          startDir = url;
+          isDir = true;
+      }
+      
+      // need to check remote files
+      else if ( !url.isLocalFile() )
+      {
+          KMimeType::Ptr mime = KMimeType::findByURL( url );
+          QString name = mime->name();
+          if ( name == "application/octet-stream" ) // unknown -> stat()
+              name = KIO::NetAccess::mimetype( url );
+
+          if ( name.startsWith( "image/" ) )
+          {
+              FileWidget::setImage( item, true );
+              showImage( &item, true, false, true );
+          }
+          else // assume directory, KDirLister will tell us if we can't list
+          {
 	      startDir = url;
 	      isDir = true;
 	  }
       }
+      // else // we don't handle local non-images
   }
 
   if ( args->isSet( "lastdir" ))
@@ -121,6 +158,7 @@ KuickShow::KuickShow( const char *name )
 
   else { // don't show browser, when image on commandline
       hide();
+      KStartupInfo::appStarted();
   }
 }
 
@@ -133,10 +171,10 @@ KuickShow::~KuickShow()
     if ( m_viewer )
 	m_viewer->close( true );
 
-    delete id;
+    free( id );
     kapp->quit();
 
-    delete kdata; kdata = 0;
+    delete kdata;
 }
 
 
@@ -157,43 +195,97 @@ void KuickShow::initGUI( const KURL& startDir )
 	     this, SLOT( dirSelected( const KURL& )) );
 
     // setup actions
+    KAction *open = KStdAction::open( this, SLOT( slotOpenURL() ),
+                                      coll, "openURL" );
+
     KAction *print = KStdAction::print( this, SLOT( slotPrint() ),
 					coll, "kuick_print" );
-    print->setText( i18n("Print image...") );
+    print->setText( i18n("Print Image...") );
 
-    KAction *configure = new KAction( i18n("Configuration"), "configure", 0,
+    KAction *configure = new KAction( i18n("Configure %1...").arg( KGlobal::instance()->aboutData()->programName() ), "configure",
+                                      KShortcut(),
 				      this, SLOT( configuration() ),
 				      coll, "kuick_configure" );
-    KAction *slide = new KAction( i18n("Slideshow" ), "ksslide", Key_F2,
+    KAction *slide = new KAction( i18n("Start Slideshow" ), "ksslide",
+                                  KShortcut( Key_F2 ),
 				  this, SLOT( startSlideShow() ),
 				  coll, "kuick_slideshow" );
-    KAction *about = new KAction( i18n( "About KuickShow" ), "about", 0,
-				  this, SLOT( about() ), coll );
-    KAction *help = KStdAction::help( this, SLOT( appHelpActivated() ),
-				      coll, "kuick_help" );
-    newWindowAction = new KToggleAction( i18n("Open only one image window"),
-					 "window_new", CTRL+Key_N, coll,
+    KAction *about = new KAction( i18n( "About KuickShow" ), "about",
+                                  KShortcut(),
+				  this, SLOT( about() ), coll, "about" );
+
+    oneWindowAction = new KToggleAction( i18n("Open only one Image Window"),
+					 "window_new",
+                                         KShortcut( CTRL+Key_N ), coll,
 					 "kuick_one window" );
 
-    KAction *hidden = coll->action( "show hidden" );
-    hidden->setIcon( "lock" );
+    m_toggleBrowserAction = new KToggleAction( i18n("Show/Hide the File Browser"), KShortcut( Key_Space ), coll, "toggleBrowser" );
+    connect( m_toggleBrowserAction, SIGNAL( toggled( bool ) ),
+             SLOT( toggleBrowser() ));
 
-    (void) new KAction( i18n("Show Image"), KShortcut(),
-                        this, SLOT( slotShowInOtherWindow() ),
-			coll, "kuick_showInOtherWindow" );
-    (void) new KAction( i18n("Show Image in Active Window"), KShortcut(),
-			this, SLOT( slotShowInSameWindow() ),
-			coll, "kuick_showInSameWindow" );
+    KAction *showInOther = new KAction( i18n("Show Image"), KShortcut(),
+                                        this, SLOT( slotShowInOtherWindow() ),
+                                        coll, "kuick_showInOtherWindow" );
+    KAction *showInSame = new KAction( i18n("Show Image in Active Window"),
+                                       KShortcut(),
+                                       this, SLOT( slotShowInSameWindow() ),
+                                       coll, "kuick_showInSameWindow" );
 
-    coll->action( "reload" )->setShortcut( KStdAccel::reload() );
-
-    KAction *quit = KStdAction::quit( this, SLOT(slotQuit()), coll, "quit" );
+    KAction *quit = KStdAction::quit( this, SLOT(slotQuit()), coll, "quit");
 
     // remove QString::null parameter -- ellis
     coll->readShortcutSettings( QString::null );
     m_accel = coll->accel();
 
+    // menubar
+    KMenuBar *mBar = menuBar();
+    QPopupMenu *fileMenu = new QPopupMenu( mBar, "file" );
+    open->plug( fileMenu );
+    showInOther->plug( fileMenu );
+    showInSame->plug( fileMenu );
+    fileMenu->insertSeparator();
+    slide->plug( fileMenu );
+    print->plug( fileMenu );
+    fileMenu->insertSeparator();
+    quit->plug( fileMenu );
+
+    QPopupMenu *editMenu = new QPopupMenu( mBar, "edit" );
+    coll->action("mkdir")->plug( editMenu );
+    coll->action("delete")->plug( editMenu );
+    editMenu->insertSeparator();
+    coll->action("properties")->plug( editMenu );
+
+
+    // remove the Sorting submenu (and the separator below)
+    // from the main contextmenu
+    KActionMenu *sortingMenu = static_cast<KActionMenu*>( coll->action("sorting menu"));
+    KActionMenu *mainActionMenu = static_cast<KActionMenu*>( coll->action("popupMenu"));
+    QPopupMenu *mainPopup = mainActionMenu->popupMenu();
+    int sortingIndex = mainPopup->indexOf( sortingMenu->itemId( 0 ) );
+    int separatorId = mainPopup->idAt( sortingIndex + 1 );
+    QMenuItem *separatorItem = mainPopup->findItem( separatorId );
+    if ( separatorItem && separatorItem->isSeparator() )
+        mainPopup->removeItem( separatorId );
+    mainActionMenu->remove( sortingMenu );
+
+    // add the sorting menu and a separator into the View menu
+    KActionMenu *viewActionMenu = static_cast<KActionMenu*>( coll->action("view menu"));
+    viewActionMenu->popupMenu()->insertSeparator( 0 );
+    sortingMenu->plug( viewActionMenu->popupMenu(), 0 ); // on top of the menu
+
+
+    QPopupMenu *settingsMenu = new QPopupMenu( mBar, "settings" );
+    configure->plug( settingsMenu );
+
+    mBar->insertItem( i18n("&File"), fileMenu );
+    mBar->insertItem( i18n("&Edit"), editMenu );
+    viewActionMenu->plug( mBar );
+    mBar->insertItem( i18n("&Settings"), settingsMenu );
+
+    // toolbar
     KToolBar *tBar = toolBar();
+    tBar->setText( i18n( "Main Toolbar" ) );
+
     coll->action("up")->plug( tBar );
     coll->action("back")->plug( tBar );
     coll->action("forward")->plug( tBar );
@@ -210,25 +302,26 @@ void KuickShow::initGUI( const KURL& startDir )
     configure->plug( tBar );
     slide->plug( tBar );
     tBar->insertSeparator();
-    hidden->plug( tBar );
-    newWindowAction->plug( tBar );
+    oneWindowAction->plug( tBar );
     print->plug( tBar );
     tBar->insertSeparator();
-    quit->plug( tBar );
     about->plug( tBar );
-    help->plug( tBar );
+
+    QPopupMenu *help = helpMenu( QString::null, false );
+    mBar->insertItem( i18n("&Help"), help );
 
 
     KStatusBar* sBar = statusBar();
-    sBar->insertItem( "                          ", SIZE_ITEM, 2 );
     sBar->insertItem( "           ", URL_ITEM, 10 );
+    sBar->insertItem( "                          ", META_ITEM, 2 );
+    sBar->setItemAlignment(URL_ITEM, QLabel::AlignVCenter | QLabel::AlignLeft);
 
     fileWidget->setFocus();
 
     KConfig *kc = KGlobal::config();
     kc->setGroup("SessionSettings");
     bool oneWindow = kc->readBoolEntry("OpenImagesInActiveWindow", true );
-    newWindowAction->setChecked( oneWindow );
+    oneWindowAction->setChecked( oneWindow );
 
     tBar->show();
 
@@ -238,37 +331,75 @@ void KuickShow::initGUI( const KURL& startDir )
 
     setCentralWidget( fileWidget );
     setAutoSaveSettings();
+
+    coll->action( "reload" )->setShortcut( KStdAccel::reload() );
+    coll->action( "short view" )->setShortcut(Key_F6);
+    coll->action( "detailed view" )->setShortcut(Key_F7);
+    coll->action( "show hidden" )->setShortcut(Key_F8);
+    coll->action( "mkdir" )->setShortcut(Key_F10);
+    coll->action( "preview" )->setShortcut(Key_F11);
+    coll->action( "separate dirs" )->setShortcut(Key_F12);
+
+    // ### somehow the filewidget isn't resized at all sometimes, when initGUI
+    // is called lazily, not from this c'tor. (just a tiny little widget in 
+    // the upper left corner of the mainwindow. Work around that.
+    fileWidget->resize( size() );
 }
 
 
 void KuickShow::viewerDeleted()
 {
-    s_viewers.remove( (ImageWindow*) sender() );
-    m_viewer = 0L;
+    ImageWindow *viewer = (ImageWindow*) sender();
+    s_viewers.remove( viewer );
+    if ( viewer == m_viewer )
+        m_viewer = 0L;
 
     if ( !haveBrowser() && s_viewers.isEmpty() ) {
 	if ( fileWidget )
 	    saveSettings();
-	
+
 	::exit(0);
     }
 
     else if ( haveBrowser() ) {
 	setActiveWindow();
-	fileWidget->setFocus();
+        // This setFocus() call causes problems in the combiview (always the
+        // directory view on the left gets the focus, which is not desired)
+        // fileWidget->setFocus();
     }
+
+    if ( fileWidget )
+        // maybe a slideshow was stopped --> enable the action again
+        fileWidget->actionCollection()->action("kuick_slideshow")->setEnabled( true );
+
+    m_slideTimer->stop();
 }
 
 
 void KuickShow::slotHighlighted( const KFileItem *fi )
 {
-    QString size;
-    size = i18n("%1 kb").arg(KGlobal::locale()->formatNumber((float)fi->size()/1024, 1));
-    statusBar()->changeItem( size, SIZE_ITEM );
-    statusBar()->changeItem( fi->url().prettyURL(), URL_ITEM );
+    KFileItem *item = const_cast<KFileItem *>( fi );
+    statusBar()->changeItem( item->getStatusBarInfo(), URL_ITEM );
+
+    QString meta;
+    KFileMetaInfo info = item->metaInfo();
+    if ( info.isValid() )
+    {
+        meta = info.item( KFileMimeTypeInfo::Size ).string();
+        KFileMetaInfoGroup group = info.group( "Technical" );
+        if ( group.isValid() )
+        {
+            QString bpp = group.item( "BitDepth" ).string();
+            if ( !bpp.isEmpty() )
+                meta.append( ", " ).append( bpp );
+        }
+    }
+    statusBar()->changeItem( meta, META_ITEM );
 
     bool image = FileWidget::isImage( fi );
     fileWidget->actionCollection()->action("kuick_print")->setEnabled( image );
+    fileWidget->actionCollection()->action("kuick_showInSameWindow")->setEnabled( image );
+    fileWidget->actionCollection()->action("kuick_showInOtherWindow")->setEnabled( image );
 }
 
 void KuickShow::dirSelected( const KURL& url )
@@ -283,7 +414,7 @@ void KuickShow::dirSelected( const KURL& url )
 
 void KuickShow::slotSelected( const KFileItem *item )
 {
-    showImage( item, !newWindowAction->isChecked() );
+    showImage( item, !oneWindowAction->isChecked() );
 }
 
 // downloads item if necessary
@@ -293,11 +424,14 @@ void KuickShow::showFileItem( ImageWindow */*view*/,
 
 }
 
-void KuickShow::showImage( const KFileItem *fi, bool newWin )
+void KuickShow::showImage( const KFileItem *fi,
+                           bool newWindow, bool fullscreen, bool moveToTopLeft )
 {
-    bool newWindow = !m_viewer || newWin;
+    newWindow  |= !m_viewer;
+    fullscreen |= (newWindow && kdata->fullScreen);
 
     if ( FileWidget::isImage( fi ) ) {
+        
 	if ( newWindow ) {
 	    m_viewer = new ImageWindow( kdata->idata, id, 0L, "image window" );
 	    s_viewers.append( m_viewer );
@@ -309,31 +443,40 @@ void KuickShow::showImage( const KFileItem *fi, bool newWin )
 		     this, SLOT( messageCantLoadImage(const QString &) ));
             connect( m_viewer, SIGNAL( requestImage( ImageWindow *, int )),
                      this, SLOT( slotAdvanceImage( ImageWindow *, int )));
-	    if ( s_viewers.count() == 1 ) {
+	    if ( s_viewers.count() == 1 && moveToTopLeft ) {
 		// we have to move to 0x0 before showing _and_
 		// after showing, otherwise we get some bogus geometry()
 		m_viewer->move( Kuick::workArea().topLeft() );
 	    }
 
-	    m_viewer->setPopupMenu();
 	    m_viewer->installEventFilter( this );
 	}
 
-	QString filename = fi->url().path();
+        // for some strange reason, m_viewer sometimes changes during the
+        // next few lines of code, so as a workaround, we use safeViewer here.
+        // This happens when calling KuickShow with two or more remote-url
+        // arguments on the commandline, where the first one is loaded properly
+        // and the second isn't (e.g. because it is a pdf or something else,
+        // Imlib can't load).
+        ImageWindow *safeViewer = m_viewer;
 
-	if ( !m_viewer->showNextImage( filename ) )
-	    m_viewer->close( true ); // couldn't load image, close window
+	QString filename;
+	KIO::NetAccess::download(fi->url(), filename);
+
+	if ( !safeViewer->showNextImage( filename ) ) {
+            m_viewer = safeViewer;
+	    safeViewer->close( true ); // couldn't load image, close window
+        }
 	else {
-	    if ( newWindow ) {
-		if ( kdata->fullScreen )
-		    m_viewer->setFullscreen( true );
+            safeViewer->setFullscreen( fullscreen );
 
-		m_viewer->show();
+	    if ( newWindow ) {
+		safeViewer->show();
 		
-		if ( !kdata->fullScreen && s_viewers.count() == 1 ) {
+		if ( !fullscreen && s_viewers.count() == 1 && moveToTopLeft ) {
 		    // the WM might have moved us after showing -> strike back!
 		    // move the first image to 0x0 workarea coord
-		    m_viewer->move( Kuick::workArea().topLeft() );
+		    safeViewer->move( Kuick::workArea().topLeft() );
 		}
 	    }
 
@@ -341,8 +484,10 @@ void KuickShow::showImage( const KFileItem *fi, bool newWin )
   		KFileItem *item = 0L;                 // don't move cursor
   		item = fileWidget->getItem( FileWidget::Next, true );
   		if ( item )
-  		    m_viewer->cacheImage( item->url().path() ); // FIXME
+  		    safeViewer->cacheImage( item->url().path() ); // FIXME
   	    }
+
+            m_viewer = safeViewer;
 	} // m_viewer created successfully
     } // isImage
 }
@@ -350,34 +495,52 @@ void KuickShow::showImage( const KFileItem *fi, bool newWin )
 void KuickShow::startSlideShow()
 {
     KFileItem *item = fileWidget->gotoFirstImage();
+
     if ( item ) {
+        m_slideshowCycle = 1;
 	fileWidget->actionCollection()->action("kuick_slideshow")->setEnabled( false );
-	showImage( item, !kdata->showInOneWindow );
-	QTimer::singleShot( kdata->slideDelay, this, SLOT( nextSlide() ) );
+	showImage( item, !oneWindowAction->isChecked(),
+                   kdata->slideshowFullscreen );
+        m_slideTimer->start( kdata->slideDelay );
     }
 }
 
 void KuickShow::nextSlide()
 {
     if ( !m_viewer ) {
+        m_slideshowCycle = 1;
 	fileWidget->actionCollection()->action("kuick_slideshow")->setEnabled( true );
 	return;
     }
 
     KFileItem *item = fileWidget->getNext( true );
-    if ( !item ) {
+    if ( !item ) { // last image
+        if ( m_slideshowCycle < kdata->slideshowCycles
+           || kdata->slideshowCycles == 0 ) {
+            item = fileWidget->gotoFirstImage();
+            if ( item ) {
+                nextSlide( item );
+                m_slideshowCycle++;
+                return;
+            }
+        }
+
 	m_viewer->close( true );
 	fileWidget->actionCollection()->action("kuick_slideshow")->setEnabled( true );
 	return;
     }
 
+    nextSlide( item );
+}
+
+void KuickShow::nextSlide( KFileItem *item )
+{
     m_viewer->showNextImage( item->url().path() );
-    QTimer::singleShot( kdata->slideDelay, this, SLOT( nextSlide() ) );
+    m_slideTimer->start( kdata->slideDelay );
 }
 
 
 // prints the selected files in the filebrowser
-// FIXME: maybe print with QPainter?
 void KuickShow::slotPrint()
 {
     const KFileItemList *items = fileWidget->selectedItems();
@@ -388,8 +551,9 @@ void KuickShow::slotPrint()
 
     // don't show the image, just print
     ImageWindow *iw = new ImageWindow( 0, id, this, "printing image" );
-    while ( it.current() ) {
-	if ( iw->loadImage( it.current()->url().path() ) )
+    KFileItem *item;
+    while ( (item = it.current()) ) {
+	if (FileWidget::isImage( item ) && iw->loadImage( item->url().path()))
 	    iw->printImage();
 	++it;
     }
@@ -432,7 +596,7 @@ void KuickShow::dropEvent( QDropEvent *e )
 
     if ( hasRemote ) {
 	QString tmp( i18n("You can only drop local files "
-		"onto the image viewer!"));
+                          "onto the image viewer!"));
 	KMessageBox::sorry( this, tmp, i18n("KuickShow Drop Error") );
     }
 }
@@ -460,10 +624,21 @@ void KuickShow::slotAdvanceImage( ImageWindow *view, int steps )
         QFileInfo fi( view->filename() );
         start.setPath( fi.dirPath( true ) );
         initGUI( start );
-        fileWidget->setInitialItem( fi.fileName() );
 
-        connect( fileWidget, SIGNAL( finished() ),
-                 SLOT( slotReplayAdvance() ));
+        // see eventFilter() for explanation and similar code
+        if ( fileWidget->dirLister()->isFinished() &&
+             fileWidget->dirLister()->rootItem() )
+        {
+            fileWidget->setCurrentItem( fi.fileName() );
+            QTimer::singleShot( 0, this, SLOT( slotReplayAdvance()));
+        }
+        else
+        {
+            fileWidget->setInitialItem( fi.fileName() );
+            connect( fileWidget, SIGNAL( finished() ),
+                     SLOT( slotReplayAdvance() ));
+        }
+
         return;
     }
 
@@ -480,9 +655,13 @@ void KuickShow::slotAdvanceImage( ImageWindow *view, int steps )
     }
 
     if ( FileWidget::isImage( item ) ) {
-        view->showNextImage( item->url().path() ); // ###
-		
-        if ( kdata->preloadImage ) // preload next image
+	QString filename;
+	KIO::NetAccess::download(item->url(), filename);
+        view->showNextImage( filename );
+        if (m_slideTimer->isActive())
+	  m_slideTimer->start( kdata->slideDelay );
+
+        if ( kdata->preloadImage && item_next && item_next->url().isLocalFile() ) // preload next image
             if ( FileWidget::isImage( item_next ) )
                 view->cacheImage( item_next->url().path() ); // ###
     }
@@ -494,14 +673,16 @@ bool KuickShow::eventFilter( QObject *o, QEvent *e )
 	return true;    // kapp, to make it really safe
 
     bool ret = false;
+    int eventType = e->type();
     QKeyEvent *k = 0L;
-    if ( e->type() == QEvent::KeyPress )
+    if ( eventType == QEvent::KeyPress )
 	k = static_cast<QKeyEvent *>( e );
 
     if ( k ) {
         if ( KStdAccel::quit().contains( KKey( k ) ) ) {
 	    saveSettings();
-	    exit(0);
+            deleteAllViewers();
+	    ::exit(0);
         }
         else if ( KStdAccel::help().contains( KKey( k ) ) ) {
 	    appHelpActivated();
@@ -512,8 +693,13 @@ bool KuickShow::eventFilter( QObject *o, QEvent *e )
 
     ImageWindow *window = dynamic_cast<ImageWindow*>( o );
     if ( window ) {
-// 	KCursor::autoHideEventFilter( o, e );
-	
+        // The XWindow used to display Imlib's image is being resized when 
+        // switching images, causing enter- and leaveevents for this 
+        // ImageWindow, leading to the cursor being unhidden. So we simply
+        // don't pass those events to KCursor to prevent that.
+        if ( eventType != QEvent::Leave && eventType != QEvent::Enter )
+            KCursor::autoHideEventFilter( o, e );
+
 	m_viewer = window;
 	QString img;
 	KFileItem *item = 0L;      // the image to be shown
@@ -522,46 +708,65 @@ bool KuickShow::eventFilter( QObject *o, QEvent *e )
 	if ( k ) { // keypress
 	    ret = true;
 	    int key = k->key();
-            
+
 	    // Key_Shift shouldn't load the browser in nobrowser mode, it
 	    // is used for zooming in the imagewindow
 	    if ( !fileWidget )
             {
-                if ( key != Key_Escape && key != Key_Shift ) 
+                if ( key != Key_Escape && key != Key_Shift )
                 {
                     KURL start;
                     QFileInfo fi( m_viewer->filename() );
                     start.setPath( fi.dirPath( true ) );
                     initGUI( start );
 
-                    // the fileBrowser will list the start-directory 
-                    // asynchronously so we can't immediately continue. There 
-                    // is no current-item and no next-item (actually no item 
-                    // at all). So we tell the browser the initial 
+                    // the fileBrowser will list the start-directory
+                    // asynchronously so we can't immediately continue. There
+                    // is no current-item and no next-item (actually no item
+                    // at all). So we tell the browser the initial
                     // current-item and wait for it to tell us when it's ready.
                     // Then we will replay this KeyEvent.
-                    fileWidget->setInitialItem( fi.fileName() );
                     delayedRepeatEvent( m_viewer, k );
-                    connect( fileWidget, SIGNAL( finished() ),
-                             SLOT( slotReplayEvent() ));
+
+                    // OK, once again, we have a problem with the now async and
+                    // sync KDirLister :( If the startDir is already cached by
+                    // KDirLister, we won't ever get that finished() signal
+                    // because it is emitted before we can connect(). So if
+                    // our dirlister has a rootFileItem, we assume the
+                    // directory is read already and simply call
+                    // slotReplayEvent() without the need for the finished()
+                    // signal.
+
+                    // see slotAdvanceImage() for similar code
+                    if ( fileWidget->dirLister()->isFinished() &&
+                         fileWidget->dirLister()->rootItem() )
+                    {
+                        fileWidget->setCurrentItem( fi.fileName() );
+                        QTimer::singleShot( 0, this, SLOT( slotReplayEvent()));
+                    }
+                    else
+                    {
+                        fileWidget->setInitialItem( fi.fileName() );
+                        connect( fileWidget, SIGNAL( finished() ),
+                                 SLOT( slotReplayEvent() ));
+                    }
+
                     return true;
                 }
-                
+
                 return KMainWindow::eventFilter( o, e );
 	    }
 
-            // we definitely have a filewidget here!
-            
- 	    // FIXME: make all this stuff via KStdAccel and KAccel ->slots
+            // we definitely have a fileWidget here!
 
-            KKey kkey( key );
-            if ( KStdAccel::home().contains( kkey ) )
+            KKey kkey( k );
+            if ( key == Key_Home || KStdAccel::home().contains( kkey ) )
             {
 		item = fileWidget->gotoFirstImage();
 		item_next = fileWidget->getNext( false );
 	    }
 
-            else if ( KStdAccel::end().contains( kkey ) )
+            else if ( key == Key_End || KStdAccel::end().contains( kkey ) )
             {
 		item = fileWidget->gotoLastImage();
 		item_next = fileWidget->getPrevious( false );
@@ -569,13 +774,13 @@ bool KuickShow::eventFilter( QObject *o, QEvent *e )
 
             else if ( fileWidget->actionCollection()->action("delete")->shortcut().contains( key ))
             {
-		KFileItem *cur = fileWidget->getCurrentItem( false );
+// 		KFileItem *cur = fileWidget->getCurrentItem( false );
+ 		(void) fileWidget->getCurrentItem( false );
 		item = fileWidget->getNext( false ); // don't move
 		if ( !item )
 		    item = fileWidget->getPrevious( false );
-
                 KFileItem it( KFileItem::Unknown, KFileItem::Unknown,
-                                m_viewer->url() );
+                              m_viewer->url() );
                 KFileItemList list;
                 list.append( &it );
                 if ( fileWidget->del(list, window,
@@ -586,9 +791,9 @@ bool KuickShow::eventFilter( QObject *o, QEvent *e )
                 fileWidget->setCurrentItem( item );
 	    }
 
-            else if ( key == Key_Space )
+	    else if ( m_toggleBrowserAction->shortcut().contains( key ) )
             {
-                toggleBrowser( !haveBrowser() );
+                toggleBrowser();
 		return true; // don't pass keyEvent
 	    }
 
@@ -597,9 +802,11 @@ bool KuickShow::eventFilter( QObject *o, QEvent *e )
 
 
 	    if ( FileWidget::isImage( item ) ) {
-		m_viewer->showNextImage( item->url().path() ); // ###
+                QString filename;
+                KIO::NetAccess::download(item->url(), filename);
+		m_viewer->showNextImage( filename );
 		
-		if ( kdata->preloadImage ) // preload next image
+		if ( kdata->preloadImage && item_next && item_next->url().isLocalFile() ) // preload next image
 		    if ( FileWidget::isImage( item_next ) )
 			m_viewer->cacheImage( item_next->url().path() ); // ###
 
@@ -607,6 +814,34 @@ bool KuickShow::eventFilter( QObject *o, QEvent *e )
 	    }
 	} // keyPressEvent on ImageWindow
 
+
+        // doubleclick closes image window
+        // and shows browser when last window closed via doubleclick
+        else if ( eventType == QEvent::MouseButtonDblClick )
+        {
+            QMouseEvent *ev = static_cast<QMouseEvent*>( e );
+            if ( ev->button() == LeftButton )
+            {
+                if ( s_viewers.count() == 1 )
+                {
+                    if ( !fileWidget )
+                    {
+                        KURL start;
+                        QFileInfo fi( m_viewer->filename() );
+                        start.setPath( fi.dirPath( true ) );
+                        initGUI( start );
+                    }
+                    show();
+                    raise();
+                }
+
+                window->close( true );
+
+                ev->accept();
+                ret = true;
+            }
+        }
+
     } // isA ImageWindow
 
 
@@ -625,7 +860,8 @@ void KuickShow::configuration()
 	initGUI( QDir::homeDirPath() );
     }
 
-    dialog = new KuickConfigDialog( fileWidget->actionCollection(), 0L, "dialog", false );
+    dialog = new KuickConfigDialog( fileWidget->actionCollection(), 0L,
+                                    "dialog", false );
     dialog->resize( 540, 510 );
     dialog->setIcon( kapp->miniIcon() );
 
@@ -652,12 +888,11 @@ void KuickShow::slotConfigApplied()
     QValueListIterator<ImageWindow*> it = s_viewers.begin();
     while ( it != s_viewers.end() ) {
         viewer = *it;
-	viewer->updateAccel();
-        viewer->setBackgroundColor( kdata->backgroundColor );
+	viewer->updateActions();
 	++it;
     }
 
-	fileWidget->reloadConfiguration();
+    fileWidget->reloadConfiguration();
 }
 
 
@@ -669,13 +904,11 @@ void KuickShow::slotConfigClosed()
 
 void KuickShow::about()
 {
-    AboutWidget *aboutWidget = new AboutWidget( 0L, "about" );
+    if ( !aboutWidget )
+        aboutWidget = new AboutWidget( 0L, "about" );
+
     aboutWidget->adjustSize();
-    int scnum = QApplication::desktop()->screenNumber(this);
-    QRect d = QApplication::desktop()->screenGeometry(scnum);
-    QPoint p( d.center().x() - aboutWidget->width()/2,
-	      d.center().y() - aboutWidget->height()/2 );
-    aboutWidget->move( p );
+    KDialog::centerOnScreen( aboutWidget );
     aboutWidget->show();
 }
 
@@ -725,7 +958,7 @@ void KuickShow::saveSettings()
     KConfig *kc = KGlobal::config();
 
     kc->setGroup("SessionSettings");
-    kc->writeEntry( "OpenImagesInActiveWindow", newWindowAction->isChecked() );
+    kc->writeEntry( "OpenImagesInActiveWindow", oneWindowAction->isChecked() );
     kc->writeEntry( "CurrentDirectory", fileWidget->url().url() );
 
     if ( fileWidget )
@@ -738,10 +971,10 @@ void KuickShow::saveSettings()
 void KuickShow::messageCantLoadImage( const QString& filename )
 {
     m_viewer->clearFocus();
-    QString tmp = i18n("Sorry, I can't load the image %1.\n"
+    QString tmp = i18n("Unable to load the image %1.\n"
 	    "Perhaps the file format is unsupported or "
                       "your Imlib is not installed properly.").arg(filename);
-    KMessageBox::sorry( 0L, tmp, i18n("Image Error") );
+    KMessageBox::sorry( m_viewer, tmp, i18n("Image Error") );
 }
 
 void KuickShow::initImlib()
@@ -772,7 +1005,7 @@ void KuickShow::initImlib()
 		    "I will quit now.");
 	    KMessageBox::error( this, tmp, i18n("Fatal Imlib error") );
 
-	    exit(1);
+	    ::exit(1);
 	}
     }
 }
@@ -853,19 +1086,52 @@ void KuickShow::slotReplayAdvance()
     delete e;
 }
 
-void KuickShow::toggleBrowser( bool show )
+void KuickShow::toggleBrowser()
 {
-    if ( show ) {
+    if ( !haveBrowser() ) {
         if ( m_viewer && m_viewer->isFullscreen() )
             m_viewer->setFullscreen( false );
         fileWidget->resize( size() ); // ### somehow fileWidget isn't resized!?
-        KuickShow::show();
+        show();
         raise();
         KWin::setActiveWindow( winId() ); // ### this should not be necessary
-        setFocus();
+//         setFocus();
     }
-    else
+    else if ( !s_viewers.isEmpty() )
         hide();
 }
 
+void KuickShow::slotOpenURL()
+{
+    KFileDialog dlg(QString::null, kdata->fileFilter, this, "filedialog", true);
+    dlg.setMode( KFile::Files | KFile::Directory );
+    dlg.setCaption( i18n("Select Files or Directory to Open") );
+
+    if ( dlg.exec() == QDialog::Accepted )
+    {
+        KURL::List urls = dlg.selectedURLs();
+        KURL::List::ConstIterator it = urls.begin();
+        for ( ; it != urls.end(); ++it )
+        {
+            KFileItem item( KFileItem::Unknown, KFileItem::Unknown, *it );
+            if ( FileWidget::isImage( &item ) )
+                showImage( &item, true );
+            else
+                fileWidget->setURL( *it, true );
+        }
+    }
+}
+
+void KuickShow::deleteAllViewers()
+{
+    QValueListIterator<ImageWindow*> it = s_viewers.begin();
+    for ( ; it != s_viewers.end(); ++it ) {
+        (*it)->blockSignals( true ); // don't call viewerDeleted()
+        (*it)->close( true );
+    }
+
+    s_viewers.clear();
+    m_viewer = 0L;
+}
+
 #include "kuickshow.moc"
