@@ -1,5 +1,5 @@
 /**
- * $Id: main.cpp,v 1.2 2001/10/10 17:57:48 mueller Exp $
+ * $Id: main.cpp,v 1.5 2002/09/04 23:22:38 pfeiffer Exp $
  *
  * Copyright 1998, 2000 by Carsten Pfeiffer
  */
@@ -28,13 +28,12 @@ int main(int argc, char **argv)
     KAboutData about(
 	  "kuickshow", I18N_NOOP( "KuickShow" ), KUICKSHOWVERSION,
 	  I18N_NOOP("A fast and versatile image viewer" ),
-	  KAboutData::License_GPL, "(c) 1998-2001, Carsten Pfeiffer",
-	  0 /*text*/, "http://devel-home.kde.org/~pfeiffer/",
-	  "pfeiffer@kde.org" );
+	  KAboutData::License_GPL, "(c) 1998-2002, Carsten Pfeiffer",
+	  0 /*text*/, "http://devel-home.kde.org/~pfeiffer/" );
 
     about.addAuthor( "Carsten Pfeiffer", 0, "pfeiffer@kde.org",
 		     "http://devel-home.kde.org/~pfeiffer/" );
-    about.addCredit( "Rober Hamberger", 0, "Robert.Hamberger@AUDI.DE" );
+    about.addCredit( "Rober Hamberger", 0, "rh474@bingo-ev.de" );
     about.addCredit( "Thorsten Scheuermann", 0, "uddn@rz.uni-karlsruhe.de" );
 
     KCmdLineArgs::init( argc, argv, &about );
