@@ -33,11 +33,11 @@
 #include "gotodialog.h"
 #include "kpagetest.h"
 #include "kviewpart.moc"
-
+#include "pageSizeDialog.h"
 
 extern "C"
 {
-  void *init_libkviewerpart()
+  void *init_kviewerpart()
   {
     return new KViewPartFactory;
   }
@@ -79,22 +79,11 @@ KInstance *KViewPartFactory::instance()
 }
 
 
-class PaperSize
-{
-public:
-
-  PaperSize(double w, double h)
-    : width(w), height(h) {};
-
-  double width;
-  double height;
-};
-
-
 KViewPart::KViewPart(QString partname, QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name)
-  : KParts::ReadOnlyPart(parent, name), _partname(partname), _numberOfPages(0),
-  _currentPage(0), _zoom(1.0)
+  : KViewPart_Iface(parent, name), _partname(partname), _numberOfPages(0),
+  _currentPage(0)
 {
+  pageChangeIsConnected = false;
   setInstance(KViewPartFactory::instance());
 
   watch = KDirWatch::self();
@@ -125,11 +114,15 @@ KViewPart::KViewPart(QString partname, QWidget *parentWidget, const char *widget
   // create the displaying part
 
   // Try to load
-  KLibFactory *factory = KLibLoader::self()->factory(QString("libk%1").arg(_partname).utf8());
+  KLibFactory *factory;
+  factory = KLibLoader::self()->factory(QString("k%1part").arg(_partname).utf8());
+  // Support old style parts (as libs)
+  if (!factory)
+    factory = KLibLoader::self()->factory(QString("libk%1").arg(_partname).utf8());
   if (factory) {
     multiPage = (KMultiPage*) factory->create(mainWidget, QString("k%1").arg(_partname).utf8(), "KPart");
   } else {
-    KMessageBox::error(mainWidget, QString("No libk%1 found !").arg(_partname));
+    KMessageBox::error(mainWidget, i18n("No module (%1) found").arg(_partname));
     ::exit(-1);
   }
   hbox->addWidget(multiPage->widget());
@@ -143,14 +136,14 @@ KViewPart::KViewPart(QString partname, QWidget *parentWidget, const char *widget
   connect( multiPage, SIGNAL( completed() ), this, SIGNAL( completed() ) );
   connect( multiPage, SIGNAL( canceled( const QString & ) ), this, SIGNAL( canceled( const QString & ) ) );
   connect( multiPage, SIGNAL( previewChanged(bool)), this, SLOT(updatePreview(bool)));
-  connect( multiPage, SIGNAL( setStatusBarText( const QString& ) ), this, SIGNAL( setStatusBarText( const QString& ) ) );
+  connect( multiPage, SIGNAL( setStatusBarText( const QString& ) ), this, SLOT( setStatusBarTextFromMultiPage( const QString& ) ) );
 
   // settings menu
   showmarklist = new KToggleAction (i18n("Show &Page List"), 0, this, SLOT(slotShowMarkList()), actionCollection(), "show_page_list");
   showPreview = new KToggleAction (i18n("Show P&review"), 0, this, SLOT(slotPreview()), actionCollection(), "show_preview");
   watchAct = new KToggleAction(i18n("&Watch File"), 0, 0, 0, actionCollection(), "watch_file");
 
-  // view menu
+  // Orientation menu
   QStringList orientations;
   orientations.append(i18n("Portrait"));
   orientations.append(i18n("Landscape"));
@@ -158,14 +151,23 @@ KViewPart::KViewPart(QString partname, QWidget *parentWidget, const char *widget
   connect (orientation, SIGNAL(activated (int)), this, SLOT(slotOrientation(int)));
   orientation->setItems(orientations);
 
+  // Zoom Menu
+  zoom_action = new KSelectAction (i18n("&Zoom"), 0, 0, 0, actionCollection(), "view_zoom");
+  zoom_action->setComboWidth(80);
+  zoom_action->setEditable(true);
+  zoom_action->setItems(_zoomVal.zoomNames());
+  _zoomVal.setZoomValue(1.0); // should not be necessary @@@@
+  connect (&_zoomVal, SIGNAL(zoomNamesChanged(const QStringList &)), zoom_action, SLOT(setItems(const QStringList &)));
+  connect (&_zoomVal, SIGNAL(valNoChanged(int)), zoom_action, SLOT(setCurrentItem(int)));
+  connect (zoom_action, SIGNAL(activated(const QString &)), this, SLOT(setZoomValue(const QString &)));
+
+  // Paper Size Menu
   media = new KSelectAction (i18n("Paper &Size"), 0, 0, 0, actionCollection(), "view_media");
+  QStringList items = _paperSize.pageSizeNames();
+  items.prepend(i18n("Custom Size..."));
+  media->setItems(items);
   connect (media, SIGNAL(activated(int)), this, SLOT(slotMedia(int)));
-  fillPaperSizes();
 
-  _zoom        = 1.0;
-  _paperWidth  = 21.0;
-  _paperHeight = 29.7;
-  setPaperSize(_paperWidth, _paperHeight);
 
   zoomInAct = KStdAction::zoomIn (this, SLOT(zoomIn()), actionCollection());
   zoomOutAct = KStdAction::zoomOut(this, SLOT(zoomOut()), actionCollection());
@@ -182,7 +184,7 @@ KViewPart::KViewPart(QString partname, QWidget *parentWidget, const char *widget
   endAct = KStdAction::lastPage(this, SLOT(lastPage()), actionCollection());
   gotoAct = KStdAction::gotoPage(this, SLOT(goToPage()), actionCollection());
 
-  readDownAct = new KAction(i18n("Read down Document"), "next",
+  readDownAct = new KAction(i18n("Read Down Document"), "next",
 			    Key_Space, this, SLOT(readDown() ),
 			    actionCollection(), "go_read_down");
 
@@ -205,7 +207,6 @@ KViewPart::KViewPart(QString partname, QWidget *parentWidget, const char *widget
 
   setXMLFile("kviewerpart.rc");
 
-
   m_extension = new KViewPartExtension(this);
 
   // create the goto dialog
@@ -213,6 +214,10 @@ KViewPart::KViewPart(QString partname, QWidget *parentWidget, const char *widget
   _gotoDialog->hide();
   connect(_gotoDialog, SIGNAL(gotoPage(const QString&)), this, SLOT(slotGotoDialog(const QString&)));
 
+  // The page size dialog is constructed on first usage -- saves some
+  // memory when not used.
+  _pageSizeDialog = 0;
+
   numberOfPages(0);
   checkActions();
 
@@ -220,9 +225,6 @@ KViewPart::KViewPart(QString partname, QWidget *parentWidget, const char *widget
   // (will be merged automatically)
   insertChildClient( multiPage );
 
-  orientation->setCurrentItem(0);
-  media->setCurrentItem(1);
-
   readSettings();
 
   // watch mouse events in the viewport
@@ -244,35 +246,6 @@ KViewPart::~KViewPart()
 }
 
 
-void KViewPart::fillPaperSizes()
-{
-  _paperSizes.clear();
-
-  QString fname = KGlobal::dirs()->findResource("data", "kviewshell/paper-formats");
-  KConfig paper(fname, true);
-  paper.setGroup("Paper");
-  unsigned int count = paper.readNumEntry("Count");
-
-  double w, h;
-  for (unsigned int i=0; i<count; i++)
-    {
-      paper.setGroup(QString("Paper %1").arg(i));
-      w = paper.readDoubleNumEntry("Width");
-      h = paper.readDoubleNumEntry("Height");
-      _paperSizes.append(new PaperSize(w,h));
-    }
-
-  QStringList items;
-  items << i18n("A3");
-  items << i18n("A4");
-  items << i18n("A5");
-  items << i18n("Letter");
-  items << i18n("Legal");
-  items << i18n("Other...");
-  media->setItems(items);
-}
-
-
 void KViewPart::setPaperSize(double w, double h)
 {
   // reflect in scrollbox
@@ -312,6 +285,7 @@ bool KViewPart::openFile()
   // also look for "testdvi" and "test.dvi".
   QFileInfo fi(m_file);
   m_file = fi.absFilePath();
+
   if (fi.exists() == false) {
     // First produce a list of possible endings we try to append to
     // the filename. We decompose the format strings like "*.dvi
@@ -352,6 +326,7 @@ bool KViewPart::openFile()
   tmpFileURL.setPath(m_file);
   emit setWindowCaption( tmpFileURL.prettyURL() ); // set Window caption WITHOUT the reference part!
   tmpFileURL.setRef(m_url.ref()); // Pass the reference part of the URL through to the multipage
+
   bool r = multiPage->openURL(tmpFileURL);
 
   updateScrollBox();
@@ -402,50 +377,59 @@ bool KViewPart::closeURL()
 }
 
 
-void KViewPart::slotOrientation(int id)
+void KViewPart::slotOrientation(int)
 {
-  if (id == 0)
-    setPaperSize(_paperWidth, _paperHeight);
+  if (orientation->currentItem() == 0)
+    setPaperSize( _paperSize.pageWidth_in_mm()/10.0, _paperSize.pageHeight_in_mm()/10.0);
   else
-    setPaperSize(_paperHeight, _paperWidth);
+    setPaperSize( _paperSize.pageHeight_in_mm()/10.0, _paperSize.pageWidth_in_mm()/10.0);
+  if (_pageSizeDialog != 0)
+    _pageSizeDialog->setOrientation(orientation->currentItem());
 }
 
 
 void KViewPart::slotMedia(int id)
 {
-  double w=0.0, h=0.0;
-
-  // This hard-coded list is really a shame. We should use a more
-  // flexible global list here. If you modify here, don't forget to
-  // modify the hard-coded list in readSettings() as well!
-  switch (id) {
-  case 0:
-    w = 29.7; h = 42.0;
-    break;
-  case 1:
-    w = 21.0; h = 29.7;
-    break;
-  case 2:
-    w = 14.85; h = 21.0;
-    break;
-  case 3:
-    w = 21.59; h = 27.94;
-    break;
-  case 4:
-    w = 21.50; h = 35.56;
-    break;
-  case 5:
-    // TODO : paper size dialog!
-    break;
+  if (id > 0) {
+    _paperSize.setPageSize(media->currentText());
+    slotOrientation(0);
+    return;
   }
 
-  if (w != 0.0 && h != 0.0)
-    if (orientation->currentItem() == 0)
-      setPaperSize(w, h);
-    else
-      setPaperSize(h, w);
-  _paperWidth = w;
-  _paperHeight = h;
+  // Show the paper size dialog!
+  if (_pageSizeDialog == 0) {
+    // create the pageSize dialog
+    _pageSizeDialog = new pageSizeDialog(mainWidget);
+    if (_pageSizeDialog == 0) {
+      kdError() << "Could not construct the page size dialog!" << endl;
+      return;
+    }
+    _pageSizeDialog->setOrientation(orientation->currentItem());
+    connect(_pageSizeDialog, SIGNAL(sizeSelected(const QString&, int)), this, SLOT(slotSizeSelected(const QString&, int)));
+  }
+
+  // Set or update the paper size dialog to show the currently
+  // selected value.
+  media->setCurrentItem(_paperSize.formatNumber()+1); // Give useful setting in case the user aborts the dialog
+  _pageSizeDialog->setPageSize(_paperSize.serialize());
+  _pageSizeDialog->show();
+}
+
+
+void KViewPart::slotSizeSelected(const QString &sizeString, int ori)
+{
+  // Check if there is something to do for us. Speeds up the GUI a
+  // lot.
+  if ((ori == orientation->currentItem())&&(sizeString == _paperSize.serialize()))
+    return;
+
+  orientation->setCurrentItem(ori);
+  _paperSize.setPageSize(sizeString);
+  // We never select "Custom paper size" so that the user can select
+  // it several times in a row.
+  if (_paperSize.formatNumber() != -1)
+    media->setCurrentItem(_paperSize.formatNumber()+1);
+  slotOrientation(0); // Calls setPaperSize() and updates the display.
 }
 
 
@@ -469,15 +453,18 @@ void KViewPart::numberOfPages(int nr)
   setPage(0);
 }
 
+
 void KViewPart::pageInfo(int numpages, int currentpage)
 {
   _numberOfPages = numpages;
+
   markList->clear();
 
   if (numpages == 0) {
     // clear scroll box
     scrollBox->setPageSize(QSize(0,0));
     scrollBox->setViewSize(QSize(0,0));
+    emit pageChanged(QString::null);
     _currentPage = 0;
     return;
   }
@@ -486,14 +473,16 @@ void KViewPart::pageInfo(int numpages, int currentpage)
     markList->insertItem(QString("%1").arg(i+1), i);
 
   _currentPage = currentpage;
+  // ATTN: The string here must be the same as in setPage() below
+  QString pageString = i18n("Page %1 of %2").arg(_currentPage+1).arg(_numberOfPages);
+  if (pageChangeIsConnected)
+    emit pageChanged(pageString);
+  else
+    emit setStatusBarText(pageString);
+
   markList->select(currentpage);
   checkActions();
   updateScrollBox();
-
-  if (_numberOfPages == 0)
-    emit setStatusBarText("");
-  else
-    emit setStatusBarText(QString(i18n("Page %1 of %2")).arg(_currentPage+1).arg(_numberOfPages));
 }
 
 
@@ -501,6 +490,17 @@ void KViewPart::setPage(int page)
 {
   _currentPage = page;
 
+  QString pageString;
+  if (_numberOfPages == 0)
+    pageString = QString::null;
+  else
+    // ATTN: The string here must be the same as in pageInfo(int,int) above
+    pageString = i18n("Page %1 of %2").arg(_currentPage+1).arg(_numberOfPages);
+  if (pageChangeIsConnected)
+    emit pageChanged(pageString);
+  else
+    emit setStatusBarText(pageString);
+
   if (!multiPage->gotoPage(page))
     return;
 
@@ -567,24 +567,14 @@ void KViewPart::pageSelected(int nr)
 
 void KViewPart::zoomIn()
 {
-  _zoom = _zoom * pow(2.0, 1.0/4.0);
-  if (_zoom < minZoom/1000.0)
-    _zoom = minZoom/1000.0;
-  if (_zoom > maxZoom/1000.0)
-    _zoom = maxZoom/1000.0;
-  _zoom = multiPage->setZoom(_zoom);
+  _zoomVal.setZoomValue(multiPage->setZoom(_zoomVal.zoomIn()));
   updateScrollBox();
 }
 
 
 void KViewPart::zoomOut()
 {
-  _zoom = _zoom / pow(2.0, 1.0/4.0);
-  if (_zoom < minZoom/1000.0)
-    _zoom = minZoom/1000.0;
-  if (_zoom > maxZoom/1000.0)
-    _zoom = maxZoom/1000.0;
-  _zoom = multiPage->setZoom(_zoom);
+  _zoomVal.setZoomValue(multiPage->setZoom(_zoomVal.zoomOut()));
   updateScrollBox();
 }
 
@@ -592,6 +582,7 @@ void KViewPart::zoomOut()
 void KViewPart::fitToPage()
 {
   double w, h;
+  float _zoom;
 
   w = multiPage->zoomForWidth(pageSize().width());
   h = multiPage->zoomForHeight(pageSize().height());
@@ -600,18 +591,18 @@ void KViewPart::fitToPage()
     _zoom = w;
   else
     _zoom = h;
-  if (_zoom < minZoom/1000.0)
-    _zoom = minZoom/1000.0;
-  if (_zoom > maxZoom/1000.0)
-    _zoom = maxZoom/1000.0;
-  _zoom = multiPage->setZoom(_zoom);
+  if (_zoom < ZoomLimits::MinZoom/1000.0)
+    _zoom = ZoomLimits::MinZoom/1000.0;
+  if (_zoom > ZoomLimits::MaxZoom/1000.0)
+    _zoom = ZoomLimits::MaxZoom/1000.0;
+  _zoomVal.setZoomValue(multiPage->setZoom(_zoom));
   updateScrollBox();
 }
 
 
 void KViewPart::fitSize()
 {
-  _zoom = multiPage->setZoom(1.0);
+  _zoomVal.setZoomValue(multiPage->setZoom(1.0));
   updateScrollBox();
 }
 
@@ -623,17 +614,17 @@ void KViewPart::fitToHeight()
   int targetHeight  = multiPage->scrollView()->viewportSize(0,0).height()-1;
   int targetWidth;
   if (orientation->currentItem() == 0)
-    targetWidth = (int)(targetHeight * _paperWidth/_paperHeight +0.5);
+    targetWidth = (int)(targetHeight * _paperSize.pageWidth_in_mm()/_paperSize.pageHeight_in_mm() +0.5);
   else
-    targetWidth = (int)(targetHeight * _paperHeight/_paperWidth +0.5);
+    targetWidth = (int)(targetHeight * _paperSize.pageHeight_in_mm()/_paperSize.pageWidth_in_mm() +0.5);
   targetHeight = multiPage->scrollView()->viewportSize(targetWidth, targetHeight).height()-1;
-  
-  _zoom = multiPage->zoomForHeight(targetHeight);
-  if (_zoom < minZoom/1000.0)
-    _zoom = minZoom/1000.0;
-  if (_zoom > maxZoom/1000.0)
-    _zoom = maxZoom/1000.0;
-  _zoom = multiPage->setZoom(_zoom);
+
+  float _zoom = multiPage->zoomForHeight(targetHeight);
+  if (_zoom < ZoomLimits::MinZoom/1000.0)
+    _zoom = ZoomLimits::MinZoom/1000.0;
+  if (_zoom > ZoomLimits::MaxZoom/1000.0)
+    _zoom = ZoomLimits::MaxZoom/1000.0;
+  _zoomVal.setZoomValue(multiPage->setZoom(_zoom));
   updateScrollBox();
 }
 
@@ -655,20 +646,30 @@ void KViewPart::fitToWidth()
   int targetWidth  = multiPage->scrollView()->viewportSize(0,0).width()-1;
   int targetHeight;
   if (orientation->currentItem() == 0)
-    targetHeight = (int)(targetWidth * _paperHeight/_paperWidth +0.5);
+    targetHeight = (int)(targetWidth * _paperSize.pageHeight_in_mm()/_paperSize.pageWidth_in_mm() +0.5);
   else
-    targetHeight = (int)(targetWidth * _paperWidth/_paperHeight +0.5);
+    targetHeight = (int)(targetWidth * _paperSize.pageWidth_in_mm()/_paperSize.pageHeight_in_mm() +0.5);
   // Think again, this time use only the area which is really
   // acessible (which, in case that targetWidth targetHeight don't fit
   // the viewport, is really smaller because of the scrollbars).
   targetWidth      = multiPage->scrollView()->viewportSize(targetWidth, targetHeight).width()-1;
 
-  _zoom = multiPage->zoomForWidth(targetWidth);
-  if (_zoom < minZoom/1000.0)
-    _zoom = minZoom/1000.0;
-  if (_zoom > maxZoom/1000.0)
-    _zoom = maxZoom/1000.0;
-  _zoom = multiPage->setZoom(_zoom);
+  float _zoom = multiPage->zoomForWidth(targetWidth);
+  if (_zoom < ZoomLimits::MinZoom/1000.0)
+    _zoom = ZoomLimits::MinZoom/1000.0;
+  if (_zoom > ZoomLimits::MaxZoom/1000.0)
+    _zoom = ZoomLimits::MaxZoom/1000.0;
+  _zoomVal.setZoomValue(multiPage->setZoom(_zoom));
+  updateScrollBox();
+}
+
+
+void KViewPart::setZoomValue(const QString &sval)
+{
+  float fval = _zoomVal.value();
+  _zoomVal.setZoomValue(sval);
+  if (fval != _zoomVal.value())
+    _zoomVal.setZoomValue(multiPage->setZoom(_zoomVal.value()));
   updateScrollBox();
 }
 
@@ -686,6 +687,7 @@ void KViewPart::updateScrollBox()
   scrollBox->setPageSize(QSize(sv->contentsWidth(), sv->contentsHeight()));
   scrollBox->setViewSize(QSize(sv->visibleWidth(), sv->visibleHeight()));
   scrollBox->setViewPos(QPoint(sv->contentsX(), sv->contentsY()));
+  emit zoomChanged(QString("%1%").arg((int)(_zoomVal.value()*100.0+0.5)));
 }
 
 
@@ -750,11 +752,11 @@ bool KViewPart::eventFilter(QObject *obj, QEvent *ev)
       }
       mousePos = newPos;
     }
-    
+
     if (ev->type() == QEvent::MouseButtonRelease)
       multiPage->scrollView()->setCursor(Qt::arrowCursor);
   }
-  
+
   return false;
 }
 
@@ -841,10 +843,13 @@ void KViewPart::scrollTo(int x, int y)
 
 void KViewPart::updatePreview(bool avail)
 {
-  if (_numberOfPages == 0)
-    emit setStatusBarText("");
+  QString size = _paperSize.serialize()+"/";
+  if (orientation->currentItem() == 0)
+    size += i18n("portrait");
   else
-    emit setStatusBarText(QString(i18n("Page %1 of %2")).arg(_currentPage+1).arg(_numberOfPages));
+    size += i18n("landscape");
+  emit sizeChanged(size);
+
 
   QPixmap pixmap(scrollBox->width(), scrollBox->height());
   QPainter p(&pixmap);
@@ -866,16 +871,16 @@ void KViewPart::slotPreview()
 void KViewPart::slotPrint()
 {
   QStringList pages;
+  QValueList<int> selectedPageNo = markList->markList();
 
-  for (int i=0; i<markList->count(); i++)
-    if (markList->isSelected(i))
-      pages.append(QString::number(i));
+  QValueList<int>::iterator it;
+  for ( it = selectedPageNo.begin(); it != selectedPageNo.end(); ++it )
+    pages.append(QString::number((*it)-1));
 
   multiPage->print(pages, page());
 }
 
 
-
 void KViewPart::readSettings()
 {
   KConfig *config = instance()->config();
@@ -887,39 +892,26 @@ void KViewPart::readSettings()
 
   watchAct->setChecked(config->readBoolEntry("WatchFile", true));
   showPreview->setChecked(config->readBoolEntry("ShowPreview", true));
-  _zoom = config->readDoubleNumEntry("Zoom", 1.0);
-  if ( (_zoom < minZoom/1000.0) || (_zoom > maxZoom/1000.0))
+  float _zoom = config->readDoubleNumEntry("Zoom", 1.0);
+  if ( (_zoom < ZoomLimits::MinZoom/1000.0) || (_zoom > ZoomLimits::MaxZoom/1000.0))
     _zoom = 1.0;
-  _zoom = multiPage->setZoom(_zoom);
+  _zoomVal.setZoomValue(multiPage->setZoom(_zoom));
 
   // Read Paper Size and orientation
   int orient = config->readNumEntry("Orientation", 0 );
   orientation->setCurrentItem(orient);
-  double w = config->readDoubleNumEntry("PaperWidth", 21.0 );
-  double h = config->readDoubleNumEntry("PaperHeight", 29.7 );
-  if (orient == 0)
-    setPaperSize(w, h);
+  if (_pageSizeDialog != 0)
+    _pageSizeDialog->setOrientation(orient);
+
+  _paperSize.setPageSize(config->readEntry("PaperFormat", QString::null));
+  // Since "Custom paper size" is the first entry in the media list,
+  // we can just add 1 to the formatNumber. We never select "Custom
+  // paper size" so that the user can select it several times in a row.
+  if (_paperSize.formatNumber() == -1)
+    media->setCurrentItem(-1); // Nothing selected
   else
-    setPaperSize(h, w);
-
-  // Try the find the suitable paper size. This hard-coded list is
-  // really a shame. We should use a more flexible global list
-  // here. By the way, it is never a good idea to check if two floats
-  // are equal... here that is not a problem (yet) because we never do
-  // any calculation.
-  int mediaitem = 5; // Default: paper size if "other"
-  if ((w == 29.70) && (h == 42.00))
-    mediaitem = 0;
-  if ((w == 21.00) && (h == 29.70))
-    mediaitem = 1;
-  if ((w == 14.85) && (h == 21.00))
-    mediaitem = 2;
-  if ((w == 21.59) && (h == 27.94))
-    mediaitem = 3;
-  if ((w == 21.50) && (h == 35.56))
-    mediaitem = 4;
-  media->setCurrentItem(mediaitem);
-
+    media->setCurrentItem(_paperSize.formatNumber()+1);
+  slotOrientation(0); // Apply orientation and paperSize settings.
 }
 
 
@@ -932,11 +924,10 @@ void KViewPart::writeSettings()
   config->writeEntry("PageMarks", showmarklist->isChecked());
   config->writeEntry("WatchFile", watchAct->isChecked());
   config->writeEntry("ShowPreview", showPreview->isChecked());
-  config->writeEntry("Zoom", _zoom);
+  config->writeEntry("Zoom", _zoomVal.value());
 
   config->writeEntry("Orientation", orientation->currentItem() );
-  config->writeEntry("PaperWidth",  _paperWidth );
-  config->writeEntry("PaperHeight", _paperHeight );
+  config->writeEntry("PaperFormat", _paperSize.serialize() );
   config->sync();
 }
 
@@ -944,17 +935,34 @@ void KViewPart::writeSettings()
 void KViewPart::readDown()
 {
   QScrollBar *sb = multiPage->scrollView()->verticalScrollBar();
-  if (sb)
-    {
-      if (sb->value() == sb->maxValue())
-	{
-	  nextPage();
-	  QScrollView *sv = multiPage->scrollView();
-	  scrollTo(sv->contentsX(), 0);
-	}
-      else
-	sb->addPage();
-    }
+  if (sb) {
+    if (sb->value() == sb->maxValue()) {
+      nextPage();
+      QScrollView *sv = multiPage->scrollView();
+      scrollTo(sv->contentsX(), 0);
+    } else
+      sb->addPage();
+  }
+}
+
+
+void KViewPart::connectNotify ( const char *sig )
+{
+  if (QString("2pageChanged(const QString&)") == sig)
+    pageChangeIsConnected = true;
+}
+
+
+void KViewPart::setStatusBarTextFromMultiPage( const QString &msg )
+{
+  if (msg.isEmpty()) {
+    if (pageChangeIsConnected)
+      emit setStatusBarText(QString::null);
+    else
+      emit setStatusBarText(i18n("Page %1 of %2").arg(_currentPage+1).arg(_numberOfPages));
+  }
+  else
+    emit setStatusBarText(msg);
 }
 
 
