@@ -13,27 +13,29 @@
 class KRecentFilesAction;
 class ScrollBox;
 class KToggleAction;
-class KViewPart;
+class KViewPart_Iface;
 class KHelpMenu;
 class KAboutData;
 
 
+class QLabel;
+
 class KViewShell : public KParts::MainWindow
 {
   Q_OBJECT
 
 public:
-
+  KStatusBar *statusbar;
+  KStatusBar *action;
+  
   KViewShell(QString partname, KAboutData *);
   virtual ~KViewShell();
 
 public slots:
-
   void openURL(const KURL &url);
 
 
 protected slots:
-
   void slotFileOpen();
   void slotShowToolBar();
   void slotShowStatusBar();
@@ -41,9 +43,11 @@ protected slots:
   void slotEditToolbar();
   void slotFileClose();
 
+  void slotChangeZoomText(const QString &);
+  void slotChangePageText(const QString &);
+  void slotChangeSizeText(const QString &);
 
 protected:
-
   void readSettings();
   void writeSettings();
 
@@ -54,9 +58,8 @@ protected:
 
 
 private:
-
   QString _partname;
-  KViewPart *view;
+  KViewPart_Iface *view;
 
   KRecentFilesAction *recent;
   QString cwd;
