@@ -35,7 +35,7 @@ int main(int argc, char **argv)
 		    "Based on original code from KGhostView."));
   about.addAuthor ("Matthias Hoelzer-Kluepfel", I18N_NOOP("Framework"),
 		   "mhk@caldera.de");
-  about.addAuthor ("David Sweet", 
+  about.addAuthor ("David Sweet",
 		   I18N_NOOP("KGhostView Maintainer"),
 		   "dsweet@kde.org",
 		   "http://www.chaos.umd.edu/~dsweet");
@@ -48,8 +48,8 @@ int main(int argc, char **argv)
   about.addAuthor ("Daniel Duley",
 		   I18N_NOOP("Port to KParts"));
   about.addAuthor ("Espen Sand",
-		   I18N_NOOP("Dialogs boxes"));
-  about.addAuthor ("Stefan Kebekus", 
+		   I18N_NOOP("Dialog boxes"));
+  about.addAuthor ("Stefan Kebekus",
 		   I18N_NOOP("DCOP-Interface, major improvements"),
 		   "kebekus@kde.org");
 
@@ -69,12 +69,12 @@ int main(int argc, char **argv)
     // loading. Complain, if we are given a URL which does not point
     // to a local file.
     KURL url(args->url(1));
-    
+
     if (args->url(1).isMalformed()) {
       kdError(4300) << QString(I18N_NOOP("The URL %1 is not well-formed.")).arg(args->arg(1)) << endl;
       return -1;
     }
-    
+
     if (!args->url(1).isLocalFile()) {
       kdError(4300) << QString(I18N_NOOP("The URL %1 does not point to a local file. You can only specify local "
 			     "files if you are using the '--unique' option.")).arg(args->arg(1)) << endl;
@@ -85,7 +85,9 @@ int main(int argc, char **argv)
     QString qualPath = QFileInfo(args->url(1).path()).absFilePath();
 
     app.dcopClient()->attach();
-    app.dcopClient()->registerAs("unique-kviewshell");
+    QCString id = app.dcopClient()->registerAs("unique-kviewshell");
+    if (id.isNull())
+      kdError(4300) << "There was an error using dcopClient()->registerAs()." << endl;
     QCStringList apps = app.dcopClient()->registeredApplications();
     for ( QCStringList::Iterator it = apps.begin(); it != apps.end(); ++it ) {
       if ((*it).find("kviewshell") == 0) {
@@ -94,14 +96,14 @@ int main(int argc, char **argv)
 	QDataStream arg(data, IO_WriteOnly);
 	bool result;
 	arg << qualPath.stripWhiteSpace();
-	if (!app.dcopClient()->call(*it, "kmultipage", "is_file_loaded(QString)", data, replyType, replyData))
+	if (!app.dcopClient()->call( *it, "kmultipage", "is_file_loaded(QString)", data, replyType, replyData))
 	  kdError(4300) << "There was an error using DCOP." << endl;
 	else {
 	  QDataStream reply(replyData, IO_ReadOnly);
 	  if (replyType == "bool") {
 	    reply >> result;
 	    if (result == true) {
-	      if (app.dcopClient()->send(*it, "kmultipage", "jumpToReference(QString)", args->url(1).ref()) == true) {
+	      if (app.dcopClient()->send( *it, "kmultipage", "jumpToReference(QString)", args->url(1).ref()) == true) {
 		app.dcopClient()->detach();
 		return 0;
 	      }
@@ -110,11 +112,11 @@ int main(int argc, char **argv)
 	    kdError(4300) << "The DCOP function 'doIt' returned an unexpected type of reply!";
 	}
       }
-    } 
+    }
   }
   app.dcopClient()->registerAs("kviewshell");
   KViewShell *shell = new KViewShell(args->arg(0), &about);
-  
+
 
   if ( args->count() > 1 )
     shell->openURL( args->url(1) );
