@@ -1,19 +1,23 @@
-/***************************************************************************
-                          gammadialog.cpp  -  description
-                             -------------------
-    begin                : Sat Aug 12 2000
-    copyright            : (C) 2000 by Klaas Freitag
-    email                : freitag@suse.de
- ***************************************************************************/
+/* This file is part of the KDE Project
+   Copyright (C) 2000 Klaas Freitag <freitag@suse.de>  
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+
+   $Id: gammadialog.cpp,v 1.9 2002/09/22 14:12:03 freitag Exp $
+*/
 
 #include <qlabel.h>
 #include <qpushbutton.h>
@@ -64,7 +68,7 @@ GammaDialog::GammaDialog( QWidget *parent ) :
     wBright->slSetSlider( 0 );
     connect( wBright, SIGNAL(valueChanged(int)), gt, SLOT(setBrightness(int)));
 
-    wContrast = new KScanSlider ( page, i18n("Constrast") , -50.0, 50.0 );
+    wContrast = new KScanSlider ( page, i18n("Contrast") , -50.0, 50.0 );
     Q_CHECK_PTR(wContrast);
     wContrast->slSetSlider( 0 );
     connect( wContrast, SIGNAL(valueChanged(int)), gt, SLOT(setContrast(int)));
@@ -97,12 +101,9 @@ void GammaDialog::setGt(KGammaTable& ngt)
 
 void GammaDialog::slotApply()
 {
-   kdDebug(29000) << "Applying !" << endl;
-
-   /* Do some calculation here */
-
    /* and call a signal */
-   emit( gammaToApply( *this ));
+   KGammaTable *myTable = getGt();
+   emit( gammaToApply( myTable ));
 }
 
 GammaDialog::~GammaDialog()
