@@ -1,35 +1,24 @@
-/***************************************************************************
-           img_canvas.cpp  - Class to display a scrollable image
-                             -------------------
-    begin                : Sun Dec 12 1999
-    copyright            : (C) 1999 by Klaas Freitag
-    email                : freitag@suse.de
+/* This file is part of the KDE Project
+   Copyright (C) 1999 Klaas Freitag <freitag@suse.de>  
 
-    $Id: img_canvas.cpp,v 1.16 2002/02/28 16:44:19 freitag Exp $
- ***************************************************************************/
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+
+   $Id: img_canvas.cpp,v 1.17 2002/09/19 10:24:10 freitag Exp $
+*/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- *   Some code in this module was taken from a mail which was posted
- *   in the Qt-interest Archive by Christian Hernoux
- *   <christian.hernoux@univ-rouen.fr>. It is the redrawContents
- *   function which is *real cool* (I didnt get managed the redraw
- *   until I found his code) and the tiff-support.
- */
 #include <qapplication.h>
 #include <iostream.h>
 
