@@ -1,31 +1,23 @@
-/***************************************************************************
-                   kscandevice.h - kde2 scanner object
-                             -------------------                                         
-    begin                : ?
-    copyright            : (C) 1999 by Klaas Freitag
-                               based on work of Ivan Shvedunov          
-    email                : freitag@suse.de
+/* This file is part of the KDE Project
+   Copyright (C) 1999 Klaas Freitag <freitag@suse.de>  
 
-    $Id: kscandevice.cpp,v 1.30.2.1 2002/05/02 18:27:52 freitag Exp $
- ***************************************************************************/
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- */
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+
+   $Id: kscandevice.cpp,v 1.37 2002/09/26 06:54:45 freitag Exp $
+*/
 
 #include <stdlib.h>
 #include <qwidget.h>
@@ -121,8 +113,15 @@ KScanOption *KScanDevice::getGuiElement( const QCString& name, QWidget *parent,
 	 	
       w = so->createWidget( parent, desc, tooltip );
       if( w )
+      {
 	 connect( so,   SIGNAL( optionChanged( KScanOption* ) ),
-		  this, SLOT(   slOptChanged( KScanOption* )));	
+		  this, SLOT(   slOptChanged( KScanOption* )));
+	 w->setEnabled( so->active() );
+      }
+      else
+      {
+	 kdDebug(29000) << "ERROR: No widget created for " << name << endl;
+      }
    }
    else
    {
@@ -634,9 +633,9 @@ void KScanDevice::slStopScanning( void )
     kdDebug(29000) << "Attempt to stop scanning" << endl;
     if( scanStatus == SSTAT_IN_PROGRESS )
     {
-    	scanStatus = SSTAT_STOP_NOW;
 	emit( sigScanFinished( KSCAN_CANCELLED ));
     }
+    scanStatus = SSTAT_STOP_NOW;
 }
 
 KScanStat KScanDevice::acquirePreview( bool forceGray, int dpi )
@@ -872,7 +871,6 @@ KScanStat KScanDevice::createNewImage( SANE_Parameters *p )
       img->setNumColors( 2 );
       img->setColor( 0, qRgb( 0,0,0));
       img->setColor( 1, qRgb( 255,255,255) );
-      img->fill( 0xFFFF );
     }
   }	
   else if( p->depth == 8 )
@@ -888,8 +886,6 @@ KScanStat KScanDevice::createNewImage( SANE_Parameters *p )
 	
 	for(int i = 0; i<256; i++)
 	  img->setColor(i, qRgb(i,i,i));
-	img->fill( 0xFFFF ); 
-
       }
     }
     else
@@ -897,11 +893,7 @@ KScanStat KScanDevice::createNewImage( SANE_Parameters *p )
       /* true color image */
       img =  new QImage( p->pixels_per_line, p->lines, 32 );
       if( img )
-      {
 	img->setAlphaBuffer( false );
-	img->fill( 0xFFFF );
-      }
-
     }
   }
   else
@@ -931,15 +923,13 @@ KScanStat KScanDevice::acquire_data( bool isPreview )
 
       if( sane_stat == SANE_STATUS_GOOD )
       {
-	 kdDebug(29000) << "=== non blocking IO supported ===" << endl;
+	 kdDebug(29000) << "--Pre-Loop" << endl;
 	 kdDebug(29000) << "format : " << sane_scan_param.format << endl;
 	 kdDebug(29000) << "last_frame : " << sane_scan_param.last_frame << endl;
 	 kdDebug(29000) << "lines : " << sane_scan_param.lines << endl;
 	 kdDebug(29000) << "depth : " << sane_scan_param.depth << endl;
 	 kdDebug(29000) << "pixels_per_line : " << sane_scan_param.pixels_per_line << endl;
 	 kdDebug(29000) << "bytes_per_line : " << sane_scan_param.bytes_per_line << endl;
-	 if( sane_scan_param.depth == 1 )
-	    kdDebug(29000) << "padding value: " << sane_scan_param.pixels_per_line % 8 << endl;
       }
       else
       {
@@ -1015,7 +1005,7 @@ KScanStat KScanDevice::acquire_data( bool isPreview )
 	    if( scanStatus != SSTAT_SILENT )
 	    {
 	       sane_stat = sane_get_parameters( scanner_handle, &sane_scan_param );
-	       kdDebug(29000) << "=== Non blocking does not work ===" << endl;
+	       kdDebug(29000) << "--ProcessABlock-Loop" << endl;
 	       kdDebug(29000) << "format : " << sane_scan_param.format << endl;
 	       kdDebug(29000) << "last_frame : " << sane_scan_param.last_frame << endl;
 	       kdDebug(29000) << "lines : " << sane_scan_param.lines << endl;
@@ -1036,6 +1026,37 @@ KScanStat KScanDevice::acquire_data( bool isPreview )
    return( stat );
 }
 
+void KScanDevice::loadOptionSet( KScanOptSet *optSet )
+{
+   if( !optSet )
+   {
+      return;
+   }
+
+   // kdDebug(29000) << "Loading Option set: " << optSet->optSetName() << endl;
+   QAsciiDictIterator<KScanOption> it(*optSet);
+
+   kdDebug(29000) << "Postinstalling " << optSet->count() << " options" << endl;
+   while( it.current() )
+   {
+      KScanOption *so = it.current();
+      if( ! so->initialised() )
+	 kdDebug(29000) << so->getName() << " is not initialised" << endl;
+      
+      if( ! so->active() )
+	 kdDebug(29000) << so->getName() << " is not active" << endl;
+
+      if( so && so->active() && so->initialised())
+      {
+	 const QString qq = so->get();	
+	
+	 kdDebug(29000) << "Post-Scan-apply <" << it.currentKey() << ">: " << qq << endl;
+	 apply( so );
+      }
+      ++it;
+   }
+
+}
 
 
 void KScanDevice::slScanFinished( KScanStat status )
@@ -1069,24 +1090,7 @@ void KScanDevice::slScanFinished( KScanStat status )
 	 emit( sigNewPreview( img ));
 
 	 /* The old settings need to be redefined */
-	 QAsciiDictIterator<KScanOption> it(*storeOptions);
-
-	 kdDebug(29000) << "Postinstalling " << storeOptions->count() << " options" << endl;
-	 while( it.current() )
-	 {
-	    KScanOption *so = it.current();
-	    if( ! so->initialised() ) kdDebug(29000) << so->getName() << " is not initialised" << endl;
-	    if( ! so->active() ) kdDebug(29000) << so->getName() << " is not active" << endl;
-
-	    if( so && so->active() && so->initialised())
-	    {
-	       const QString qq = so->get();	
-	
-	       kdDebug(29000) << "Post-Scan-apply <" << it.currentKey() << ">: " << qq << endl;
-	       apply( so );
-	    }
-	    ++it;
-	 }
+	 loadOptionSet( storeOptions );
       }
       else
       {
@@ -1158,7 +1162,7 @@ void KScanDevice::doProcessABlock( void )
      if( goOn )
      {
 	overall_bytes += bytes_written;
-	// kdDebug(29000) <<  "Bytes read: " << bytes_written << ", bytes written: " << rest_bytes << endl;
+	// qDebug( "Bytes read: %d, bytes written: %d", bytes_written, rest_bytes );
 
 	rptr = data; // + rest_bytes;
 
@@ -1215,9 +1219,9 @@ void KScanDevice::doProcessABlock( void )
 			  pixel_x++;
 			  if( pixel_x  >= sane_scan_param.pixels_per_line )
 			  {
-			     pixel_x = 0; pixel_y++; break;
+			     pixel_x = 0; pixel_y++;
+			     break;
 			  }
-			  
 		       }
 		    }
 		 }
@@ -1296,8 +1300,10 @@ void KScanDevice::doProcessABlock( void )
 	 * the QSocketnotifier fires for a few times after the scan has been
 	 * cancelled.  Does it matter ? To see it, just uncomment the qDebug msg.
 	 */
-	// qDebug( "Stopping the scan progress !" );
+	kdDebug(29000) << "Stopping the scan progress !" << endl;
 	goOn = false;
+	scanStatus = SSTAT_SILENT;
+	emit( sigScanFinished( KSCAN_OK ));
      }
 
   } /* while( 1 ) */
