@@ -1,22 +1,23 @@
-/***************************************************************************
-	     kscanoptset.cpp -  store a set of scan options
-                             -------------------
-    begin                : Wed Oct 13 2000
-    copyright            : (C) 2000 by Klaas Freitag
-    email                : Klaas.Freitag@SuSE.de
+/* This file is part of the KDE Project
+   Copyright (C) 2000 Klaas Freitag <freitag@suse.de>  
 
-    $Id: kscanoptset.cpp,v 1.10 2002/01/09 17:57:47 freitag Exp $
-***************************************************************************/
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
 
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+
+   $Id: kscanoptset.cpp,v 1.11 2002/09/19 10:24:10 freitag Exp $
+*/
 
 #include <qstring.h>
 #include <qasciidict.h>
