@@ -1,19 +1,23 @@
-/***************************************************************************
-                          massscandialog.cpp  -  description                              
-                             -------------------                                         
-    begin                : Sun Jun 11 2000                                           
-    copyright            : (C) 2000 by Klaas Freitag                         
-    email                : freitag@suse.de
- ***************************************************************************/
+/* This file is part of the KDE Project
+   Copyright (C) 2000 Klaas Freitag <freitag@suse.de>  
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
- *                                                                         *
- ***************************************************************************/
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+
+   $Id: massscandialog.cpp,v 1.9 2002/09/19 10:24:10 freitag Exp $
+*/
 
 #include <qlayout.h>
 #include <qlabel.h>
@@ -43,7 +47,7 @@ MassScanDialog::MassScanDialog( QWidget *parent )
    bigdad->addWidget( l1, 1);
  	
  	/* Scan parameter information */
- 	QGroupBox *f1 = new QGroupBox( i18n("Scan parameter:"), this );
+ 	QGroupBox *f1 = new QGroupBox( i18n("Scan Parameter"), this );
  	f1->setFrameStyle( QFrame::Box | QFrame::Sunken );
  	f1->setMargin(5);
  	f1->setLineWidth( 1 );
@@ -59,7 +63,7 @@ MassScanDialog::MassScanDialog( QWidget *parent )
  	l_main->addWidget( l_tofolder );
  	
  	/* Scan Progress information */
- 	QGroupBox *f2 = new QGroupBox( i18n("Scan progress:"), this );
+ 	QGroupBox *f2 = new QGroupBox( i18n("Scan Progress"), this );
  	f2->setFrameStyle( QFrame::Box | QFrame::Sunken );
  	f2->setMargin(15);
  	f2->setLineWidth( 1 );
