@@ -1,20 +1,23 @@
-/***************************************************************************
-                          scanparams.cpp  -  description
-                             -------------------
-    begin                : Fri Dec 17 1999
-    copyright            : (C) 1999 by Klaas Freitag
-    email                : freitag@suse.de
- ***************************************************************************/
+/* This file is part of the KDE Project
+   Copyright (C) 1999 Klaas Freitag <freitag@suse.de>  
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+
+   $Id: scanparams.cpp,v 1.38 2002/09/25 18:51:55 freitag Exp $
+*/
 
 #include <sane/saneopts.h>
 #include <qcstring.h>
@@ -151,13 +154,12 @@ bool ScanParams::connectDevice( KScanDevice *newScanDevice )
    /* Create a Start-Scan-Button */
    (void) new KSeparator( KSeparator::HLine, this);
    KButtonBox *kbb = new KButtonBox( this );
-   QPushButton* pb = kbb->addButton( i18n( "&Final Scan" ));
+   QPushButton* pb = kbb->addButton( i18n( "Final S&can" ));
    connect( pb, SIGNAL(clicked()), this, SLOT(slStartScan()) );
    pb = kbb->addButton( i18n( "&Preview Scan" ));
    connect( pb, SIGNAL(clicked()), this, SLOT(slAcquirePreview()) );
    kbb->layout();
 
-
    /* Initialise the progress dialog */
    progressDialog = new QProgressDialog( i18n("Scanning in progress"),
 					 i18n("Stop"), 100, 0L,
@@ -168,23 +170,10 @@ bool ScanParams::connectDevice( KScanDevice *newScanDevice )
    connect( sane_device, SIGNAL(sigScanProgress(int)),
 	    progressDialog, SLOT(setProgress(int)));
 	
-
    /* Connect the Progress Dialogs cancel-Button */
    connect( progressDialog, SIGNAL( cancelled() ), sane_device,
 	    SLOT( slStopScanning() ) );
 
-#if 0  /* hmm. Calculating the min height does not work in that way */
-   int min1 = toplabel->minimumHeight();
-   int min2 = kbb->minimumHeight();
-   int min3 = sv->minimumHeight();
-   kdDebug(29000) << "Three minheights: " << min1 << " " << min2 <<" " << min3 << endl;
-   int minH = toplabel->minimumHeight() + kbb->minimumHeight() + sv->minimumHeight();
-   kdDebug(29000) << "setting minimumHeight for scanparams: " << minH << endl;
-#endif
-   int minH = 220;
-   if( sv )
-      setMinimumHeight( minH );
-   
    return( true );
 }
 
@@ -238,7 +227,6 @@ QScrollView *ScanParams::scannerParams( )
    KScanOption *so = 0;
 
    /* Its a real scanner */
-   /* Mode setting */
    QScrollView *sv = new QScrollView( this );
    sv->setHScrollBarMode( QScrollView::AlwaysOff );
    sv->setResizePolicy( QScrollView::AutoOneFit );
@@ -249,28 +237,34 @@ QScrollView *ScanParams::scannerParams( )
    
    QHBox *hb = new QHBox(pbox);
    
-   so = sane_device->getGuiElement( SANE_NAME_SCAN_MODE, hb );
+   /* Mode setting */
+   so = sane_device->getGuiElement( SANE_NAME_SCAN_MODE, hb,
+				    SANE_TITLE_SCAN_MODE,
+				    SANE_DESC_SCAN_MODE );
    if ( so )
    {
       /* Pretty-Pixmap */
 
       KScanCombo *cb = (KScanCombo*) so->widget();
       Q_CHECK_PTR(cb);
-      cb->slSetIcon( pixLineArt, i18n("Lineart") );
-      cb->slSetIcon( pixLineArt, i18n("Binary" ));
-      cb->slSetIcon( pixGray, i18n("Gray") );
-      cb->slSetIcon( pixColor, i18n("Color") );
+      cb->slSetIcon( pixLineArt,  i18n("Line art") );
+      cb->slSetIcon( pixLineArt,  i18n("Lineart"));
+      cb->slSetIcon( pixLineArt,  i18n("Binary" ));
+      cb->slSetIcon( pixGray,     i18n("Gray") );
+      cb->slSetIcon( pixGray,     i18n("Grey") );
+      cb->slSetIcon( pixColor,    i18n("Color") );
       cb->slSetIcon( pixHalftone, i18n("Halftone") );
 
-      hb->setMargin( KDialog::marginHint() );
+      // hb->setMargin( KDialog::marginHint() );
+      // hb->setSpacing( KDialog::spacingHint());
+      hb->setMargin( 0 ); /// KDialog::marginHint() );
       hb->setSpacing( KDialog::spacingHint());
 
       hb->setStretchFactor( cb, 5 );
-      
-      connect( so, SIGNAL(guiChange(KScanOption*)),
-	       this, SLOT(slReloadAllGui( KScanOption* )));
 
       initialise( so );
+      connect( so, SIGNAL(guiChange(KScanOption*)),
+	       this, SLOT(slReloadAllGui( KScanOption* )));
    }
 
    /* Add a button for Source-Selection */
@@ -302,9 +296,53 @@ QScrollView *ScanParams::scannerParams( )
       }
    }
 
+   /* Halftoning */
+   if( sane_device->optionExists( SANE_NAME_HALFTONE ) )
+   {
+      so = sane_device->getGuiElement( SANE_NAME_HALFTONE, pbox,
+				       SANE_TITLE_HALFTONE,
+				       SANE_DESC_HALFTONE );
+      if( so )
+      {
+	 initialise(so);
+	 connect( so,   SIGNAL(guiChange(KScanOption*)),
+		  this, SLOT(slReloadAllGui( KScanOption* )));
+      }
+   }
+   
+   if( sane_device->optionExists( SANE_NAME_HALFTONE_DIMENSION) )
+   {
+      kdDebug(28000) << "Halftone-Dimen exists" << endl;
+      so = sane_device->getGuiElement( SANE_NAME_HALFTONE_DIMENSION, pbox,
+				       SANE_TITLE_HALFTONE_DIMENSION,
+				       SANE_DESC_HALFTONE_DIMENSION );
+      if( so )
+      {
+	 initialise(so);
+	 connect( so,   SIGNAL(guiChange(KScanOption*)),
+		  this, SLOT(slReloadAllGui( KScanOption* )));
+      }
+   }
+
+   if( sane_device->optionExists( SANE_NAME_HALFTONE_PATTERN) )
+   {
+      kdDebug(28000) << "Halftone-Pattern exists" << endl;
+      so = sane_device->getGuiElement( SANE_NAME_HALFTONE_PATTERN, pbox,
+				       SANE_TITLE_HALFTONE_PATTERN,
+				       SANE_DESC_HALFTONE_PATTERN );
+      if( so )
+      {
+	 initialise(so);
+	 connect( so,   SIGNAL(guiChange(KScanOption*)),
+		  this, SLOT(slReloadAllGui( KScanOption* )));
+      }
+   }
+         
+   
    /* Resolution Setting -> X-Resolution Setting */
    so = sane_device->getGuiElement( SANE_NAME_SCAN_X_RESOLUTION, pbox /* this */,
-				    i18n("Resolution (dpi):").local8Bit() );
+				    i18n("Resolution"),
+				    SANE_DESC_SCAN_X_RESOLUTION );
    
    if ( so )
    {
@@ -322,7 +360,8 @@ QScrollView *ScanParams::scannerParams( )
 
       xy_resolution_bind =
 	 sane_device->getGuiElement(SANE_NAME_RESOLUTION_BIND, pbox,
-				    i18n( "Bind X- and Y-Resolution" ).local8Bit() );
+				    SANE_TITLE_RESOLUTION_BIND,
+				    SANE_DESC_RESOLUTION_BIND );
       if( xy_resolution_bind  )
       {
 	 initialise( xy_resolution_bind );
@@ -333,12 +372,15 @@ QScrollView *ScanParams::scannerParams( )
       }
 
       /* Resolution Setting -> Y-Resolution Setting */
-      so = sane_device->getGuiElement( SANE_NAME_SCAN_Y_RESOLUTION, pbox);
+      so = sane_device->getGuiElement( SANE_NAME_SCAN_Y_RESOLUTION, pbox,
+				       SANE_TITLE_SCAN_Y_RESOLUTION,
+				       SANE_DESC_SCAN_Y_RESOLUTION );
       int y_res = x_y_res;
       if ( so )
       {
 	 initialise( so );
-	 so->get( &y_res );
+	 if( so->active() )
+	    so->get( &y_res );
 	 so->slRedrawWidget( so );
       }
 
@@ -348,7 +390,8 @@ QScrollView *ScanParams::scannerParams( )
    {
       /* If the SCAN_X_RES does not exists, perhaps just SCAN_RES does */
       so = sane_device->getGuiElement( SANE_NAME_SCAN_RESOLUTION, pbox,
-				       i18n("Resolution (dpi):") );
+				       SANE_TITLE_SCAN_Y_RESOLUTION,
+				       SANE_DESC_SCAN_X_RESOLUTION );
       if( so )
       {
 	 initialise( so );
@@ -363,26 +406,37 @@ QScrollView *ScanParams::scannerParams( )
    (void) new KSeparator( KSeparator::HLine, pbox );
 
    /* Speed-Setting - show only if active */
-   KScanOption kso_speed( SANE_NAME_SCAN_SPEED );
-   if( kso_speed.valid() && kso_speed.softwareSetable() && kso_speed.active())
+   if( sane_device->optionExists( SANE_NAME_SCAN_SPEED ))
    {
-      so = sane_device->getGuiElement( SANE_NAME_SCAN_SPEED, pbox);
-      initialise( so );
+      KScanOption kso_speed( SANE_NAME_SCAN_SPEED );
+      if( kso_speed.valid() && kso_speed.softwareSetable() && kso_speed.active())
+      {
+	 so = sane_device->getGuiElement( SANE_NAME_SCAN_SPEED, pbox,
+					  SANE_TITLE_SCAN_SPEED,
+					  SANE_DESC_SCAN_SPEED );
+	 initialise( so );
+      }
    }
-
+   
    /* Threshold-Setting */
-   so = sane_device->getGuiElement( SANE_NAME_THRESHOLD, pbox );
+   so = sane_device->getGuiElement( SANE_NAME_THRESHOLD, pbox,
+				    SANE_TITLE_THRESHOLD,
+				    SANE_DESC_THRESHOLD);
    if( so )
    {
       initialise( so );
    }
 
    /* Brightness-Setting */
-   so = sane_device->getGuiElement( SANE_NAME_BRIGHTNESS, pbox );
+   so = sane_device->getGuiElement( SANE_NAME_BRIGHTNESS, pbox,
+				    SANE_TITLE_BRIGHTNESS,
+				    SANE_DESC_BRIGHTNESS);
    if( so ) initialise( so );
    
    /* Contrast-Setting */
-   so = sane_device->getGuiElement( SANE_NAME_CONTRAST, pbox );
+   so = sane_device->getGuiElement( SANE_NAME_CONTRAST, pbox,
+				    SANE_TITLE_CONTRAST,
+				    SANE_DESC_CONTRAST );
    if( so ) initialise( so );
    /* Custom Gamma */
 
@@ -392,38 +446,35 @@ QScrollView *ScanParams::scannerParams( )
 
 
    /* The gamma table can be used - add  a button for editing */
+   QHBox *hb1 = new QHBox(pbox);
+   
    if( sane_device->optionExists( SANE_NAME_CUSTOM_GAMMA ) )
    {
-      QHBox *hb1 = new QHBox(pbox);
-
-      so = sane_device->getGuiElement( SANE_NAME_CUSTOM_GAMMA, hb1);
-
-      if( so )
-      {
-	 int isOn;
-	 initialise( so );
-	 so->get( &isOn );
-	
-	 (void) new QWidget( hb1 ); /* dummy widget to eat space */
-	 
-	 kdDebug(29000) << "Custom Gamma Table is <" << (isOn ? "on" : "off") << ">" << endl;
-	
-	 /* Connect a signal to refresh activity of the gamma tables */
-	 connect( so, SIGNAL(guiChange(KScanOption*)),
+      so = sane_device->getGuiElement( SANE_NAME_CUSTOM_GAMMA, hb1,
+				       SANE_TITLE_CUSTOM_GAMMA,
+				       SANE_DESC_CUSTOM_GAMMA );
+      initialise( so );
+      connect( so,   SIGNAL(guiChange(KScanOption*)),
 	       this, SLOT(slReloadAllGui( KScanOption* )));
-
-	 pb_edit_gtable = new QPushButton( i18n("Edit..."), hb1 );
-	 Q_CHECK_PTR(pb_edit_gtable);
-	 pb_edit_gtable->setEnabled( isOn );
-	
-	 connect( pb_edit_gtable, SIGNAL( clicked () ),
-		  this, SLOT( slEditCustGamma () ) );
-
-	 /* This connection cares for enabling/disabling the edit-Button */
-	 connect( so, SIGNAL(guiChange(KScanOption*)),
-		  this, SLOT(slOptionNotify(KScanOption*)));
-      }
    }
+   else
+   {
+      (void) new QLabel( i18n("Custom Gamma Table"), hb1 );
+   }
+	 
+   /* Connect a signal to refresh activity of the gamma tables */
+   (void) new QWidget( hb1 ); /* dummy widget to eat space */
+
+   pb_edit_gtable = new QPushButton( i18n("Edit..."), hb1 );
+   Q_CHECK_PTR(pb_edit_gtable);
+
+   connect( pb_edit_gtable, SIGNAL( clicked () ),
+	    this, SLOT( slEditCustGamma () ) );
+   setEditCustomGammaTableState();
+   
+   /* This connection cares for enabling/disabling the edit-Button */
+   connect( so,   SIGNAL(guiChange(KScanOption*)),
+	    this, SLOT(slOptionNotify(KScanOption*)));
 
    /* my Epson Perfection backends offer a list of user defined gamma values */
    
@@ -434,14 +485,18 @@ QScrollView *ScanParams::scannerParams( )
       (void) new KSeparator( KSeparator::HLine, pbox );
    }
 
-   so = sane_device->getGuiElement( SANE_NAME_NEGATIVE, pbox  );
+   so = sane_device->getGuiElement( SANE_NAME_NEGATIVE, pbox,
+				    SANE_TITLE_NEGATIVE,
+				    SANE_DESC_NEGATIVE );
    initialise( so );
    
    /* PREVIEW-Switch */
    kdDebug(29000) << "Try to get Gray-Preview" << endl;
    if( sane_device->optionExists( SANE_NAME_GRAY_PREVIEW ))
    {
-     so = sane_device->getGuiElement( SANE_NAME_GRAY_PREVIEW, pbox );
+     so = sane_device->getGuiElement( SANE_NAME_GRAY_PREVIEW, pbox,
+				      SANE_TITLE_GRAY_PREVIEW,
+				      SANE_DESC_GRAY_PREVIEW );
      initialise( so );
      cb_gray_preview = (QCheckBox*) so->widget();
      QToolTip::add( cb_gray_preview, i18n("Acquire a gray preview even in color mode (faster)") );
@@ -467,18 +522,7 @@ void ScanParams::createNoScannerMsg( void )
 void ScanParams::slOptionNotify( KScanOption *kso )
 {
    if( !kso || !kso->valid()) return;
-
-   kdDebug(29000) << "slOptionNotify called !" << endl;
-   if( kso->getName() == SANE_NAME_CUSTOM_GAMMA )
-   {
-      int state;
-      kso->get( &state );
-
-      if( pb_edit_gtable )
-      {
-	 pb_edit_gtable->setEnabled( state );
-      }
-   }
+   setEditCustomGammaTableState	();
 }
 
 
@@ -506,9 +550,6 @@ void ScanParams::slSourceSelect( void )
 
       if( d.exec() == QDialog::Accepted  )
       {
-#ifdef __GNUC__
-#warning and here is the rest
-#endif
 	 QString sel_source = d.getText();
 	 adf = d.getAdfBehave();
 
@@ -640,7 +681,9 @@ void ScanParams::virtualScannerParams( void )
    top->addWidget( bg_virt_scan_mode, 1 );
 
    /* GUI-Element Filename */
-   virt_filename = sane_device->getGuiElement( SANE_NAME_FILE, this );
+   virt_filename = sane_device->getGuiElement( SANE_NAME_FILE, this,
+					       SANE_TITLE_FILE,
+					       SANE_DESC_FILE );
    if( virt_filename )
    {
       QHBoxLayout *hb = new QHBoxLayout();
@@ -661,7 +704,9 @@ void ScanParams::virtualScannerParams( void )
    }
 
    /* GUI-Element Brightness */
-   so = sane_device->getGuiElement( SANE_NAME_BRIGHTNESS, this );
+   so = sane_device->getGuiElement( SANE_NAME_BRIGHTNESS, this,
+				    SANE_TITLE_BRIGHTNESS,
+				    SANE_DESC_BRIGHTNESS );
    if( so )
    {
       top->addWidget( so->widget(), 1 );
@@ -670,7 +715,9 @@ void ScanParams::virtualScannerParams( void )
    }
 
    /* GUI-Element Contrast */
-   so = sane_device->getGuiElement( SANE_NAME_CONTRAST, this );
+   so = sane_device->getGuiElement( SANE_NAME_CONTRAST, this,
+				    SANE_TITLE_CONTRAST,
+				    SANE_DESC_CONTRAST );
    if ( so )
    {
       top->addWidget( so->widget(), 1 );
@@ -689,7 +736,7 @@ void ScanParams::virtualScannerParams( void )
    }
 
    /* GUI-Element three pass simulation */
-   so = sane_device->getGuiElement( "three-pass", this, i18n("Simulate three pass acquirering"), 0 );
+   so = sane_device->getGuiElement( "three-pass", this, i18n("Simulate three-pass acquiring"), 0 );
    if ( so )
    {
       top->addWidget( so->widget(), 1 );
@@ -758,8 +805,6 @@ void ScanParams::slEditCustGamma( void )
     kdDebug(29000) << "Called EditCustGamma ;)" << endl;
     KGammaTable old_gt;
 
-    KScanOption grayGt( SANE_NAME_GAMMA_VECTOR );
-    KScanOption redGt( SANE_NAME_GAMMA_VECTOR_R );
 
     /* Since gammatable options are not set in the default gui, it must be
      * checked if it is the first edit. If it is, take from loaded default
@@ -780,8 +825,9 @@ void ScanParams::slEditCustGamma( void )
     else
     {
        /* it is not the first edit, use older values */
-       if( grayGt.active())
+       if( sane_device->optionExists( SANE_NAME_GAMMA_VECTOR ) )
        {
+	  KScanOption grayGt( SANE_NAME_GAMMA_VECTOR );
 	  /* This will be fine for all color gt's. */
 	  grayGt.get( &old_gt );
 	  kdDebug(29000) << "Gray Gamma Table is active " << endl;
@@ -792,8 +838,9 @@ void ScanParams::slEditCustGamma( void )
 	   * red/green/blue gammatables, but one for all, all gammatables
 	   * are equally. So taking the red one should be fine. TODO
 	   */
-	  if( redGt.active())
+	  if( sane_device->optionExists( SANE_NAME_GAMMA_VECTOR_R ))
 	  {
+	     KScanOption redGt( SANE_NAME_GAMMA_VECTOR_R );
 	     redGt.get( &old_gt );
 	     kdDebug(29000) << "Getting old gamma table from Red channel" << endl;
 	  }
@@ -802,6 +849,7 @@ void ScanParams::slEditCustGamma( void )
 	     /* uh ! No current gammatable could be retrieved. Use the 100/0/0 gt
 	      * created by KGammaTable's constructor. Nothing to do for that.
 	      */
+	     kdDebug(29000) << "WRN: Could not retrieve a gamma table" << endl;
 	  }
        }
     }
@@ -809,55 +857,72 @@ void ScanParams::slEditCustGamma( void )
     kdDebug(29000) << "Old gamma table: " << old_gt.getGamma() << ", " << old_gt.getBrightness() << ", " << old_gt.getContrast() << endl;
 
     GammaDialog gdiag( this );
-    connect( &gdiag, SIGNAL( gammaToApply(GammaDialog&) ),
-	     this, SLOT( slApplyGamma(GammaDialog&) ) );
+    connect( &gdiag, SIGNAL( gammaToApply(KGammaTable*) ),
+	     this,     SLOT( slApplyGamma(KGammaTable*) ) );
 
     gdiag.setGt( old_gt );
 
     if( gdiag.exec() == QDialog::Accepted  )
     {
-       slApplyGamma( gdiag );
+       slApplyGamma( gdiag.getGt() );
+       kdDebug(29000) << "Fine, applied new Gamma Table !" << endl;
     }
-
+    else
+    {
+       /* reset to old values */
+       slApplyGamma( &old_gt );
+       kdDebug(29000) << "Cancel, reverted to old Gamma Table !" << endl;
+    }
+    
 }
 
 
-void ScanParams::slApplyGamma( GammaDialog& gdiag )
+void ScanParams::slApplyGamma( KGammaTable* gt )
 {
-   KGammaTable *gt = gdiag.getGt();
    if( ! gt ) return;
-   KGammaTable old_gt;
 
-   KScanOption grayGt( SANE_NAME_GAMMA_VECTOR );
-   grayGt.get( &old_gt );
-
-   /* Now find out, which gamma-Tables are active. */
-   if( grayGt.active() )
+   kdDebug(29000) << "Applying gamma table: " << gt->getGamma() <<
+      ", " << gt->getBrightness() << ", " << gt->getContrast() << endl;
+   
+   
+   if( sane_device->optionExists( SANE_NAME_GAMMA_VECTOR ) )
    {
-      grayGt.set( gt );
-      sane_device->apply( &grayGt, true );
+      KScanOption grayGt( SANE_NAME_GAMMA_VECTOR );
+
+      /* Now find out, which gamma-Tables are active. */
+      if( grayGt.active() )
+      {
+	 grayGt.set( gt );
+	 sane_device->apply( &grayGt, true );
+      }
+   }
+   
+   if( sane_device->optionExists( SANE_NAME_GAMMA_VECTOR_R )) {
+      KScanOption rGt( SANE_NAME_GAMMA_VECTOR_R );
+      if( rGt.active() )
+      {
+	 rGt.set( gt );
+	 sane_device->apply( &rGt, true );
+      }
    }
 
-   KScanOption rGt( SANE_NAME_GAMMA_VECTOR_R );
-   KScanOption gGt( SANE_NAME_GAMMA_VECTOR_G );
-   KScanOption bGt( SANE_NAME_GAMMA_VECTOR_B );
-
-   if( rGt.active() ) {
-      rGt.set( gt );
-      sane_device->apply( &rGt, true );
+   if( sane_device->optionExists( SANE_NAME_GAMMA_VECTOR_G )) {
+      KScanOption gGt( SANE_NAME_GAMMA_VECTOR_G );
+      if( gGt.active() )
+      {
+	 gGt.set( gt );
+	 sane_device->apply( &gGt, true );
+      }
    }
 
-   if( gGt.active() ) {
-      gGt.set( gt );
-      sane_device->apply( &gGt, true );
+   if( sane_device->optionExists( SANE_NAME_GAMMA_VECTOR_B )) {
+      KScanOption bGt( SANE_NAME_GAMMA_VECTOR_B );
+      if( bGt.active() )
+      {
+	 bGt.set( gt );
+	 sane_device->apply( &bGt, true );
+      }
    }
-
-   if( bGt.active() ) {
-      bGt.set( gt );
-      sane_device->apply( &bGt, true );
-   }
-   kdDebug(29000) << "Fine !" << endl;
-
 }
 
 /* Slot calls if a widget changes. Things to do:
@@ -873,14 +938,49 @@ void ScanParams::slReloadAllGui( KScanOption* t)
     sane_device->slReloadAllBut( t );
 
     /* Custom Gamma <- What happens if that does not exist for some scanner ? TODO */
-    KScanOption kso( SANE_NAME_CUSTOM_GAMMA );
+    setEditCustomGammaTableState();
+}
 
-    if( pb_edit_gtable )
-    {
-        int state;
-        kso.get( &state );
-	pb_edit_gtable->setEnabled( state );
-    }
+/*
+ * enable editing of the gamma tables if one of the gamma tables
+ * exists and is active at the moment
+ */
+void ScanParams::setEditCustomGammaTableState()
+{
+   if( !(sane_device && pb_edit_gtable) )
+      return;
+   
+   bool butState = false;
+   kdDebug(29000) << "Checking state of edit custom gamma button !" << endl;
+   
+   if( sane_device->optionExists( SANE_NAME_CUSTOM_GAMMA ) )
+   {
+      KScanOption kso( SANE_NAME_CUSTOM_GAMMA );
+      butState = kso.active();
+      // kdDebug(29000) << "CustomGamma is active: " << butState << endl;
+   }
+
+   if( !butState && sane_device->optionExists( SANE_NAME_GAMMA_VECTOR_R ) )
+   {
+      KScanOption kso( SANE_NAME_GAMMA_VECTOR_R );
+      butState = kso.active();
+      // kdDebug(29000) << "CustomGamma Red is active: " << butState << endl;
+   }
+
+   if( !butState && sane_device->optionExists( SANE_NAME_GAMMA_VECTOR_G ) )
+   {
+      KScanOption kso( SANE_NAME_GAMMA_VECTOR_G );
+      butState = kso.active();
+      // kdDebug(29000) << "CustomGamma Green is active: " << butState << endl;
+   }
+
+   if( !butState && sane_device->optionExists( SANE_NAME_GAMMA_VECTOR_B ) )
+   {
+      KScanOption kso( SANE_NAME_GAMMA_VECTOR_B );
+      butState = kso.active();
+      // kdDebug(29000) << "CustomGamma blue is active: " << butState << endl;
+   }
+   pb_edit_gtable->setEnabled( butState );
 }
 
 
